@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -131,6 +131,18 @@ class CControllerPopupGeneric extends CController {
 					_('Name')
 				]
 			],
+			'application_prototypes' => [
+				'title' => _('Application prototypes'),
+				'min_user_type' => USER_TYPE_ZABBIX_ADMIN,
+				'allowed_src_fields' => 'application_prototypeid,name',
+				'form' => [
+					'name' => 'application_prototype_form',
+					'id' => 'application_prototypes'
+				],
+				'table_columns' => [
+					_('Name')
+				]
+			],
 			'triggers' => [
 				'title' => _('Triggers'),
 				'min_user_type' => USER_TYPE_ZABBIX_USER,
@@ -866,6 +878,33 @@ class CControllerPopupGeneric extends CController {
 				$records = CArrayHelper::renameObjectsKeys($records, ['applicationid' => 'id']);
 				break;
 
+			case 'application_prototypes':
+				$parent_discoveryid = $this->getInput('parent_discoveryid');
+
+				$discovery_rules = API::DiscoveryRule()->get([
+					'output' => [],
+					'selectApplicationPrototypes' => ['application_prototypeid', 'name'],
+					'itemids' => [$parent_discoveryid]
+				]);
+
+				if ($discovery_rules) {
+					$discovery_rule = $discovery_rules[0];
+
+					if ($discovery_rule['applicationPrototypes']) {
+						CArrayHelper::sort($discovery_rule['applicationPrototypes'], [
+							['field' => 'name', 'order' => ZBX_SORT_UP]
+						]);
+
+						foreach ($discovery_rule['applicationPrototypes'] as $application_prototype) {
+							$records[$application_prototype['application_prototypeid']] = [
+								'id' => $application_prototype['application_prototypeid'],
+								'name' => $application_prototype['name']
+							];
+						}
+					}
+				}
+				break;
+
 			case 'graphs':
 			case 'graph_prototypes':
 				if ($page_filter->hostsSelected) {
@@ -986,7 +1025,7 @@ class CControllerPopupGeneric extends CController {
 
 			case 'scripts':
 				$options = [
-					'output' => ['scriptid', 'name', 'type', 'execute_on', 'command'],
+					'output' => API_OUTPUT_EXTEND,
 					'preservekeys' => true
 				];
 				if ($hostid === null) {
