@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ class CControllerProxyHostDisable extends CController {
 		}
 		unset($host);
 
-		$result = $hosts ? (bool) API::Host()->update($hosts) : true;
+		$result = API::Host()->update($hosts);
 
 		$updated = count($hosts);
 
