@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -102,7 +102,7 @@ else {
 	}
 }
 
-if (in_array($data['popup_type'], ['applications', 'triggers'])) {
+if (in_array($data['popup_type'], ['applications', 'application_prototypes', 'triggers'])) {
 	if (!array_key_exists('noempty', $options)) {
 		$value1 = strpos($options['dstfld1'], 'id') !== false ? 0 : '';
 		$value2 = strpos($options['dstfld2'], 'id') !== false ? 0 : '';
@@ -159,6 +159,7 @@ switch ($data['popup_type']) {
 	case 'host_templates':
 	case 'templates':
 	case 'applications':
+	case 'application_prototypes':
 	case 'drules':
 		foreach ($data['table_records'] as $item) {
 			$check_box = $data['multiselect']
@@ -277,12 +278,7 @@ switch ($data['popup_type']) {
 					$options['dstfld2'] => $trigger[$options['srcfld2']]
 				];
 				if (array_key_exists('dstfld3', $options)) {
-					if (array_key_exists($options['srcfld3'], $trigger) && array_key_exists($trigger[$options['srcfld3']], $trigger)) {
-						$values[$options['dstfld3']] = $trigger[$trigger[$options['srcfld3']]];
-					}
-					else {
-						$values[$options['dstfld3']] = null;
-					}
+					$values[$options['dstfld3']] = $trigger[$trigger[$options['srcfld3']]];
 				}
 				$js_action = 'javascript: addValues('.zbx_jsvalue($options['dstfrm']).','.zbx_jsvalue($values).');';
 			}
@@ -621,7 +617,7 @@ switch ($data['popup_type']) {
 				$check_box,
 				$description,
 				$script_execute_on,
-				zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8'))
+				zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8')),
 			]);
 		}
 		unset($data['table_records']);
@@ -642,7 +638,9 @@ if ($data['multiselect'] && $form !== null) {
 	];
 }
 
-$types = ['users', 'templates', 'hosts', 'host_templates', 'host_groups', 'applications', 'proxies', 'items'];
+$types = ['users', 'templates', 'hosts', 'host_templates', 'host_groups', 'applications', 'application_prototypes',
+	'proxies', 'items'
+];
 if (array_key_exists('table_records', $data) && (in_array($data['popup_type'], $types) || $data['multiselect'])) {
 	$output['script_inline'] .= 'var popup_reference = '.zbx_jsvalue($data['table_records'], true).';';
 }
