@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,14 +29,19 @@ class CItemPrototype extends CItemGeneral {
 	protected $sortColumns = ['itemid', 'name', 'key_', 'delay', 'history', 'trends', 'type', 'status'];
 
 	/**
-	 * Define a set of supported item types.
+	 * Define a set of supported pre-processing rules.
 	 *
 	 * @var array
+	 *
+	 * 5.6 would allow this to be defined constant.
 	 */
-	protected $supported_item_types = [ITEM_TYPE_ZABBIX, ITEM_TYPE_SNMPV1, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE,
-		ITEM_TYPE_SNMPV2C, ITEM_TYPE_INTERNAL, ITEM_TYPE_SNMPV3, ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_AGGREGATE,
-		ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_CALCULATED,
-		ITEM_TYPE_JMX, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT
+	public static $supported_preprocessing_types = [ZBX_PREPROC_REGSUB, ZBX_PREPROC_TRIM, ZBX_PREPROC_RTRIM,
+		ZBX_PREPROC_LTRIM, ZBX_PREPROC_XPATH, ZBX_PREPROC_JSONPATH, ZBX_PREPROC_MULTIPLIER, ZBX_PREPROC_DELTA_VALUE,
+		ZBX_PREPROC_DELTA_SPEED, ZBX_PREPROC_BOOL2DEC, ZBX_PREPROC_OCT2DEC, ZBX_PREPROC_HEX2DEC,
+		ZBX_PREPROC_VALIDATE_RANGE, ZBX_PREPROC_VALIDATE_REGEX, ZBX_PREPROC_VALIDATE_NOT_REGEX,
+		ZBX_PREPROC_ERROR_FIELD_JSON, ZBX_PREPROC_ERROR_FIELD_XML, ZBX_PREPROC_ERROR_FIELD_REGEX,
+		ZBX_PREPROC_THROTTLE_VALUE, ZBX_PREPROC_THROTTLE_TIMED_VALUE, ZBX_PREPROC_SCRIPT,
+		ZBX_PREPROC_PROMETHEUS_PATTERN, ZBX_PREPROC_PROMETHEUS_TO_JSON
 	];
 
 	public function __construct() {
@@ -255,7 +260,7 @@ class CItemPrototype extends CItemGeneral {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$res = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($item = DBfetch($res)) {
 			if ($options['countOutput']) {
 				if ($options['groupCount'])
@@ -368,7 +373,6 @@ class CItemPrototype extends CItemGeneral {
 		foreach ($items as &$item) {
 			unset($item['itemid']);
 		}
-		unset($item);
 
 		$this->validateDependentItems($items);
 
@@ -743,9 +747,7 @@ class CItemPrototype extends CItemGeneral {
 			'preservekeys' => true
 		]);
 
-		$items = $this->extendFromObjects(zbx_toHash($items, 'itemid'), $db_items, ['type', 'authtype',
-			'master_itemid'
-		]);
+		$items = $this->extendFromObjects(zbx_toHash($items, 'itemid'), $db_items, ['type', 'master_itemid']);
 
 		$this->validateDependentItems($items);
 
@@ -769,6 +771,9 @@ class CItemPrototype extends CItemGeneral {
 				'verify_host' => $defaults['verify_host'],
 				'ssl_cert_file' => '',
 				'ssl_key_file' => '',
+				'authtype' => $defaults['authtype'],
+				'username' => '',
+				'password' => '',
 				'posts' => ''
 			]
 		];
@@ -797,8 +802,9 @@ class CItemPrototype extends CItemGeneral {
 			}
 
 			if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
-				// Clean username and password when authtype is set to HTTPTEST_AUTH_NONE.
-				if ($item['authtype'] == HTTPTEST_AUTH_NONE) {
+				// Clean username and password on authtype change to HTTPTEST_AUTH_NONE.
+				if (array_key_exists('authtype', $item) && $item['authtype'] == HTTPTEST_AUTH_NONE
+						&& $item['authtype'] != $db_items[$item['itemid']]['authtype']) {
 					$item['username'] = '';
 					$item['password'] = '';
 				}
@@ -903,7 +909,7 @@ class CItemPrototype extends CItemGeneral {
 			'output' => $output,
 			'selectApplications' => ['applicationid'],
 			'selectApplicationPrototypes' => ['name'],
-			'selectPreprocessing' => ['type', 'params'],
+			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
 			'hostids' => $data['templateids'],
 			'preservekeys' => true
 		]);
@@ -962,8 +968,6 @@ class CItemPrototype extends CItemGeneral {
 				_s('Incorrect value for field "%1$s": %2$s.', 'trends', $error)
 			);
 		}
-
-		$this->validateItemPreprocessing($item, $method);
 	}
 
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
@@ -985,57 +989,47 @@ class CItemPrototype extends CItemGeneral {
 
 		// adding applications
 		if ($options['selectApplications'] !== null && $options['selectApplications'] != API_OUTPUT_COUNT) {
-			$applications = [];
 			$relationMap = $this->createRelationMap($result, 'itemid', 'applicationid', 'items_applications');
-			$related_ids = $relationMap->getRelatedIds();
-
-			if ($related_ids) {
-				$applications = API::Application()->get([
-					'output' => $options['selectApplications'],
-					'applicationids' => $related_ids,
-					'preservekeys' => true
-				]);
-			}
-
+			$applications = API::Application()->get([
+				'output' => $options['selectApplications'],
+				'applicationids' => $relationMap->getRelatedIds(),
+				'preservekeys' => true
+			]);
 			$result = $relationMap->mapMany($result, $applications, 'applications');
 		}
 
 		// adding application prototypes
 		if ($options['selectApplicationPrototypes'] !== null
 				&& $options['selectApplicationPrototypes'] != API_OUTPUT_COUNT) {
-			$application_prototypes = [];
+			$pkFieldId = $this->pk('application_prototype');
+			$outputFields = [
+				$pkFieldId => $this->fieldId($pkFieldId, 'ap')
+			];
+
+			if (is_array($options['selectApplicationPrototypes'])) {
+				foreach ($options['selectApplicationPrototypes'] as $field) {
+					if ($this->hasField($field, 'application_prototype')) {
+						$outputFields[$field] = $this->fieldId($field, 'ap');
+					}
+				}
+
+				$outputFields = implode(',', $outputFields);
+			}
+			else {
+				$outputFields = 'ap.*';
+			}
+
 			$relationMap = $this->createRelationMap($result, 'itemid', 'application_prototypeid',
 				'item_application_prototype'
 			);
-			$related_ids = $relationMap->getRelatedIds();
 
-			if ($related_ids) {
-				$pkFieldId = $this->pk('application_prototype');
-				$outputFields = [
-					$pkFieldId => $this->fieldId($pkFieldId, 'ap')
-				];
+			$application_prototypes = DBfetchArray(DBselect(
+				'SELECT '.$outputFields.
+				' FROM application_prototype ap'.
+				' WHERE '.dbConditionInt('ap.application_prototypeid', $relationMap->getRelatedIds())
+			));
 
-				if (is_array($options['selectApplicationPrototypes'])) {
-					foreach ($options['selectApplicationPrototypes'] as $field) {
-						if ($this->hasField($field, 'application_prototype')) {
-							$outputFields[$field] = $this->fieldId($field, 'ap');
-						}
-					}
-
-					$outputFields = implode(',', $outputFields);
-				}
-				else {
-					$outputFields = 'ap.*';
-				}
-
-				$application_prototypes = DBfetchArray(DBselect(
-					'SELECT '.$outputFields.
-					' FROM application_prototype ap'.
-					' WHERE '.dbConditionInt('ap.application_prototypeid', $related_ids)
-				));
-
-				$application_prototypes = zbx_toHash($application_prototypes, 'application_prototypeid');
-			}
+			$application_prototypes = zbx_toHash($application_prototypes, 'application_prototypeid');
 
 			$result = $relationMap->mapMany($result, $application_prototypes, 'applicationPrototypes');
 		}
@@ -1043,22 +1037,16 @@ class CItemPrototype extends CItemGeneral {
 		// adding triggers
 		if (!is_null($options['selectTriggers'])) {
 			if ($options['selectTriggers'] != API_OUTPUT_COUNT) {
-				$triggers = [];
 				$relationMap = $this->createRelationMap($result, 'itemid', 'triggerid', 'functions');
-				$related_ids = $relationMap->getRelatedIds();
+				$triggers = API::TriggerPrototype()->get([
+					'output' => $options['selectTriggers'],
+					'triggerids' => $relationMap->getRelatedIds(),
+					'preservekeys' => true
+				]);
 
-				if ($related_ids) {
-					$triggers = API::TriggerPrototype()->get([
-						'output' => $options['selectTriggers'],
-						'triggerids' => $related_ids,
-						'preservekeys' => true
-					]);
-
-					if (!is_null($options['limitSelects'])) {
-						order_result($triggers, 'description');
-					}
+				if (!is_null($options['limitSelects'])) {
+					order_result($triggers, 'description');
 				}
-
 				$result = $relationMap->mapMany($result, $triggers, 'triggers', $options['limitSelects']);
 			}
 			else {
@@ -1080,22 +1068,16 @@ class CItemPrototype extends CItemGeneral {
 		// adding graphs
 		if (!is_null($options['selectGraphs'])) {
 			if ($options['selectGraphs'] != API_OUTPUT_COUNT) {
-				$graphs = [];
 				$relationMap = $this->createRelationMap($result, 'itemid', 'graphid', 'graphs_items');
-				$related_ids = $relationMap->getRelatedIds();
+				$graphs = API::GraphPrototype()->get([
+					'output' => $options['selectGraphs'],
+					'graphids' => $relationMap->getRelatedIds(),
+					'preservekeys' => true
+				]);
 
-				if ($related_ids) {
-					$graphs = API::GraphPrototype()->get([
-						'output' => $options['selectGraphs'],
-						'graphids' => $related_ids,
-						'preservekeys' => true
-					]);
-
-					if (!is_null($options['limitSelects'])) {
-						order_result($graphs, 'name');
-					}
+				if (!is_null($options['limitSelects'])) {
+					order_result($graphs, 'name');
 				}
-
 				$result = $relationMap->mapMany($result, $graphs, 'graphs', $options['limitSelects']);
 			}
 			else {
@@ -1126,30 +1108,6 @@ class CItemPrototype extends CItemGeneral {
 			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
 		}
 
-		// adding preprocessing
-		if ($options['selectPreprocessing'] !== null && $options['selectPreprocessing'] != API_OUTPUT_COUNT) {
-			$db_item_preproc = API::getApiService()->select('item_preproc', [
-				'output' => $this->outputExtend($options['selectPreprocessing'], ['itemid', 'step']),
-				'filter' => ['itemid' => array_keys($result)]
-			]);
-
-			CArrayHelper::sort($db_item_preproc, ['step']);
-
-			foreach ($result as &$item) {
-				$item['preprocessing'] = [];
-			}
-			unset($item);
-
-			foreach ($db_item_preproc as $step) {
-				$itemid = $step['itemid'];
-				unset($step['item_preprocid'], $step['itemid'], $step['step']);
-
-				if (array_key_exists($itemid, $result)) {
-					$result[$itemid]['preprocessing'][] = $step;
-				}
-			}
-		}
-
 		return $result;
 	}
 }
