@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ function make_event_details($event, $backurl) {
 	$table = (new CTableInfo())
 		->addRow([
 			_('Event'),
-			(new CDiv($event['name']))->addClass(ZBX_STYLE_WORDWRAP)
+			$event['name']
 		])
 		->addRow([
 			_('Severity'),
@@ -221,7 +221,7 @@ function make_event_details($event, $backurl) {
 					$table->addRow([_('Resolved by'), getUserFullname($user[0])]);
 				}
 				else {
-					$table->addRow([_('Resolved by'), _('Inaccessible user')]);
+					$table->addRow([_('Resolved by'), _('User')]);
 				}
 			}
 		}
@@ -309,12 +309,17 @@ function make_small_eventlist($startEvent, $backurl) {
 		'severity_name_4' => $config['severity_name_4'],
 		'severity_name_5' => $config['severity_name_5']
 	];
-	$actions = getEventsActionsIconsData($events, $triggers);
+	$actions = getEventsActionsIconsData($events, $triggers, $r_events);
 	$users = API::User()->get([
 		'output' => ['alias', 'name', 'surname'],
 		'userids' => array_keys($actions['userids']),
 		'preservekeys' => true
 	]);
+	$mediatypes = API::Mediatype()->get([
+		'output' => ['description', 'maxattempts'],
+		'mediatypeids' => array_keys($actions['mediatypeids']),
+		'preservekeys' => true
+	]);
 
 	foreach ($events as $event) {
 		$duration = ($event['r_eventid'] != 0)
@@ -371,13 +376,252 @@ function make_small_eventlist($startEvent, $backurl) {
 			(new CLink($event['acknowledged'] == EVENT_ACKNOWLEDGED ? _('Yes') : _('No'), $problem_update_url))
 				->addClass($event['acknowledged'] == EVENT_ACKNOWLEDGED ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
 				->addClass(ZBX_STYLE_LINK_ALT),
-			makeEventActionsIcons($event['eventid'], $actions['data'], $users, $severity_config)
+			makeEventActionsIcons($event['eventid'], $actions['data'], $mediatypes, $users, $severity_config)
 		]);
 	}
 
 	return $table;
 }
 
+/**
+ * Create table with trigger description and events.
+ *
+ * @param array  $trigger                    An array of trigger data.
+ * @param string $trigger['triggerid']       Trigger ID to select events.
+ * @param string $trigger['description']     Trigger description.
+ * @param string $trigger['url']             Trigger URL.
+ * @param string $eventid_till
+ * @param string $backurl                    URL to return to.
+ * @param bool   $show_timeline              Show time line flag.
+ * @param int    $show_tags                  Show tags flag. Possible values:
+ *                                             - PROBLEMS_SHOW_TAGS_NONE;
+ *                                             - PROBLEMS_SHOW_TAGS_1;
+ *                                             - PROBLEMS_SHOW_TAGS_2;
+ *                                             - PROBLEMS_SHOW_TAGS_3 (default).
+ * @param array  $filter_tags                An array of tag filtering data.
+ * @param string $filter_tags[]['tag']       Tag name.
+ * @param int    $filter_tags[]['operator']  Tag operator.
+ * @param string $filter_tags[]['value']     Tag value.
+ * @param int    $tag_name_format            Tag name format. Possible values:
+ *                                             - PROBLEMS_TAG_NAME_FULL (default);
+ *                                             - PROBLEMS_TAG_NAME_SHORTENED;
+ *                                             - PROBLEMS_TAG_NAME_NONE.
+ * @param string $tag_priority               A list of comma-separated tag names.
+ *
+ * @return CDiv
+ */
+function make_popup_eventlist($trigger, $eventid_till, $backurl, $show_timeline = true,
+		$show_tags = PROBLEMS_SHOW_TAGS_3, array $filter_tags = [], $tag_name_format = PROBLEMS_TAG_NAME_FULL,
+		$tag_priority = '') {
+	// Show trigger description and URL.
+	$div = new CDiv();
+
+	if ($trigger['comments'] !== '') {
+		$div->addItem(
+			(new CDiv())
+				->addItem(zbx_str2links($trigger['comments']))
+				->addClass(ZBX_STYLE_OVERLAY_DESCR)
+				->addStyle('max-width: 500px')
+		);
+	}
+
+	if ($trigger['url'] !== '') {
+		$trigger_url = CHtmlUrlValidator::validate($trigger['url'])
+			? $trigger['url']
+			: 'javascript: alert(\''._s('Provided URL "%1$s" is invalid.', zbx_jsvalue($trigger['url'], false, false)).
+				'\');';
+
+		$div->addItem(
+			(new CDiv())
+				->addItem(new CLink(CHTML::encode($trigger['url']), $trigger_url))
+				->addClass(ZBX_STYLE_OVERLAY_DESCR_URL)
+				->addStyle('max-width: 500px')
+		);
+	}
+
+	// indicator of sort field
+	$sort_div = (new CSpan())->addClass(ZBX_STYLE_ARROW_DOWN);
+
+	if ($show_timeline) {
+		$header = [
+			(new CColHeader([_('Time'), $sort_div]))->addClass(ZBX_STYLE_RIGHT),
+			(new CColHeader())->addClass(ZBX_STYLE_TIMELINE_TH),
+			(new CColHeader())->addClass(ZBX_STYLE_TIMELINE_TH)
+		];
+	}
+	else {
+		$header = [[_('Time'), $sort_div]];
+	}
+
+	// Select and show events.
+	$table = (new CTableInfo())
+		->setHeader(array_merge($header, [
+			_('Recovery time'),
+			_('Status'),
+			_('Duration'),
+			_('Ack'),
+			($show_tags != PROBLEMS_SHOW_TAGS_NONE) ? _('Tags') : null
+		]));
+
+	if ($eventid_till != 0) {
+		$problems = API::Event()->get([
+			'output' => ['eventid', 'r_eventid', 'clock', 'ns', 'objectid', 'acknowledged'],
+			'selectTags' => ['tag', 'value'],
+			'select_acknowledges' => ['action'],
+			'source' => EVENT_SOURCE_TRIGGERS,
+			'object' => EVENT_OBJECT_TRIGGER,
+			'eventid_till' => $eventid_till,
+			'objectids' => $trigger['triggerid'],
+			'value' => TRIGGER_VALUE_TRUE,
+			'sortfield' => ['eventid'],
+			'sortorder' => ZBX_SORT_DOWN,
+			'limit' => ZBX_WIDGET_ROWS
+		]);
+
+		CArrayHelper::sort($problems, [
+			['field' => 'clock', 'order' => ZBX_SORT_DOWN],
+			['field' => 'ns', 'order' => ZBX_SORT_DOWN]
+		]);
+
+		$r_eventids = [];
+
+		foreach ($problems as $problem) {
+			$r_eventids[$problem['r_eventid']] = true;
+		}
+		unset($r_eventids[0]);
+
+		$r_events = $r_eventids
+			? API::Event()->get([
+				'output' => ['clock', 'correlationid', 'userid'],
+				'source' => EVENT_SOURCE_TRIGGERS,
+				'object' => EVENT_OBJECT_TRIGGER,
+				'eventids' => array_keys($r_eventids),
+				'preservekeys' => true
+			])
+			: [];
+
+		$today = strtotime('today');
+		$last_clock = 0;
+
+		if ($problems && $show_tags != PROBLEMS_SHOW_TAGS_NONE) {
+			$tags = makeTags($problems, true, 'eventid', $show_tags, $filter_tags, $tag_name_format, $tag_priority);
+		}
+
+		$url_details = (new CUrl('tr_events.php'))
+			->setArgument('triggerid', '')
+			->setArgument('eventid', '');
+
+		foreach ($problems as $problem) {
+			if (array_key_exists($problem['r_eventid'], $r_events)) {
+				$problem['r_clock'] = $r_events[$problem['r_eventid']]['clock'];
+				$problem['correlationid'] = $r_events[$problem['r_eventid']]['correlationid'];
+				$problem['userid'] = $r_events[$problem['r_eventid']]['userid'];
+			}
+			else {
+				$problem['r_clock'] = 0;
+				$problem['correlationid'] = 0;
+				$problem['userid'] = 0;
+			}
+
+			if ($problem['r_eventid'] != 0) {
+				$value = TRIGGER_VALUE_FALSE;
+				$value_str = _('RESOLVED');
+				$value_clock = $problem['r_clock'];
+			}
+			else {
+				$in_closing = false;
+
+				foreach ($problem['acknowledges'] as $acknowledge) {
+					if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
+						$in_closing = true;
+						break;
+					}
+				}
+
+				$value = $in_closing ? TRIGGER_VALUE_FALSE : TRIGGER_VALUE_TRUE;
+				$value_str = $in_closing ? _('CLOSING') : _('PROBLEM');
+				$value_clock = $in_closing ? time() : $problem['clock'];
+			}
+
+			$url_details
+				->setArgument('triggerid', $problem['objectid'])
+				->setArgument('eventid', $problem['eventid']);
+
+			$cell_clock = ($problem['clock'] >= $today)
+				? zbx_date2str(TIME_FORMAT_SECONDS, $problem['clock'])
+				: zbx_date2str(DATE_TIME_FORMAT_SECONDS, $problem['clock']);
+			$cell_clock = new CCol(new CLink($cell_clock, $url_details));
+			if ($problem['r_eventid'] != 0) {
+				$cell_r_clock = ($problem['r_clock'] >= $today)
+					? zbx_date2str(TIME_FORMAT_SECONDS, $problem['r_clock'])
+					: zbx_date2str(DATE_TIME_FORMAT_SECONDS, $problem['r_clock']);
+				$cell_r_clock = (new CCol(new CLink($cell_r_clock, $url_details)))
+					->addClass(ZBX_STYLE_NOWRAP)
+					->addClass(ZBX_STYLE_RIGHT);
+			}
+			else {
+				$cell_r_clock = '';
+			}
+
+			$cell_status = new CSpan($value_str);
+
+			// add colors and blinking to span depending on configuration and trigger parameters
+			addTriggerValueStyle($cell_status, $value, $value_clock, $problem['acknowledged'] == EVENT_ACKNOWLEDGED);
+
+			if ($show_timeline) {
+				if ($last_clock != 0) {
+					CScreenProblem::addTimelineBreakpoint($table, $last_clock, $problem['clock'], ZBX_SORT_DOWN);
+				}
+				$last_clock = $problem['clock'];
+
+				$row = [
+					$cell_clock->addClass(ZBX_STYLE_TIMELINE_DATE),
+					(new CCol())
+						->addClass(ZBX_STYLE_TIMELINE_AXIS)
+						->addClass(ZBX_STYLE_TIMELINE_DOT),
+					(new CCol())->addClass(ZBX_STYLE_TIMELINE_TD)
+				];
+			}
+			else {
+				$row = [
+					$cell_clock
+						->addClass(ZBX_STYLE_NOWRAP)
+						->addClass(ZBX_STYLE_RIGHT)
+				];
+			}
+
+			// Create acknowledge link.
+			$problem_update_url = (new CUrl('zabbix.php'))
+				->setArgument('action', 'acknowledge.edit')
+				->setArgument('eventids', [$problem['eventid']])
+				->setArgument('backurl', $backurl)
+				->getUrl();
+
+			$acknowledged = $problem['acknowledged'] == EVENT_ACKNOWLEDGED;
+			$problem_update_link = (new CLink($acknowledged ? _('Yes') : _('No'), $problem_update_url))
+				->addClass($acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
+				->addClass(ZBX_STYLE_LINK_ALT);
+
+			$table->addRow(array_merge($row, [
+				$cell_r_clock,
+				$cell_status,
+				(new CCol(
+					($problem['r_eventid'] != 0)
+						? zbx_date2age($problem['clock'], $problem['r_clock'])
+						: zbx_date2age($problem['clock'])
+				))
+					->addClass(ZBX_STYLE_NOWRAP),
+				$problem_update_link,
+				($show_tags != PROBLEMS_SHOW_TAGS_NONE) ? $tags[$problem['eventid']] : null
+			]));
+		}
+	}
+
+	$div->addItem($table);
+
+	return $div;
+}
+
 /**
  * Place filter tags at the beginning of tags array.
  *
@@ -439,24 +683,26 @@ function orderEventTagsByPriority(array $event_tags, array $priorities) {
  * Create element with tags.
  *
  * @param array  $list
- * @param string $list[]['eventid'|'triggerid']
+ * @param string $list[][$key]
  * @param array  $list[]['tags']
  * @param string $list[]['tags'][]['tag']
  * @param string $list[]['tags'][]['value']
  * @param bool   $html
- * @param string $key                            Name of tags source ID. Possible values:
- *                                                - 'eventid' - for events and problems (default);
- *                                                - 'triggerid' - for triggers.
- * @param int    $list_tag_count                 Maximum number of tags to display.
- * @param array  $filter_tags                    An array of tag filtering data.
+ * @param string $key                        Name of tag source ID. Possible values:
+ *                                            - 'eventid' - for events and problems (default);
+ *                                            - 'hostid' - for hosts;
+ *                                            - 'templateid' - for templates;
+ *                                            - 'triggerid' - for triggers.
+ * @param int    $list_tag_count             Maximum number of tags to display.
+ * @param array  $filter_tags                An array of tag filtering data.
  * @param string $filter_tags[]['tag']
  * @param int    $filter_tags[]['operator']
  * @param string $filter_tags[]['value']
- * @param int    $tag_name_format                Tag name format. Possible values:
- *                                                - PROBLEMS_TAG_NAME_FULL (default);
- *                                                - PROBLEMS_TAG_NAME_SHORTENED;
- *                                                - PROBLEMS_TAG_NAME_NONE.
- * @param string $tag_priority                   A list of comma-separated tag names.
+ * @param int    $tag_name_format            Tag name format. Possible values:
+ *                                            - PROBLEMS_TAG_NAME_FULL (default);
+ *                                            - PROBLEMS_TAG_NAME_SHORTENED;
+ *                                            - PROBLEMS_TAG_NAME_NONE.
+ * @param string $tag_priority               A list of comma-separated tag names.
  *
  * @return array
  */
@@ -466,6 +712,7 @@ function makeTags(array $list, $html = true, $key = 'eventid', $list_tag_count =
 
 	if ($html) {
 		// Convert $filter_tags to a more usable format.
+
 		$f_tags = [];
 
 		foreach ($filter_tags as $tag) {
@@ -482,10 +729,14 @@ function makeTags(array $list, $html = true, $key = 'eventid', $list_tag_count =
 	}
 
 	foreach ($list as $element) {
-		CArrayHelper::sort($element['tags'], ['tag', 'value']);
-
 		$tags[$element[$key]] = [];
 
+		if (!$element['tags']) {
+			continue;
+		}
+
+		CArrayHelper::sort($element['tags'], ['tag', 'value']);
+
 		if ($html) {
 			// Show first n tags and "..." with hint box if there are more.
 
@@ -504,7 +755,9 @@ function makeTags(array $list, $html = true, $key = 'eventid', $list_tag_count =
 					$tags[$element[$key]][] = (new CSpan($value))
 						->addClass(ZBX_STYLE_TAG)
 						->setHint(getTagString($tag));
+
 					$tags_shown++;
+
 					if ($tags_shown >= $list_tag_count) {
 						break;
 					}
@@ -527,7 +780,7 @@ function makeTags(array $list, $html = true, $key = 'eventid', $list_tag_count =
 					(new CButton(null))
 						->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
 						->setHint(new CDiv($hint_content), '', true, 'max-width: 500px')
-					))->addClass(ZBX_STYLE_REL_CONTAINER);
+				))->addClass(ZBX_STYLE_REL_CONTAINER);
 			}
 		}
 		else {
@@ -564,3 +817,71 @@ function getTagString(array $tag, $tag_name_format = PROBLEMS_TAG_NAME_FULL) {
 			return $tag['tag'].(($tag['value'] === '') ? '' : ': '.$tag['value']);
 	}
 }
+
+/**
+ * Selects recent problems.
+ *
+ * @param array  $options  Variate selection set using options. All fields are mandatory.
+ * @param string $options['time_from']
+ * @param bool   $options['show_recovered']
+ * @param bool   $options['show_suppressed']
+ * @param array  $options['severities']
+ * @param int    $options['limit']
+ *
+ * @return array
+ */
+function getLastProblems(array $options) {
+	$problem_options = [
+		'output' => ['eventid', 'r_eventid', 'objectid', 'severity', 'clock', 'r_clock', 'name'],
+		'source' => EVENT_SOURCE_TRIGGERS,
+		'object' => EVENT_OBJECT_TRIGGER,
+		'severities' => $options['severities'],
+		'sortorder' => ZBX_SORT_DOWN,
+		'sortfield' => ['eventid'],
+		'limit' => $options['limit']
+	];
+
+	if ($options['show_recovered']) {
+		$problem_options['recent'] = true;
+	}
+	else {
+		$problem_options['time_from'] = $options['time_from'];
+	}
+
+	if (!$options['show_suppressed']) {
+		$problem_options['suppressed'] = false;
+	}
+
+	$db_problems = API::Problem()->get($problem_options);
+	$triggers = $db_problems
+		? API::Trigger()->get([
+			'output' => [],
+			'selectHosts' => ['hostid', 'name'],
+			'triggerid' => zbx_objectValues($db_problems, 'objectid'),
+			'lastChangeSince' => $options['time_from'],
+			'preservekeys' => true
+		])
+		: [];
+
+	$problems = [];
+
+	foreach ($db_problems as $problem) {
+		$resolved = ($problem['r_eventid'] != 0);
+		if (!array_key_exists($problem['objectid'], $triggers)) {
+			continue;
+		}
+		$trigger = $triggers[$problem['objectid']];
+		$problems[] = [
+			'resolved' => $resolved,
+			'triggerid' => $problem['objectid'],
+			'objectid' => $problem['objectid'],
+			'eventid' => $resolved ? $problem['r_eventid'] : $problem['eventid'],
+			'description' => $problem['name'],
+			'host' => reset($trigger['hosts']),
+			'severity' => $problem['severity'],
+			'clock' => $resolved ? $problem['r_clock'] : $problem['clock']
+		];
+	}
+
+	return $problems;
+}
