@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -103,7 +103,7 @@ function getUserFormData($userId, array $config, $isProfile = false) {
 			$data['messages']['enabled'] = 0;
 		}
 		if (!isset($data['messages']['sounds.recovery'])) {
-			$data['messages']['sounds.recovery'] = 'alarm_ok.mp3';
+			$data['messages']['sounds.recovery'] = 'alarm_ok.wav';
 		}
 		if (!isset($data['messages']['triggers.recovery'])) {
 			$data['messages']['triggers.recovery'] = 0;
@@ -232,8 +232,8 @@ function prepareSubfilterOutput($label, $data, $subfilter, $subfilterName) {
 }
 
 function getItemFilterForm(&$items) {
-	$filter_groupId				= $_REQUEST['filter_groupid'];
-	$filter_hostId				= $_REQUEST['filter_hostid'];
+	$filter_groupids			= $_REQUEST['filter_groupids'];
+	$filter_hostids				= $_REQUEST['filter_hostids'];
 	$filter_application			= $_REQUEST['filter_application'];
 	$filter_name				= $_REQUEST['filter_name'];
 	$filter_type				= $_REQUEST['filter_type'];
@@ -319,25 +319,25 @@ function getItemFilterForm(&$items) {
 	zbx_add_post_js("var filterTypeSwitcher = new CViewSwitcher('filter_type', 'change', ".zbx_jsvalue($fTypeVisibility, true).');');
 
 	// row 1
-	$group_filter = !empty($filter_groupId)
+	$group_filter = !empty($filter_groupids)
 		? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
 			'output' => ['groupid', 'name'],
-			'groupids' => $filter_groupId
+			'groupids' => $filter_groupids,
+			'editable' => true
 		]), ['groupid' => 'id'])
 		: [];
 
-	$filterColumn1->addRow((new CLabel(_('Host group'), 'filter_groupid_ms')),
+	$filterColumn1->addRow((new CLabel(_('Host groups'), 'filter_groupid_ms')),
 		(new CMultiSelect([
-			'name' => 'filter_groupid',
+			'name' => 'filter_groupids[]',
 			'object_name' => 'hostGroup',
-			'multiple' => false,
 			'data' => $group_filter,
 			'popup' => [
 				'parameters' => [
 					'srctbl' => 'host_groups',
 					'srcfld1' => 'groupid',
 					'dstfrm' => $filter->getName(),
-					'dstfld1' => 'filter_groupid',
+					'dstfld1' => 'filter_groupids_',
 					'editable' => true
 				]
 			]
@@ -364,26 +364,26 @@ function getItemFilterForm(&$items) {
 	);
 
 	// row 2
-	$host_filter = !empty($filter_hostId)
+	$host_filter = !empty($filter_hostids)
 		? CArrayHelper::renameObjectsKeys(API::Host()->get([
 			'output' => ['hostid', 'name'],
-			'hostids' => $filter_hostId,
-			'templated_hosts' => true
+			'hostids' => $filter_hostids,
+			'templated_hosts' => true,
+			'editable' => true
 		]), ['hostid' => 'id'])
 		: [];
 
-	$filterColumn1->addRow((new CLabel(_('Host'), 'filter_hostid_ms')),
+	$filterColumn1->addRow((new CLabel(_('Hosts'), 'filter_hostid_ms')),
 		(new CMultiSelect([
-			'name' => 'filter_hostid',
+			'name' => 'filter_hostids[]',
 			'object_name' => 'hosts',
-			'multiple' => false,
 			'data' => $host_filter,
 			'popup' => [
 				'parameters' => [
 					'srctbl' => 'host_templates',
 					'srcfld1' => 'hostid',
 					'dstfrm' => $filter->getName(),
-					'dstfld1' => 'filter_hostid',
+					'dstfld1' => 'filter_hostids_',
 					'editable' => true,
 					'templated_hosts' => true
 				]
@@ -418,8 +418,8 @@ function getItemFilterForm(&$items) {
 						'dstfld1' => 'filter_application',
 						'with_applications' => '1'
 					]).
-					',(jQuery("input[name=\'filter_hostid\']").length > 0)'.
-						' ? {hostid: jQuery("input[name=\'filter_hostid\']").val()}'.
+					',(jQuery("input[name=\'filter_hostids\']").length > 0)'.
+						' ? {hostid: jQuery("input[name=\'filter_hostids\']").val()}'.
 						' : {}'.
 					'), null, this);'
 				)
@@ -460,8 +460,8 @@ function getItemFilterForm(&$items) {
 	$filterColumn4->addRow(_('Template'),
 		new CComboBox('filter_templated_items', $filter_templated_items, null, [
 			-1 => _('all'),
-			1 => _('Templated items'),
-			0 => _('Not Templated items')
+			1 => _('Inherited items'),
+			0 => _('Not inherited items'),
 		])
 	);
 
@@ -511,7 +511,7 @@ function getItemFilterForm(&$items) {
 	// generate array with values for subfilters of selected items
 	foreach ($items as $item) {
 		// hosts
-		if (zbx_empty($filter_hostId)) {
+		if ($filter_hostids) {
 			$host = reset($item['hosts']);
 
 			if (!isset($item_params['hosts'][$host['hostid']])) {
@@ -642,10 +642,10 @@ function getItemFilterForm(&$items) {
 		// template
 		if ($filter_templated_items == -1) {
 			if ($item['templateid'] == 0 && !isset($item_params['templated_items'][0])) {
-				$item_params['templated_items'][0] = ['name' => _('Not Templated items'), 'count' => 0];
+				$item_params['templated_items'][0] = ['name' => _('Not inherited items'), 'count' => 0];
 			}
 			elseif ($item['templateid'] > 0 && !isset($item_params['templated_items'][1])) {
-				$item_params['templated_items'][1] = ['name' => _('Templated items'), 'count' => 0];
+				$item_params['templated_items'][1] = ['name' => _('Inherited items'), 'count' => 0];
 			}
 			$show_item = true;
 			foreach ($item['subfilters'] as $name => $value) {
@@ -823,9 +823,9 @@ function getItemFilterForm(&$items) {
 	}
 
 	// output
-	if (zbx_empty($filter_hostId) && count($item_params['hosts']) > 1) {
+	if ($filter_hostids && count($item_params['hosts']) > 1) {
 		$hosts_output = prepareSubfilterOutput(_('Hosts'), $item_params['hosts'], $subfilter_hosts, 'subfilter_hosts');
-		$table_subfilter->addRow($hosts_output);
+		$table_subfilter->addRow([$hosts_output]);
 	}
 
 	if (!empty($item_params['applications']) && count($item_params['applications']) > 1) {
@@ -941,8 +941,9 @@ function prepareItemHttpAgentFormData(array $item) {
 /**
  * Get data for item edit page.
  *
- * @param array	$item							Item, item prototype, LLD rule or LLD item to take the data from.
- * @param bool $options['is_discovery_rule']
+ * @param array $item                          Item, item prototype, LLD rule or LLD item to take the data from.
+ * @param array $options
+ * @param bool  $options['is_discovery_rule']
  *
  * @return array
  */
@@ -975,7 +976,7 @@ function getItemFormData(array $item = [], array $options = []) {
 		'trends' => getRequest('trends', DB::getDefault('items', 'trends')),
 		'new_application' => getRequest('new_application', ''),
 		'applications' => getRequest('applications', []),
-		'delay_flex' => array_values(getRequest('delay_flex', [])),
+		'delay_flex' => getRequest('delay_flex', []),
 		'snmpv3_contextname' => getRequest('snmpv3_contextname', ''),
 		'snmpv3_securityname' => getRequest('snmpv3_securityname', ''),
 		'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel', 0),
@@ -1018,7 +1019,9 @@ function getItemFormData(array $item = [], array $options = []) {
 		'verify_host' => getRequest('verify_host', DB::getDefault('items', 'verify_host')),
 		'http_authtype' => getRequest('http_authtype', HTTPTEST_AUTH_NONE),
 		'http_username' => getRequest('http_username', ''),
-		'http_password' => getRequest('http_password', '')
+		'http_password' => getRequest('http_password', ''),
+		'preprocessing' => getRequest('preprocessing', []),
+		'preprocessing_script_maxlength' => DB::getFieldLength('item_preproc', 'params')
 	];
 
 	if ($data['type'] == ITEM_TYPE_HTTPAGENT) {
@@ -1068,18 +1071,21 @@ function getItemFormData(array $item = [], array $options = []) {
 		$data['hostid'] = getRequest('hostid', 0);
 	}
 
-	if (!$data['is_discovery_rule']) {
-		$data['preprocessing'] = getRequest('preprocessing', []);
+	foreach ($data['preprocessing'] as &$step) {
+		$step += [
+			'error_handler' => ZBX_PREPROC_FAIL_DEFAULT,
+			'error_handler_params' => ''
+		];
 	}
+	unset($step);
 
 	// types, http items only for internal processes
 	$data['types'] = item_type2str();
 	unset($data['types'][ITEM_TYPE_HTTPTEST]);
-	if (!empty($options['is_discovery_rule'])) {
+	if ($data['is_discovery_rule']) {
 		unset($data['types'][ITEM_TYPE_AGGREGATE],
 			$data['types'][ITEM_TYPE_CALCULATED],
-			$data['types'][ITEM_TYPE_SNMPTRAP],
-			$data['types'][ITEM_TYPE_DEPENDENT]
+			$data['types'][ITEM_TYPE_SNMPTRAP]
 		);
 	}
 
@@ -1106,7 +1112,7 @@ function getItemFormData(array $item = [], array $options = []) {
 	}
 
 	// caption
-	if (!empty($data['is_discovery_rule'])) {
+	if ($data['is_discovery_rule']) {
 		$data['caption'] = _('Discovery rule');
 	}
 	else {
@@ -1196,8 +1202,9 @@ function getItemFormData(array $item = [], array $options = []) {
 			$data['headers'] = $headers;
 		}
 
+		$data['preprocessing'] = $data['item']['preprocessing'];
+
 		if (!$data['is_discovery_rule']) {
-			$data['preprocessing'] = $data['item']['preprocessing'];
 			$data['output_format'] = $data['item']['output_format'];
 		}
 
@@ -1324,7 +1331,7 @@ function getItemFormData(array $item = [], array $options = []) {
 	}
 	else {
 		$data['valuemaps'] = API::ValueMap()->get([
-			'output' => ['valuemapid', 'name']
+			'output' => ['valemapid', 'name']
 		]);
 
 		CArrayHelper::sort($data['valuemaps'], ['name']);
@@ -1368,6 +1375,266 @@ function getItemFormData(array $item = [], array $options = []) {
 	return $data;
 }
 
+/**
+ * Get list of item pre-processing data and return a prepared HTML object.
+ *
+ * @param CForm  $form                                     Form object to where add pre-processing list.
+ * @param array  $preprocessing                            Array of item pre-processing steps.
+ * @param string $preprocessing[]['type']                  Pre-processing step type.
+ * @param array  $preprocessing[]['params']                Additional parameters used by pre-processing.
+ * @param string $preprocessing[]['error_handler']         Action type used in case of pre-processing step failure.
+ * @param string $preprocessing[]['error_handler_params']  Error handler parameters.
+ * @param bool   $readonly                                 True if fields should be read only.
+ * @param array  $types                                    Supported pre-processing types.
+ *
+ * @return CList
+ */
+function getItemPreprocessing(CForm $form, array $preprocessing, $readonly, array $types) {
+	$script_maxlength = DB::getFieldLength('item_preproc', 'params');
+	$preprocessing_list = (new CList())
+		->setId('preprocessing')
+		->addClass('preprocessing-list')
+		->addClass('list-numbered')
+		->addItem(
+			(new CListItem([
+				(new CDiv(_('Name')))->addClass('step-name'),
+				(new CDiv(_('Parameters')))->addClass('step-parameters'),
+				(new CDiv(_('Custom on fail')))->addClass('step-on-fail'),
+				(new CDiv(_('Actions')))->addClass('step-action')
+			]))
+				->addClass('preprocessing-list-head')
+				->addStyle(!$preprocessing ? 'display: none;' : null)
+		);
+
+	$sortable = (count($preprocessing) > 1 && !$readonly);
+
+	$i = 0;
+
+	foreach ($preprocessing as $step) {
+		// Create a combo box with preprocessing types.
+		$preproc_types_cbbox = (new CComboBox('preprocessing['.$i.'][type]', $step['type']))->setReadonly($readonly);
+
+		foreach (get_preprocessing_types(null, true, $types) as $group) {
+			$cb_group = new COptGroup($group['label']);
+
+			foreach ($group['types'] as $type => $label) {
+				$cb_group->addItem(new CComboItem($type, $label, ($type == $step['type'])));
+			}
+
+			$preproc_types_cbbox->addItem($cb_group);
+		}
+
+		// Depending on preprocessing type, display corresponding params field and placeholders.
+		$params = '';
+
+		// Create a primary param text box, so it can be hidden if necessary.
+		$step_param_0_value = array_key_exists('params', $step) ? $step['params'][0] : '';
+		$step_param_0 = (new CTextBox('preprocessing['.$i.'][params][0]', $step_param_0_value))
+			->setTitle($step_param_0_value)
+			->setReadonly($readonly);
+
+		// Create a secondary param text box, so it can be hidden if necessary.
+		$step_param_1_value = (array_key_exists('params', $step) && array_key_exists(1, $step['params']))
+			? $step['params'][1]
+			: '';
+		$step_param_1 = (new CTextBox('preprocessing['.$i.'][params][1]', $step_param_1_value))
+			->setTitle($step_param_1_value)
+			->setReadonly($readonly);
+
+		// Add corresponding placeholders and show or hide text boxes.
+		switch ($step['type']) {
+			case ZBX_PREPROC_MULTIPLIER:
+				$params = $step_param_0
+					->setAttribute('placeholder', _('number'))
+					->setWidth(ZBX_TEXTAREA_NUMERIC_BIG_WIDTH);
+				break;
+
+			case ZBX_PREPROC_RTRIM:
+			case ZBX_PREPROC_LTRIM:
+			case ZBX_PREPROC_TRIM:
+				$params = $step_param_0
+					->setAttribute('placeholder', _('list of characters'))
+					->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
+				break;
+
+			case ZBX_PREPROC_XPATH:
+			case ZBX_PREPROC_ERROR_FIELD_XML:
+				$params = $step_param_0->setAttribute('placeholder', _('XPath'));
+				break;
+
+			case ZBX_PREPROC_JSONPATH:
+			case ZBX_PREPROC_ERROR_FIELD_JSON:
+				$params = $step_param_0->setAttribute('placeholder', _('$.path.to.node'));
+				break;
+
+			case ZBX_PREPROC_REGSUB:
+			case ZBX_PREPROC_ERROR_FIELD_REGEX:
+				$params = [
+					$step_param_0->setAttribute('placeholder', _('pattern')),
+					$step_param_1->setAttribute('placeholder', _('output'))
+				];
+				break;
+
+			case ZBX_PREPROC_VALIDATE_RANGE:
+				$params = [
+					$step_param_0->setAttribute('placeholder', _('min')),
+					$step_param_1->setAttribute('placeholder', _('max'))
+				];
+				break;
+
+			case ZBX_PREPROC_VALIDATE_REGEX:
+			case ZBX_PREPROC_VALIDATE_NOT_REGEX:
+				$params = $step_param_0->setAttribute('placeholder', _('pattern'));
+				break;
+
+			case ZBX_PREPROC_THROTTLE_TIMED_VALUE:
+				$params = $step_param_0
+					->setAttribute('placeholder', _('seconds'))
+					->setWidth(ZBX_TEXTAREA_NUMERIC_BIG_WIDTH);
+				break;
+
+			case ZBX_PREPROC_SCRIPT:
+				$params = new CMultilineInput($step_param_0->getName(), $step_param_0_value, [
+					'title' => _('JavaScript'),
+					'placeholder' => _('script'),
+					'placeholder_textarea' => 'return value',
+					'label_before' => 'function (value) {',
+					'label_after' => '}',
+					'grow' => 'auto',
+					'rows' => 0,
+					'maxlength' => $script_maxlength,
+					'readonly' => $readonly
+				]);
+				break;
+
+			case ZBX_PREPROC_PROMETHEUS_PATTERN:
+				$params = [
+					$step_param_0->setAttribute('placeholder',
+						_('<metric name>{<label name>="<label value>", ...} == <value>')
+					),
+					$step_param_1->setAttribute('placeholder', _('<label name>'))
+				];
+				break;
+
+			case ZBX_PREPROC_PROMETHEUS_TO_JSON:
+				$params = $step_param_0->setAttribute('placeholder',
+					_('<metric name>{<label name>="<label value>", ...} == <value>')
+				);
+				break;
+		}
+
+		// Create checkbox "Custom on fail" and enable or disable depending on preprocessing type.
+		$on_fail = new CCheckBox('preprocessing['.$i.'][on_fail]');
+
+		switch ($step['type']) {
+			case ZBX_PREPROC_RTRIM:
+			case ZBX_PREPROC_LTRIM:
+			case ZBX_PREPROC_TRIM:
+			case ZBX_PREPROC_ERROR_FIELD_JSON:
+			case ZBX_PREPROC_ERROR_FIELD_XML:
+			case ZBX_PREPROC_ERROR_FIELD_REGEX:
+			case ZBX_PREPROC_THROTTLE_VALUE:
+			case ZBX_PREPROC_THROTTLE_TIMED_VALUE:
+			case ZBX_PREPROC_SCRIPT:
+				$on_fail->setEnabled(false);
+				break;
+
+			default:
+				$on_fail->setEnabled(!$readonly);
+
+				if ($step['error_handler'] != ZBX_PREPROC_FAIL_DEFAULT) {
+					$on_fail->setChecked(true);
+				}
+				break;
+		}
+
+		$error_handler = (new CRadioButtonList('preprocessing['.$i.'][error_handler]',
+			($step['error_handler'] == ZBX_PREPROC_FAIL_DEFAULT)
+				? ZBX_PREPROC_FAIL_DISCARD_VALUE
+				: (int) $step['error_handler']
+		))
+			->addValue(_('Discard value'), ZBX_PREPROC_FAIL_DISCARD_VALUE)
+			->addValue(_('Set value to'), ZBX_PREPROC_FAIL_SET_VALUE)
+			->addValue(_('Set error to'), ZBX_PREPROC_FAIL_SET_ERROR)
+			->setModern(true);
+
+		$error_handler_params = (new CTextBox('preprocessing['.$i.'][error_handler_params]',
+			$step['error_handler_params'])
+		)->setTitle($step['error_handler_params']);
+
+		if ($step['error_handler'] == ZBX_PREPROC_FAIL_DEFAULT) {
+			$error_handler->setEnabled(false);
+		}
+
+		if ($step['error_handler'] == ZBX_PREPROC_FAIL_DEFAULT
+				|| $step['error_handler'] == ZBX_PREPROC_FAIL_DISCARD_VALUE) {
+			$error_handler_params
+				->setEnabled(false)
+				->addStyle('display: none;');
+		}
+
+		$on_fail_options = (new CDiv([
+			new CLabel(_('Custom on fail')),
+			$error_handler->setReadonly($readonly),
+			$error_handler_params->setReadonly($readonly)
+		]))->addClass('on-fail-options');
+
+		if ($step['error_handler'] == ZBX_PREPROC_FAIL_DEFAULT) {
+			$on_fail_options->addStyle('display: none;');
+		}
+
+		$preprocessing_list->addItem(
+			(new CListItem([
+				(new CDiv([
+					(new CDiv())
+						->addClass(ZBX_STYLE_DRAG_ICON)
+						->addClass(!$sortable ? ZBX_STYLE_DISABLED : null),
+					(new CDiv($preproc_types_cbbox))
+						->addClass('list-numbered-item')
+						->addClass('step-name'),
+					(new CDiv($params))->addClass('step-parameters'),
+					(new CDiv($on_fail))->addClass('step-on-fail'),
+					(new CDiv([
+						(new CButton('preprocessing['.$i.'][test]', _('Test')))
+							->addClass(ZBX_STYLE_BTN_LINK)
+							->addClass('preprocessing-step-test')
+							->removeId(),
+						(new CButton('preprocessing['.$i.'][remove]', _('Remove')))
+							->addClass(ZBX_STYLE_BTN_LINK)
+							->addClass('element-table-remove')
+							->setEnabled(!$readonly)
+							->removeId()
+					]))->addClass('step-action'),
+				]))->addClass('preprocessing-step'),
+				$on_fail_options
+			]))
+				->addClass('preprocessing-list-item')
+				->addClass('sortable')
+				->setAttribute('data-step', $i)
+		);
+
+		$i++;
+	}
+
+	$preprocessing_list->addItem(
+		(new CListItem([
+			(new CDiv(
+				(new CButton('param_add', _('Add')))
+					->addClass(ZBX_STYLE_BTN_LINK)
+					->addClass('element-table-add')
+					->setEnabled(!$readonly)
+			))->addClass('step-action'),
+			(new CDiv(
+				(new CButton('preproc_test_all', _('Test all steps')))
+					->addClass(ZBX_STYLE_BTN_LINK)
+					->addStyle(($i > 0) ? null : 'display: none')
+			))->addClass('step-action')
+		]))->addClass('preprocessing-list-foot')
+	);
+
+	return $preprocessing_list;
+}
+
 /**
  * Prepares data to copy items/triggers/graphs.
  *
@@ -1425,7 +1692,6 @@ function getCopyElementsFormData($elements_field, $title = null) {
 function getTriggerMassupdateFormData() {
 	$data = [
 		'visible' => getRequest('visible', []),
-		'priority' => getRequest('priority', ''),
 		'dependencies' => getRequest('dependencies', []),
 		'tags' => getRequest('tags', []),
 		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED),
@@ -1476,31 +1742,31 @@ function getTriggerMassupdateFormData() {
 /**
  * Generate data for the trigger configuration form.
  *
- * @param array $data											Trigger data array.
- * @param string $data['form']									Form action.
- * @param string $data['form_refresh']							Form refresh.
- * @param null|string $data['parent_discoveryid']					Parent discovery.
- * @param array $data['dependencies']							Trigger dependencies.
- * @param array $data['db_dependencies']						DB trigger dependencies.
- * @param string $data['triggerid']								Trigger ID.
- * @param string $data['expression']							Trigger expression.
- * @param string $data['recovery_expression']					Trigger recovery expression.
- * @param string $data['expr_temp']								Trigger temporary expression.
- * @param string $data['recovery_expr_temp']					Trigger temporary recovery expression.
- * @param string $data['recovery_mode']							Trigger recovery mode.
- * @param string $data['description']							Trigger description.
- * @param int $data['type']										Trigger problem event generation mode.
- * @param string $data['priority']								Trigger severity.
- * @param int $data['status']									Trigger status.
- * @param string $data['comments']								Trigger description.
- * @param string $data['url']									Trigger URL.
- * @param string $data['expression_constructor']				Trigger expression constructor mode.
- * @param string $data['recovery_expression_constructor']		Trigger recovery expression constructor mode.
- * @param bool $data['limited']									Templated trigger.
- * @param array $data['templates']								Trigger templates.
- * @param string $data['hostid']								Host ID.
- * @param string $data['expression_action']						Trigger expression action.
- * @param string $data['recovery_expression_action']			Trigger recovery expression action.
+ * @param array       $data                                     Trigger data array.
+ * @param string      $data['form']                             Form action.
+ * @param string      $data['form_refresh']                     Form refresh.
+ * @param null|string $data['parent_discoveryid']               Parent discovery ID.
+ * @param array       $data['dependencies']                     Trigger dependencies.
+ * @param array       $data['db_dependencies']                  DB trigger dependencies.
+ * @param string      $data['triggerid']                        Trigger ID.
+ * @param string      $data['expression']                       Trigger expression.
+ * @param string      $data['recovery_expression']              Trigger recovery expression.
+ * @param string      $data['expr_temp']                        Trigger temporary expression.
+ * @param string      $data['recovery_expr_temp']               Trigger temporary recovery expression.
+ * @param string      $data['recovery_mode']                    Trigger recovery mode.
+ * @param string      $data['description']                      Trigger description.
+ * @param int         $data['type']                             Trigger problem event generation mode.
+ * @param string      $data['priority']                         Trigger severity.
+ * @param int         $data['status']                           Trigger status.
+ * @param string      $data['comments']                         Trigger description.
+ * @param string      $data['url']                              Trigger URL.
+ * @param string      $data['expression_constructor']           Trigger expression constructor mode.
+ * @param string      $data['recovery_expression_constructor']  Trigger recovery expression constructor mode.
+ * @param bool        $data['limited']                          Templated trigger.
+ * @param array       $data['templates']                        Trigger templates.
+ * @param string      $data['hostid']                           Host ID.
+ * @param string      $data['expression_action']                Trigger expression action.
+ * @param string      $data['recovery_expression_action']       Trigger recovery expression action.
  *
  * @return array
  */
@@ -1517,8 +1783,12 @@ function getTriggerFormData(array $data) {
 			$options['selectTags'] = ['tag', 'value'];
 		}
 
+		if ($data['show_inherited_tags']) {
+			$options['selectItems'] = ['itemid', 'templateid', 'flags'];
+		}
+
 		if ($data['parent_discoveryid'] === null) {
-			$options['selectDiscoveryRule'] = ['itemid', 'name'];
+			$options['selectDiscoveryRule'] = ['itemid', 'name', 'templateid'];
 			$triggers = API::Trigger()->get($options);
 			$flag = ZBX_FLAG_DISCOVERY_NORMAL;
 		}
@@ -1535,7 +1805,6 @@ function getTriggerFormData(array $data) {
 
 		if (!hasRequest('form_refresh')) {
 			$data['tags'] = $trigger['tags'];
-			CArrayHelper::sort($data['tags'], ['tag', 'value']);
 		}
 
 		// Get templates.
@@ -1543,9 +1812,81 @@ function getTriggerFormData(array $data) {
 			getTriggerParentTemplates([$trigger], $flag), $flag
 		);
 
+		if ($data['show_inherited_tags']) {
+			if ($data['parent_discoveryid'] === null) {
+				if ($trigger['discoveryRule']) {
+					$item_parent_templates = getItemParentTemplates([$trigger['discoveryRule']],
+						ZBX_FLAG_DISCOVERY_RULE
+					)['templates'];
+				}
+				else {
+					$item_parent_templates = getItemParentTemplates($trigger['items'],
+						ZBX_FLAG_DISCOVERY_NORMAL
+					)['templates'];
+				}
+			}
+			else {
+				$items = [];
+				$item_prototypes = [];
+
+				foreach ($trigger['items'] as $item) {
+					if ($item['flags'] == ZBX_FLAG_DISCOVERY_NORMAL) {
+						$items[] = $item;
+					}
+					else {
+						$item_prototypes[] = $item;
+					}
+				}
+
+				$item_parent_templates = getItemParentTemplates($items, ZBX_FLAG_DISCOVERY_NORMAL)['templates']
+					+ getItemParentTemplates($item_prototypes, ZBX_FLAG_DISCOVERY_PROTOTYPE)['templates'];
+			}
+			unset($item_parent_templates[0]);
+
+			$db_templates = $item_parent_templates
+				? API::Template()->get([
+					'output' => ['templateid'],
+					'selectTags' => ['tag', 'value'],
+					'templateids' => array_keys($item_parent_templates),
+					'preservekeys' => true
+				])
+				: [];
+
+			$inherited_tags = [];
+
+			foreach ($item_parent_templates as $templateid => $template) {
+				if (array_key_exists($templateid, $db_templates)) {
+					foreach ($db_templates[$templateid]['tags'] as $tag) {
+						if (!array_key_exists($tag['tag'].':'.$tag['value'], $inherited_tags)) {
+							$inherited_tags[$tag['tag'].':'.$tag['value']] = $tag + [
+								'parent_templates' => [$templateid => $template],
+								'type' => ZBX_PROPERTY_INHERITED
+							];
+						}
+						else {
+							$inherited_tags[$tag['tag'].':'.$tag['value']]['parent_templates'] += [
+								$templateid => $template
+							];
+						}
+					}
+				}
+			}
+
+			foreach ($data['tags'] as $tag) {
+				if (!array_key_exists($tag['tag'].':'.$tag['value'], $inherited_tags)) {
+					$inherited_tags[$tag['tag'].':'.$tag['value']] = $tag + ['type' => ZBX_PROPERTY_OWN];
+				}
+				else {
+					$inherited_tags[$tag['tag'].':'.$tag['value']]['type'] = ZBX_PROPERTY_BOTH;
+				}
+			}
+
+			$data['tags'] = array_values($inherited_tags);
+		}
+
 		$data['limited'] = ($trigger['templateid'] != 0);
 
-		// Select first host from triggers if no matching value is given.
+		// select first host from triggers if gived not match
 		$hosts = $trigger['hosts'];
 		if (count($hosts) > 0 && !in_array(['hostid' => $data['hostid']], $hosts)) {
 			$host = reset($hosts);
@@ -1553,6 +1894,14 @@ function getTriggerFormData(array $data) {
 		}
 	}
 
+	// tags
+	if (!$data['tags']) {
+		$data['tags'][] = ['tag' => '', 'value' => ''];
+	}
+	else {
+		CArrayHelper::sort($data['tags'], ['tag', 'value']);
+	}
+
 	if ($data['hostid'] && (!array_key_exists('groupid', $data) || !$data['groupid'])) {
 		$db_hostgroups = API::HostGroup()->get([
 			'output' => ['groupid'],
@@ -1735,12 +2084,9 @@ function getTriggerFormData(array $data) {
 
 	order_result($data['db_dependencies'], 'description');
 
-	if (!$data['tags']) {
-		$data['tags'][] = ['tag' => '', 'value' => ''];
-	}
-
 	return $data;
 }
+
 /**
  * Get "Maintenance period" form.
  *
@@ -2011,7 +2357,7 @@ function getTimeperiodForm(array $data) {
 								2 => _x('second', 'adjective'),
 								3 => _('third'),
 								4 => _('fourth'),
-								5 => _x('last', 'week of month')
+								5 => _('last')
 							])))
 						)
 						->addRow(
@@ -2115,3 +2461,55 @@ function getTimeperiodForm(array $data) {
 
 	return $form;
 }
+
+/**
+ * Renders tag table row.
+ *
+ * @param int|string $index
+ * @param string     $tag       (optional)
+ * @param string     $value     (optional)
+ * @param bool       $readonly  (optional)
+ *
+ * @return CRow
+ */
+function renderTagTableRow($index, $tag = '', $value = '', $readonly = false) {
+	return (new CRow([
+		(new CTextBox('tags['.$index.'][tag]', $tag, $readonly))
+			->setWidth(ZBX_TEXTAREA_TAG_WIDTH)
+			->setAttribute('placeholder', _('tag')),
+		(new CTextBox('tags['.$index.'][value]', $value, $readonly))
+			->setWidth(ZBX_TEXTAREA_TAG_WIDTH)
+			->setAttribute('placeholder', _('value')),
+		new CCol(
+			(new CButton('tags['.$index.'][remove]', _('Remove')))
+				->addClass(ZBX_STYLE_BTN_LINK)
+				->addClass('element-table-remove')
+				->setEnabled(!$readonly)
+		)
+	]))->addClass('form_row');
+}
+
+/**
+ * Renders tag table.
+ *
+ * @param array  $tags
+ * @param array  $tags[]['tag']
+ * @param array  $tags[]['value']
+ * @param bool   $readonly         (optional)
+ *
+ * @return CTable
+ */
+function renderTagTable(array $tags, $readonly = false) {
+	$table = new CTable();
+
+	foreach ($tags as $index => $tag) {
+		$table->addRow(renderTagTableRow($index, $tag['tag'], $tag['value'], $readonly));
+	}
+
+	return $table->setFooter(new CCol(
+		(new CButton('tag_add', _('Add')))
+			->addClass(ZBX_STYLE_BTN_LINK)
+			->addClass('element-table-add')
+			->setEnabled(!$readonly)
+	));
+}
