@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ function get_cookie($name, $default_value = null) {
 }
 
 function zbx_setcookie($name, $value, $time = null) {
-	setcookie($name, $value, isset($time) ? $time : 0, CSession::getDefaultCookiePath(), null, HTTPS, true);
+	setcookie($name, $value, isset($time) ? $time : 0, null, null, HTTPS, true);
 	$_COOKIE[$name] = $value;
 }
 
@@ -294,7 +294,7 @@ function zbx_date2str($format, $value = null) {
 }
 
 /**
- * Calculates and converts timestamp to string representation.
+ * Calculates and converts timestamp to string represenation.
  *
  * @param int|string $start_date  Start date timestamp.
  * @param int|string $end_date    End date timestamp.
@@ -987,7 +987,7 @@ function zbx_is_int($var) {
 
 /**
  * Look for two arrays field value and create 3 array lists, one with arrays where field value exists only in first array
- * second with arrays where field values are only in second array and both where field values are in both arrays.
+ * second with arrays where field values are only in second array and both where fiel values are in both arrays.
  *
  * @param array  $primary
  * @param array  $secondary
@@ -1086,42 +1086,6 @@ function zbx_formatDomId($value) {
 	return str_replace(['[', ']'], ['_', ''], $value);
 }
 
-/**
- * Sort an array of objects so that the objects whose $column value matches $pattern are at the top.
- * Return the first $limit objects.
- *
- * @param array 	$table		array of objects to sort
- * @param string 	$column		name of the $column to search
- * @param string 	$pattern	string to match the value of $column against
- * @param int		$limit		number of objects to return
- *
- * @return array
- */
-function selectByPattern(array $table, $column, $pattern, $limit) {
-	$chunk_size = $limit;
-
-	$rsTable = [];
-	foreach ($table as $num => $row) {
-		if (mb_strtolower($row[$column]) === mb_strtolower($pattern)) {
-			$rsTable = [$num => $row] + $rsTable;
-		}
-		elseif ($limit > 0) {
-			$rsTable[$num] = $row;
-		}
-		else {
-			continue;
-		}
-		$limit--;
-	}
-
-	if (!empty($rsTable)) {
-		$rsTable = array_chunk($rsTable, $chunk_size, true);
-		$rsTable = $rsTable[0];
-	}
-
-	return $rsTable;
-}
-
 /************* SORT *************/
 function natksort(&$array) {
 	$keys = array_keys($array);
@@ -1373,7 +1337,7 @@ function zbx_toObject($value, $field, $preserve_keys = false) {
  * Converts the given value to a numeric array:
  * - a scalar value will be converted to an array and added as the only element;
  * - an array with first element key containing only numeric characters will be converted to plain zero-based numeric array.
- * This is used for resetting nonsequential numeric arrays;
+ * This is used for reseting nonsequential numeric arrays;
  * - an associative array will be returned in an array as the only element, except if first element key contains only numeric characters.
  *
  * @param mixed $value
@@ -1502,7 +1466,7 @@ function zbx_str2links($text) {
 				if ($pos != $start) {
 					$result[] = mb_substr($line, $start, $pos - $start);
 				}
-				$result[] = new CLink(CHtml::encode($match), $match);
+				$result[] = new CLink(CHTML::encode($match), $match);
 				$start = $pos + mb_strlen($match);
 			}
 		}
@@ -1854,12 +1818,7 @@ function access_deny($mode = ACCESS_DENY_OBJECT) {
 
 		$data['theme'] = getUserTheme(CWebUser::$data);
 
-		if (detect_page_type() == PAGE_TYPE_JS) {
-			(new CView('layout.json', ['main_block' => json_encode(['error' => $data['header']])]))->render();
-		}
-		else {
-			(new CView('general.warning', $data))->render();
-		}
+		(new CView('general.warning', $data))->render();
 		exit;
 	}
 }
@@ -1980,19 +1939,20 @@ function filter_messages(array $messages = []) {
 /**
  * Returns the message box when messages are present; null otherwise
  *
- * @param  boolean	$good			Parameter passed to makeMessageBox to specify message box style.
- * @param  string	$title			Message box title.
- * @global array	$ZBX_MESSAGES
+ * @param  bool    $good            Parameter passed to makeMessageBox to specify message box style.
+ * @param  string  $title           Message box title.
+ * @param  bool    $show_close_box  Show or hide close button in error message box.
+ * @global array   $ZBX_MESSAGES
  *
  * @return CDiv|null
  */
-function getMessages($good = false, $title = null) {
+function getMessages($good = false, $title = null, $show_close_box = true) {
 	global $ZBX_MESSAGES;
 
 	$messages = (isset($ZBX_MESSAGES) && $ZBX_MESSAGES) ? filter_messages($ZBX_MESSAGES) : [];
 
 	$message_box = ($title || $messages)
-		? makeMessageBox($good, $messages, $title)
+		? makeMessageBox($good, $messages, $title, $show_close_box)
 		: null;
 
 	$ZBX_MESSAGES = [];
@@ -2037,6 +1997,15 @@ function show_messages($good = false, $okmsg = null, $errmsg = null) {
 				];
 			}
 			break;
+		case PAGE_TYPE_XML:
+			if ($title !== null) {
+				echo htmlspecialchars($title)."\n";
+			}
+
+			foreach ($messages as $message) {
+				echo '['.$message['type'].'] '.$message['message']."\n";
+			}
+			break;
 		case PAGE_TYPE_HTML:
 		default:
 			if ($title || $messages) {
@@ -2335,14 +2304,23 @@ function get_status() {
 	return $status;
 }
 
-function set_image_header() {
+/**
+ * Set image header.
+ *
+ * @param integer $format    One of IMAGE_FORMAT_* constants. If not set global $IMAGE_FORMAT_DEFAULT will be used.
+ */
+function set_image_header($format = null) {
 	global $IMAGE_FORMAT_DEFAULT;
 
-	switch ($IMAGE_FORMAT_DEFAULT) {
+	switch ($format !== null ? $format : $IMAGE_FORMAT_DEFAULT) {
 		case IMAGE_FORMAT_JPEG:
 			header('Content-type: image/jpeg');
 			break;
 
+		case IMAGE_FORMAT_GIF:
+			header('Content-type: image/gif');
+			break;
+
 		case IMAGE_FORMAT_TEXT:
 			header('Content-type: text/html');
 			break;
