@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -659,6 +659,7 @@ function replace_template_dependencies($deps, $hostid) {
  *
  * @param array  $groupids
  * @param string $application
+ * @param int    $style                               Table display style: either hosts on top or on the left.
  * @param array  $host_options
  * @param array  $trigger_options
  * @param array  $problem_options
@@ -668,8 +669,8 @@ function replace_template_dependencies($deps, $hostid) {
  *
  * @return array
  */
-function getTriggersOverviewData(array $groupids, $application, array $host_options = [], array $trigger_options = [],
-		array $problem_options = []) {
+function getTriggersOverviewData(array $groupids, $application, $style, array $host_options = [],
+		array $trigger_options = [], array $problem_options = []) {
 	$problem_options += [
 		'min_severity' => TRIGGER_SEVERITY_NOT_CLASSIFIED,
 		'show_suppressed' => ZBX_PROBLEM_SUPPRESSED_FALSE,
@@ -690,6 +691,7 @@ function getTriggersOverviewData(array $groupids, $application, array $host_opti
 		'selectHosts' => ['hostid', 'name'],
 		'hostids' => $hostids,
 		'monitored' => true,
+		'skipDependent' => true,
 		'sortfield' => 'description',
 		'selectDependencies' => ['triggerid'],
 		'preservekeys' => true
@@ -727,110 +729,60 @@ function getTriggersOverviewData(array $groupids, $application, array $host_opti
 function getTriggersWithActualSeverity(array $trigger_options, array $problem_options) {
 	$problem_options += [
 		'min_severity' => TRIGGER_SEVERITY_NOT_CLASSIFIED,
-		'show_suppressed' => null,
-		'show_recent' => null,
 		'time_from' => null,
 		'acknowledged' => null
 	];
 
-	$triggers = API::Trigger()->get(['preservekeys' => true] + $trigger_options);
+	$triggers = API::Trigger()->get($trigger_options);
 
-	$nondependent_trigger_options = [
-		'output' => [],
-		'triggerids' => array_keys($triggers),
-		'skipDependent' => true,
-		'preservekeys' => true
-	];
+	$problem_triggerids = [];
 
-	$nondependent_triggers = API::Trigger()->get($nondependent_trigger_options);
-
-	CArrayHelper::sort($triggers, ['description']);
-
-	if ($triggers) {
-		$problem_stats = [];
-
-		foreach ($triggers as $triggerid => &$trigger) {
+	foreach ($triggers as $triggerid => &$trigger) {
+		if ($trigger['value'] == TRIGGER_VALUE_TRUE
+				|| (array_key_exists('only_true', $trigger_options) && $trigger_options['only_true'])) {
+			$problem_triggerids[] = $triggerid;
 			$trigger['priority'] = TRIGGER_SEVERITY_NOT_CLASSIFIED;
-			$trigger['resolved'] = true;
-
-			$problem_stats[$triggerid] = [
-				'has_resolved' => false,
-				'has_unresolved' => false,
-				'has_resolved_unacknowledged' => false,
-				'has_unresolved_unacknowledged' => false
-			];
-
-			if ($trigger['value'] == TRIGGER_VALUE_TRUE && !array_key_exists($triggerid, $nondependent_triggers)) {
-				$trigger['value'] = TRIGGER_VALUE_FALSE;
-			}
 		}
-		unset($trigger);
+	}
+	unset($trigger);
 
+	if ($problem_triggerids) {
 		$problems = API::Problem()->get([
-			'output' => ['eventid', 'acknowledged', 'objectid', 'severity', 'r_eventid'],
-			'objectids' => array_keys($triggers),
+			'output' => ['eventid', 'acknowledged', 'objectid', 'severity'],
+			'objectids' => $problem_triggerids,
 			'suppressed' => ($problem_options['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_FALSE) ? false : null,
-			'recent' => $problem_options['show_recent'],
-			'acknowledged' => $problem_options['acknowledged'],
+			'recent' => array_key_exists('show_recent', $problem_options) ? $problem_options['show_recent'] : null,
+			'acknowledged' => (array_key_exists('acknowledged', $problem_options) && $problem_options['acknowledged'])
+				? false
+				: null,
 			'time_from' => $problem_options['time_from']
 		]);
 
+		$objectids = [];
+
 		foreach ($problems as $problem) {
-			$triggerid = $problem['objectid'];
-
-			if ($problem['r_eventid'] == 0 && array_key_exists($triggerid, $nondependent_triggers)) {
-				$triggers[$triggerid]['resolved'] = false;
-			}
-
-			$triggers[$triggerid]['problem']['eventid'] = $problem['eventid'];
-
-			if ($triggers[$triggerid]['priority'] < $problem['severity']) {
-				$triggers[$triggerid]['priority'] = $problem['severity'];
-			}
-
-			if ($problem['r_eventid'] == 0) {
-				$problem_stats[$triggerid]['has_unresolved'] = true;
-				if ($problem['acknowledged'] == 0 && $problem['severity'] >= $problem_options['min_severity']) {
-					$problem_stats[$triggerid]['has_unresolved_unacknowledged'] = true;
-				}
-			}
-			else {
-				$problem_stats[$triggerid]['has_resolved'] = true;
-				if ($problem['acknowledged'] == 0 && $problem['severity'] >= $problem_options['min_severity']) {
-					$problem_stats[$triggerid]['has_resolved_unacknowledged'] = true;
-				}
+			if ($triggers[$problem['objectid']]['priority'] < $problem['severity']) {
+				$triggers[$problem['objectid']]['priority'] = $problem['severity'];
+				$triggers[$problem['objectid']]['problem']['eventid'] = $problem['eventid'];
+				$triggers[$problem['objectid']]['problem']['acknowledged'] = $problem['acknowledged'];
 			}
+			$objectids[$problem['objectid']] = true;
 		}
 
-		foreach ($triggers as $triggerid => &$trigger) {
-			$stats = $problem_stats[$triggerid];
-
-			$trigger['problem']['acknowledged'] = (
-				// Trigger has only resolved problems, all acknowledged.
-				($stats['has_resolved'] && !$stats['has_resolved_unacknowledged'] && !$stats['has_unresolved'])
-					// Trigger has unresolved problems, all acknowledged.
-					|| ($stats['has_unresolved'] && !$stats['has_unresolved_unacknowledged'])
-			) ? 1 : 0;
-
-			$trigger['value'] = ($triggers[$triggerid]['resolved'] === true)
-				? TRIGGER_VALUE_FALSE
-				: TRIGGER_VALUE_TRUE;
-
-			if (($stats['has_resolved'] || $stats['has_unresolved'])
-					&& $trigger['priority'] >= $problem_options['min_severity']) {
+		foreach ($triggers as $triggerid => $trigger) {
+			if (array_key_exists($triggerid, $objectids) && $trigger['priority'] >= $problem_options['min_severity']) {
 				continue;
 			}
 
 			if (!array_key_exists('only_true', $trigger_options)
 					|| ($trigger_options['only_true'] === null && $trigger_options['filter']['value'] === null)) {
 				// Overview type = 'Data', Maps, Dasboard or Overview 'show any' mode.
-				$trigger['value'] = TRIGGER_VALUE_FALSE;
+				$triggers[$triggerid]['value'] = TRIGGER_VALUE_FALSE;
 			}
 			else {
 				unset($triggers[$triggerid]);
 			}
 		}
-		unset($trigger);
 	}
 
 	return $triggers;
@@ -897,9 +849,11 @@ function getTriggersOverview(array $hosts, array $triggers, $pageFile, $viewMode
 				'triggerid' => $trigger['triggerid'],
 				'value' => $trigger['value'],
 				'lastchange' => $trigger['lastchange'],
-				'priority' => $trigger['priority'],
-				'problem' => $trigger['problem']
+				'priority' => $trigger['priority']
 			];
+			if (array_key_exists('problem', $trigger)) {
+				$trigger_data['problem'] = $trigger['problem'];
+			}
 
 			$data[$trigger_name][$trcounter[$host['name']][$trigger_name]][$host['name']] = $trigger_data;
 			$trcounter[$host['name']][$trigger_name]++;
@@ -1001,12 +955,16 @@ function getTriggerOverviewCells($trigger, $dependencies, $pageFile, $screenid =
 
 		// problem trigger
 		if ($trigger['value'] == TRIGGER_VALUE_TRUE) {
-			$eventid = $trigger['problem']['eventid'];
-			$acknowledge = ['backurl' => ($screenid !== null) ? $pageFile.'?screenid='.$screenid : $pageFile];
-		}
+			$ack = null;
 
-		if ($trigger['problem']['acknowledged'] == 1) {
-			$ack = (new CSpan())->addClass(ZBX_STYLE_ICON_ACKN);
+			if (array_key_exists('problem', $trigger)) {
+				$eventid = $trigger['problem']['eventid'];
+				$acknowledge = ['backurl' => ($screenid !== null) ? $pageFile.'?screenid='.$screenid : $pageFile];
+
+				if ($trigger['problem']['acknowledged'] == 1) {
+					$ack = (new CSpan())->addClass(ZBX_STYLE_ICON_ACKN);
+				}
+			}
 		}
 
 		$desc = array_key_exists($trigger['triggerid'], $dependencies)
@@ -1249,7 +1207,6 @@ function make_trigger_details($trigger) {
 		->addRow([
 			new CCol(_('Trigger')),
 			new CCol((new CLinkAction(CMacrosResolverHelper::resolveTriggerName($trigger)))
-				->addClass(ZBX_STYLE_WORDWRAP)
 				->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid']))
 			)
 		])
@@ -1983,7 +1940,7 @@ function get_item_function_info($expr) {
 	}
 
 	switch (true) {
-		case ($expression->hasTokenOfType(CTriggerExprParserResult::TOKEN_TYPE_MACRO)):
+		case ($expression->hasTokenOfType(CTriggerExpressionParserResult::TOKEN_TYPE_MACRO)):
 			$result = [
 				'type' => T_ZBX_STR,
 				'value_type' => $rule_0or1[0],
@@ -1991,8 +1948,8 @@ function get_item_function_info($expr) {
 			];
 			break;
 
-		case ($expression->hasTokenOfType(CTriggerExprParserResult::TOKEN_TYPE_USER_MACRO)):
-		case ($expression->hasTokenOfType(CTriggerExprParserResult::TOKEN_TYPE_LLD_MACRO)):
+		case ($expression->hasTokenOfType(CTriggerExpressionParserResult::TOKEN_TYPE_USER_MACRO)):
+		case ($expression->hasTokenOfType(CTriggerExpressionParserResult::TOKEN_TYPE_LLD_MACRO)):
 			$result = [
 				'type' => T_ZBX_STR,
 				'value_type' => $rule_float[0],
@@ -2000,7 +1957,7 @@ function get_item_function_info($expr) {
 			];
 			break;
 
-		case ($expression->hasTokenOfType(CTriggerExprParserResult::TOKEN_TYPE_FUNCTION_MACRO)):
+		case ($expression->hasTokenOfType(CTriggerExpressionParserResult::TOKEN_TYPE_FUNCTION_MACRO)):
 			$expr_part = reset($expr_data->expressions);
 
 			if (!array_key_exists($expr_part['functionName'], $functions)) {
@@ -2109,14 +2066,14 @@ function evalExpressionData($expression, $replaceFunctionMacros) {
 		$value = $token['value'];
 
 		switch ($token['type']) {
-			case CTriggerExprParserResult::TOKEN_TYPE_OPERATOR:
+			case CTriggerExpressionParserResult::TOKEN_TYPE_OPERATOR:
 				// replace specific operators with their PHP analogues
 				if (isset($replaceOperators[$token['value']])) {
 					$value = $replaceOperators[$token['value']];
 				}
 
 				break;
-			case CTriggerExprParserResult::TOKEN_TYPE_NUMBER:
+			case CTriggerExpressionParserResult::TOKEN_TYPE_NUMBER:
 				// convert numeric values with suffixes
 				if ($token['data']['suffix'] !== null) {
 					$value = convert($value);
@@ -2550,7 +2507,7 @@ function makeTriggerTemplatePrefix($triggerid, array $parent_templates, $flag) {
 			// ZBX_FLAG_DISCOVERY_NORMAL
 			else {
 				$url = (new CUrl('triggers.php'))
-					->setArgument('hostid', $template['hostid'])
+					->setArgument('filter_hostids', [$template['hostid']])
 					->setArgument('filter_set', 1);
 			}
 
@@ -2654,6 +2611,35 @@ function isReadableTriggers(array $triggerids) {
 	]);
 }
 
+/**
+ * Get last problems by given trigger IDs.
+ *
+ * @param array $triggerids
+ * @param array $output         List of output fields.
+ *
+ * @return array
+ */
+function getTriggerLastProblems(array $triggerids, array $output) {
+	$problems = DBfetchArray(DBselect(
+		'SELECT '.implode(',e.', $output).
+		' FROM events e'.
+		' JOIN ('.
+			'SELECT e2.source,e2.object,e2.objectid,MAX(clock) AS clock'.
+			' FROM events e2'.
+			' WHERE e2.source='.EVENT_SOURCE_TRIGGERS.
+				' AND e2.object='.EVENT_OBJECT_TRIGGER.
+				' AND e2.value='.TRIGGER_VALUE_TRUE.
+				' AND '.dbConditionInt('e2.objectid', $triggerids).
+			' GROUP BY e2.source,e2.object,e2.objectid'.
+		') e3 ON e3.source=e.source'.
+			' AND e3.object=e.object'.
+			' AND e3.objectid=e.objectid'.
+			' AND e3.clock=e.clock'
+	));
+
+	return $problems;
+}
+
 /**
  * Returns a list of the trigger dependencies.
  *
