@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -168,8 +168,6 @@ struct	_DC_TRIGGER;
 #	define ITEM_HEADERS_LEN		65535
 #endif
 
-#define APPLICATION_NAME_LEN		255
-
 #define HISTORY_STR_VALUE_LEN		255
 #ifdef HAVE_IBM_DB2
 #	define HISTORY_TEXT_VALUE_LEN	2048
@@ -191,6 +189,7 @@ struct	_DC_TRIGGER;
 #define GRAPH_ITEM_COLOR_LEN_MAX	(GRAPH_ITEM_COLOR_LEN + 1)
 
 #define DSERVICE_VALUE_LEN		255
+#define MAX_DISCOVERED_VALUE_SIZE	(DSERVICE_VALUE_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1)
 
 #define HTTPTEST_HTTP_USER_LEN		64
 #define HTTPTEST_HTTP_PASSWORD_LEN	64
@@ -238,11 +237,8 @@ struct	_DC_TRIGGER;
 #	define	DBend_multiple_update(sql, sql_alloc, sql_offset)	do {} while (0)
 
 #	define	ZBX_SQL_EXEC_FROM	0
-#	ifdef HAVE_MYSQL
-#		define	ZBX_SQL_STRCMP		"%s binary '%s'"
-#	else
-#		define	ZBX_SQL_STRCMP		"%s'%s'"
-#	endif
+
+#	define	ZBX_SQL_STRCMP		"%s'%s'"
 #	define	ZBX_SQL_STRVAL_EQ(str)	"=", str
 #	define	ZBX_SQL_STRVAL_NE(str)	"<>", str
 #endif
@@ -333,12 +329,11 @@ typedef struct
 	int			severity;
 	unsigned char		suppressed;
 
-	zbx_vector_ptr_t	tags;
+	zbx_vector_ptr_t	tags;	/* used for both zbx_tag_t and zbx_host_tag_t */
 
 #define ZBX_FLAGS_DB_EVENT_UNSET		0x0000
 #define ZBX_FLAGS_DB_EVENT_CREATE		0x0001
 #define ZBX_FLAGS_DB_EVENT_NO_ACTION		0x0002
-#define ZBX_FLAGS_DB_EVENT_RECOVER		0x0004
 	zbx_uint64_t		flags;
 }
 DB_EVENT;
@@ -364,6 +359,18 @@ typedef struct
 }
 DB_MEDIATYPE;
 
+typedef struct
+{
+	zbx_uint64_t	conditionid;
+	zbx_uint64_t	actionid;
+	char		*value;
+	char		*value2;
+	int		condition_result;
+	unsigned char	conditiontype;
+	unsigned char	op;
+}
+DB_CONDITION;
+
 typedef struct
 {
 	zbx_uint64_t	alertid;
@@ -471,8 +478,6 @@ DB_ACKNOWLEDGE;
 int	DBinit(char **error);
 void	DBdeinit(void);
 
-void	DBinit_autoincrement_options(void);
-
 int	DBconnect(int flag);
 void	DBclose(void);
 
@@ -544,8 +549,8 @@ typedef struct
 }
 zbx_trigger_diff_t;
 
-void	zbx_process_triggers(zbx_vector_ptr_t *triggers, zbx_vector_ptr_t *trigger_diff);
-void	zbx_db_save_trigger_changes(const zbx_vector_ptr_t *trigger_diff);
+void	zbx_process_triggers(zbx_vector_ptr_t *triggers, zbx_vector_ptr_t *diffs);
+void	zbx_db_save_trigger_changes(const zbx_vector_ptr_t *diffs);
 void	zbx_trigger_diff_free(zbx_trigger_diff_t *diff);
 void	zbx_append_trigger_diff(zbx_vector_ptr_t *trigger_diff, zbx_uint64_t triggerid, unsigned char priority,
 		zbx_uint64_t flags, unsigned char value, unsigned char state, int lastchange, const char *error);
@@ -603,7 +608,7 @@ void	DBregister_host_clean(zbx_vector_ptr_t *autoreg_hosts);
 void	DBproxy_register_host(const char *host, const char *ip, const char *dns, unsigned short port,
 		const char *host_metadata);
 int	DBexecute_overflowed_sql(char **sql, size_t *sql_alloc, size_t *sql_offset);
-char	*DBget_unique_hostname_by_sample(const char *host_name_sample);
+char	*DBget_unique_hostname_by_sample(const char *host_name_sample, const char *field_name);
 
 const char	*DBsql_id_ins(zbx_uint64_t id);
 const char	*DBsql_id_cmp(zbx_uint64_t id);
@@ -628,22 +633,17 @@ int	DBindex_exists(const char *table_name, const char *index_name);
 int	DBexecute_multiple_query(const char *query, const char *field_name, zbx_vector_uint64_t *ids);
 int	DBlock_record(const char *table, zbx_uint64_t id, const char *add_field, zbx_uint64_t add_id);
 int	DBlock_records(const char *table, const zbx_vector_uint64_t *ids);
+int	DBlock_ids(const char *table_name, const char *field_name, zbx_vector_uint64_t *ids);
 
 #define DBlock_hostid(id)			DBlock_record("hosts", id, NULL, 0)
 #define DBlock_druleid(id)			DBlock_record("drules", id, NULL, 0)
 #define DBlock_dcheckid(dcheckid, druleid)	DBlock_record("dchecks", dcheckid, "druleid", druleid)
-#define DBlock_graphid(id)			DBlock_record("graphs", id, NULL, 0)
 #define DBlock_hostids(ids)			DBlock_records("hosts", ids)
-#define DBlock_triggerids(ids)			DBlock_records("triggers", ids)
-#define DBlock_itemids(ids)			DBlock_records("items", ids)
-#define DBlock_group_prototypeids(ids)		DBlock_records("group_prototype", ids)
 
 void	DBdelete_groups(zbx_vector_uint64_t *groupids);
 
 void	DBselect_uint64(const char *sql, zbx_vector_uint64_t *ids);
 
-void	DBcheck_character_set(void);
-
 /* bulk insert support */
 
 /* database bulk insert data */
@@ -770,4 +770,19 @@ zbx_proxy_diff_t;
 
 int	zbx_db_lock_maintenanceids(zbx_vector_uint64_t *maintenanceids);
 
+void	zbx_db_save_item_changes(char **sql, size_t *sql_alloc, size_t *sql_offset, const zbx_vector_ptr_t *item_diff);
+
+/* mock field to estimate how much data can be stored in characters, bytes or both, */
+/* depending on database backend                                                    */
+
+typedef struct
+{
+	int	bytes_num;
+	int	chars_num;
+}
+zbx_db_mock_field_t;
+
+void	zbx_db_mock_field_init(zbx_db_mock_field_t *field, int field_type, int field_len);
+int	zbx_db_mock_field_append(zbx_db_mock_field_t *field, const char *text);
+
 #endif
