@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@
 	#define zbx_sleep(sec) sleep((sec))
 
 	#define zbx_thread_kill(h) kill(h, SIGUSR2)
-	#define zbx_thread_kill_fatal(h) kill(h, SIGHUP)
+	#define zbx_thread_kill_fatal(h) kill(h, SIGABRT)
 #endif	/* _WINDOWS */
 
 typedef struct
