@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,17 +24,13 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"25 September 2023"
+#define ZABBIX_REVDATE		"29 July 2019"
 #define ZABBIX_VERSION_MAJOR	4
-#define ZABBIX_VERSION_MINOR	0
-#define ZABBIX_VERSION_PATCH	49
-#ifndef ZABBIX_VERSION_REVISION
-#	define ZABBIX_VERSION_REVISION	cbbcb2bf47d
-#endif
+#define ZABBIX_VERSION_MINOR	2
+#define ZABBIX_VERSION_PATCH	5
+#define ZABBIX_VERSION_REVISION	2c0e4d1d39
 #ifdef _WINDOWS
-#	ifndef ZABBIX_VERSION_RC_NUM
-#		define ZABBIX_VERSION_RC_NUM	2400
-#	endif
+#	define ZABBIX_VERSION_RC_NUM	1400
 #endif
 #define ZABBIX_VERSION_RC	""
 #define ZABBIX_VERSION		ZBX_STR(ZABBIX_VERSION_MAJOR) "." ZBX_STR(ZABBIX_VERSION_MINOR) "." \
