@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@
 	(										\
 			memcpy(&value_len, buffer, sizeof(zbx_uint32_t)),		\
 			0 < value_len ? (						\
-			*value = (char *)zbx_malloc(NULL, (zbx_uint64_t)value_len + 1),	\
+			*value = (char *)zbx_malloc(NULL, value_len + 1),			\
 			memcpy(*(value), buffer + sizeof(zbx_uint32_t), value_len),	\
 			(*value)[value_len] = '\0'					\
 			) : (*value = NULL, 0),						\
@@ -103,4 +103,14 @@
 #define zbx_deserialize_value(buffer, value) \
 	(memcpy(value, buffer, sizeof(*value)), sizeof(*value))
 
-#endif /* ZABBIX_SERIALIZE_H */
+/* length prefixed binary data */
+#define zbx_deserialize_bin(buffer, value, value_len)					\
+	(										\
+		memcpy(&value_len, buffer, sizeof(zbx_uint32_t)),			\
+		*value = (void *)zbx_malloc(NULL, value_len + sizeof(zbx_uint32_t)),	\
+		memcpy(*(value), buffer, value_len + sizeof(zbx_uint32_t)),		\
+		value_len + sizeof(zbx_uint32_t)					\
+	)
+#endif
+
+/* ZABBIX_SERIALIZE_H */
