@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -362,6 +362,7 @@ static int	zbx_socket_connect(zbx_socket_t *s, const struct sockaddr *addr, sock
 #ifdef _WINDOWS
 	u_long		mode = 1;
 	FD_SET		fdw, fde;
+	int		res;
 	struct timeval	tv, *ptv;
 #endif
 	if (0 != timeout)
@@ -395,7 +396,7 @@ static int	zbx_socket_connect(zbx_socket_t *s, const struct sockaddr *addr, sock
 		return FAIL;
 	}
 
-	if (-1 == select(0, NULL, &fdw, &fde, ptv))
+	if (-1 == (res = select(0, NULL, &fdw, &fde, ptv)))
 	{
 		*error = zbx_strdup(*error, strerror_from_system(zbx_socket_last_error()));
 		return FAIL;
@@ -470,8 +471,6 @@ static int	zbx_socket_create(zbx_socket_t *s, int type, const char *source_ip, c
 	char		service[8], *error = NULL;
 	void		(*func_socket_close)(zbx_socket_t *s);
 
-	zbx_socket_clean(s);
-
 	if (SOCK_DGRAM == type && (ZBX_TCP_SEC_TLS_CERT == tls_connect || ZBX_TCP_SEC_TLS_PSK == tls_connect))
 	{
 		THIS_SHOULD_NEVER_HAPPEN;
@@ -490,6 +489,7 @@ static int	zbx_socket_create(zbx_socket_t *s, int type, const char *source_ip, c
 		return FAIL;
 	}
 #endif
+	zbx_socket_clean(s);
 
 	zbx_snprintf(service, sizeof(service), "%hu", port);
 	memset(&hints, 0x00, sizeof(struct addrinfo));
@@ -575,7 +575,7 @@ static int	zbx_socket_create(zbx_socket_t *s, int type, const char *source_ip, c
 		int timeout, unsigned int tls_connect, const char *tls_arg1, const char *tls_arg2)
 {
 	ZBX_SOCKADDR	servaddr_in;
-	struct addrinfo	hints, *ai;
+	struct hostent	*hp;
 	char		*error = NULL;
 	void		(*func_socket_close)(zbx_socket_t *s);
 
@@ -599,21 +599,17 @@ static int	zbx_socket_create(zbx_socket_t *s, int type, const char *source_ip, c
 #endif
 	zbx_socket_clean(s);
 
-	memset(&hints, 0, sizeof(hints));
-	hints.ai_family = AF_INET;
-	hints.ai_socktype = type;
-
-	if (0 != getaddrinfo(ip, NULL, &hints, &ai))
+	if (NULL == (hp = gethostbyname(ip)))
 	{
 #ifdef _WINDOWS
-		zbx_set_socket_strerror("getaddrinfo() failed for '%s': %s",
+		zbx_set_socket_strerror("gethostbyname() failed for '%s': %s",
 				ip, strerror_from_system(WSAGetLastError()));
 #else
 #ifdef HAVE_HSTRERROR
-		zbx_set_socket_strerror("getaddrinfo() failed for '%s': [%d] %s",
+		zbx_set_socket_strerror("gethostbyname() failed for '%s': [%d] %s",
 				ip, h_errno, hstrerror(h_errno));
 #else
-		zbx_set_socket_strerror("getaddrinfo() failed for '%s': [%d]",
+		zbx_set_socket_strerror("gethostbyname() failed for '%s': [%d]",
 				ip, h_errno);
 #endif
 #endif
@@ -621,11 +617,9 @@ static int	zbx_socket_create(zbx_socket_t *s, int type, const char *source_ip, c
 	}
 
 	servaddr_in.sin_family = AF_INET;
-	servaddr_in.sin_addr = ((struct sockaddr_in *)ai->ai_addr)->sin_addr;
+	servaddr_in.sin_addr.s_addr = ((struct in_addr *)(hp->h_addr))->s_addr;
 	servaddr_in.sin_port = htons(port);
 
-	freeaddrinfo(ai);
-
 	if (ZBX_SOCKET_ERROR == (s->socket = socket(AF_INET, type | SOCK_CLOEXEC, 0)))
 	{
 		zbx_set_socket_strerror("cannot create socket [[%s]:%hu]: %s",
@@ -767,7 +761,6 @@ static ssize_t	zbx_tcp_write(zbx_socket_t *s, const char *buf, size_t len)
  ******************************************************************************/
 
 #define ZBX_TCP_HEADER_DATA	"ZBXD"
-#define ZBX_TCP_HEADER		ZBX_TCP_HEADER_DATA ZBX_TCP_HEADER_VERSION
 #define ZBX_TCP_HEADER_LEN	ZBX_CONST_STRLEN(ZBX_TCP_HEADER_DATA)
 
 int	zbx_tcp_send_ext(zbx_socket_t *s, const char *data, size_t len, unsigned char flags, int timeout)
@@ -1574,8 +1567,7 @@ const char	*zbx_tcp_recv_line(zbx_socket_t *s)
 		}
 		else
 		{
-			if (0 != (left = (NULL == ptr ? ZBX_TCP_LINE_LEN - s->read_bytes :
-					MIN(ZBX_TCP_LINE_LEN - s->read_bytes, (size_t)(ptr - buffer)))))
+			if (0 != (left = MIN(ZBX_TCP_LINE_LEN - s->read_bytes, (size_t)(ptr - buffer))))
 			{
 				/* fill the string to the defined limit */
 				zbx_strncpy_alloc(&s->buffer, &alloc, &offset, buffer, left);
@@ -1667,8 +1659,6 @@ ssize_t	zbx_tcp_recv_ext(zbx_socket_t *s, int timeout)
 #define ZBX_TCP_EXPECT_LENGTH		4
 #define ZBX_TCP_EXPECT_SIZE		5
 
-	const char	*__function_name = "zbx_tcp_recv_ext";
-
 	ssize_t		nbytes;
 	size_t		buf_dyn_bytes = 0, buf_stat_bytes = 0, offset = 0;
 	zbx_uint32_t	expected_len = 16 * ZBX_MEBIBYTE, reserved = 0;
@@ -1830,7 +1820,7 @@ ssize_t	zbx_tcp_recv_ext(zbx_socket_t *s, int timeout)
 				s->read_bytes = reserved;
 
 				zabbix_log(LOG_LEVEL_TRACE, "%s(): received " ZBX_FS_SIZE_T " bytes with"
-						" compression ratio %.1f", __function_name,
+						" compression ratio %.1f", __func__,
 						(zbx_fs_size_t)(buf_stat_bytes + buf_dyn_bytes),
 						(double)reserved / (buf_stat_bytes + buf_dyn_bytes));
 			}
@@ -2003,15 +1993,7 @@ static int	subnet_match(int af, unsigned int prefix_size, const void *address1,
 	return SUCCEED;
 }
 
-#ifndef HAVE_IPV6
-static int	zbx_ip_cmp(unsigned int prefix_size, const struct addrinfo *current_ai, ZBX_SOCKADDR name)
-{
-	struct sockaddr_in	*name4 = (struct sockaddr_in *)&name,
-				*ai_addr4 = (struct sockaddr_in *)current_ai->ai_addr;
-
-	return subnet_match(current_ai->ai_family, prefix_size, &name4->sin_addr.s_addr, &ai_addr4->sin_addr.s_addr);
-}
-#else
+#ifdef HAVE_IPV6
 static int	zbx_ip_cmp(unsigned int prefix_size, const struct addrinfo *current_ai, ZBX_SOCKADDR name)
 {
 	/* Network Byte Order is ensured */
@@ -2083,6 +2065,7 @@ static int	zbx_ip_cmp(unsigned int prefix_size, const struct addrinfo *current_a
 				break;
 		}
 	}
+
 	return FAIL;
 }
 #endif
@@ -2167,7 +2150,11 @@ int	zbx_tcp_check_allowed_peers(const zbx_socket_t *s, const char *peer_list)
 
 	for (start = tmp; '\0' != *start;)
 	{
+#ifdef HAVE_IPV6
 		struct addrinfo	hints, *ai = NULL, *current_ai;
+#else
+		struct hostent	*hp;
+#endif /* HAVE_IPV6 */
 
 		prefix_size = -1;
 
@@ -2183,6 +2170,11 @@ int	zbx_tcp_check_allowed_peers(const zbx_socket_t *s, const char *peer_list)
 				*cidr_sep = '/';	/* CIDR is only supported for IP */
 		}
 
+		/* When adding IPv6 support it was decided to leave current implementation   */
+		/* (based on gethostbyname()) for handling non-IPv6-enabled components. In   */
+		/* the future it should be considered to switch completely to getaddrinfo(). */
+
+#ifdef HAVE_IPV6
 		memset(&hints, 0, sizeof(hints));
 		hints.ai_family = AF_UNSPEC;
 		hints.ai_socktype = SOCK_STREAM;
@@ -2208,7 +2200,25 @@ int	zbx_tcp_check_allowed_peers(const zbx_socket_t *s, const char *peer_list)
 			}
 			freeaddrinfo(ai);
 		}
+#else
+		if (NULL != (hp = gethostbyname(start)))
+		{
+			int	i;
 
+			for (i = 0; NULL != hp->h_addr_list[i]; i++)
+			{
+				if (-1 == prefix_size)
+					prefix_size = IPV4_MAX_CIDR_PREFIX;
+
+				if (SUCCEED == subnet_match(AF_INET, prefix_size,
+						&((struct in_addr *)hp->h_addr_list[i])->s_addr,
+						&s->peer_info.sin_addr.s_addr))
+				{
+					return SUCCEED;
+				}
+			}
+		}
+#endif	/* HAVE_IPV6 */
 		if (NULL != end)
 			start = end + 1;
 		else
@@ -2311,3 +2321,35 @@ void	zbx_udp_close(zbx_socket_t *s)
 	zbx_socket_free(s);
 	zbx_socket_close(s->socket);
 }
+
+#if !defined(_WINDOWS) && defined(HAVE_RESOLV_H)
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_update_resolver_conf                                         *
+ *                                                                            *
+ * Purpose: react to "/etc/resolv.conf" update                                *
+ *                                                                            *
+ * Comments: it is intended to call this function in the end of each process  *
+ *           main loop. The purpose of calling it at the end (instead of the  *
+ *           beginning of main loop) is to let the first initialization of    *
+ *           libc resolver proceed internally.                                *
+ *                                                                            *
+ ******************************************************************************/
+void	zbx_update_resolver_conf(void)
+{
+#define ZBX_RESOLV_CONF_FILE	"/etc/resolv.conf"
+
+	static time_t	mtime = 0;
+	zbx_stat_t	buf;
+
+	if (0 == zbx_stat(ZBX_RESOLV_CONF_FILE, &buf) && mtime != buf.st_mtime)
+	{
+		mtime = buf.st_mtime;
+
+		if (0 != res_init())
+			zabbix_log(LOG_LEVEL_WARNING, "zbx_update_resolver_conf(): res_init() failed");
+	}
+
+#undef ZBX_RESOLV_CONF_FILE
+}
+#endif
