@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -101,9 +101,27 @@ typedef struct
 	unsigned char		queue_priority;
 	unsigned char		schedulable;
 	unsigned char		update_triggers;
+	zbx_uint64_t		templateid;
+	zbx_uint64_t		parent_itemid; /* from joined item_discovery table */
 }
 ZBX_DC_ITEM;
 
+typedef struct
+{
+	zbx_uint64_t		itemid;
+	zbx_uint64_t		hostid;
+	zbx_uint64_t		templateid;
+}
+ZBX_DC_TEMPLATE_ITEM;
+
+typedef struct
+{
+	zbx_uint64_t		itemid;
+	zbx_uint64_t		hostid;
+	zbx_uint64_t		templateid;
+}
+ZBX_DC_PROTOTYPE_ITEM;
+
 typedef struct
 {
 	zbx_uint64_t	hostid;
@@ -117,7 +135,6 @@ typedef struct
 	zbx_uint64_t	itemid;
 	const char	*units;
 	unsigned char	trends;
-	int		trends_sec;
 }
 ZBX_DC_NUMITEM;
 
@@ -156,6 +173,7 @@ typedef struct
 	zbx_uint64_t	itemid;
 	zbx_uint64_t	master_itemid;
 	zbx_uint64_t	last_master_itemid;
+	unsigned char	flags;
 }
 ZBX_DC_DEPENDENTITEM;
 
@@ -222,14 +240,15 @@ ZBX_DC_CALCITEM;
 
 typedef struct
 {
-	zbx_uint64_t		itemid;
-	zbx_vector_uint64_t	dep_itemids;
+	zbx_uint64_t			itemid;
+	zbx_vector_uint64_pair_t	dep_itemids;
 }
 ZBX_DC_MASTERITEM;
 
 typedef struct
 {
 	zbx_uint64_t		itemid;
+	int			update_time;
 	zbx_vector_ptr_t	preproc_ops;
 }
 ZBX_DC_PREPROCITEM;
@@ -262,8 +281,6 @@ typedef struct
 }
 ZBX_DC_HTTPITEM;
 
-typedef zbx_item_history_value_t	ZBX_DC_DELTAITEM;
-
 #if defined(HAVE_POLARSSL) || defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
 typedef struct
 {
@@ -490,6 +507,7 @@ typedef struct
 	int		default_inventory_mode;
 	int		refresh_unsupported;
 	unsigned char	snmptrap_logging;
+	const char	*db_extension;
 	/* housekeeping related configuration data */
 	zbx_config_hk_t	hk;
 }
@@ -544,6 +562,23 @@ typedef struct
 }
 zbx_dc_trigger_tag_t;
 
+typedef struct
+{
+	zbx_uint64_t	hosttagid;
+	zbx_uint64_t	hostid;
+	const char	*tag;
+	const char	*value;
+}
+zbx_dc_host_tag_t;
+
+typedef struct
+{
+	zbx_uint64_t		hostid;
+	zbx_vector_ptr_t	tags;
+		/* references to zbx_dc_host_tag_t records cached in config-> host_tags hashset */
+}
+zbx_dc_host_tag_index_t;
+
 typedef struct
 {
 	const char	*tag;
@@ -630,8 +665,10 @@ typedef struct
 	zbx_uint64_t	item_preprocid;
 	zbx_uint64_t	itemid;
 	int		step;
+	int		error_handler;
 	unsigned char	type;
 	const char	*params;
+	const char	*error_handler_params;
 }
 zbx_dc_preproc_op_t;
 
@@ -692,8 +729,6 @@ typedef struct
 	int			sync_ts;
 	int			item_sync_ts;
 
-	unsigned int		internal_actions;		/* number of enabled internal actions */
-
 	/* maintenance processing management */
 	unsigned char		maintenance_update;		/* flag to trigger maintenance update by timers  */
 	zbx_uint64_t		*maintenance_update_flags;	/* Array of flags to manage timer maintenance updates.*/
@@ -704,6 +739,8 @@ typedef struct
 
 	zbx_hashset_t		items;
 	zbx_hashset_t		items_hk;		/* hostid, key */
+	zbx_hashset_t		template_items;		/* template items selected from items table */
+	zbx_hashset_t		prototype_items;	/* item prototypes selected from items table */
 	zbx_hashset_t		numitems;
 	zbx_hashset_t		snmpitems;
 	zbx_hashset_t		ipmiitems;
@@ -727,7 +764,10 @@ typedef struct
 	zbx_hashset_t		hosts_p;		/* for searching proxies by 'host' name */
 	zbx_hashset_t		proxies;
 	zbx_hashset_t		host_inventories;
-	zbx_hashset_t		host_inventories_auto;	/* for caching of automatically populated host inventories */
+	zbx_hashset_t		host_inventories_auto;	/* For caching of automatically populated host inventories. */
+	 	 	 	 	 	 	/* Configuration syncer will read host_inventories without  */
+							/* locking cache and therefore it cannot be updated by      */
+							/* by history syncers when new data is received.	    */
 	zbx_hashset_t		ipmihosts;
 	zbx_hashset_t		htmpls;
 	zbx_hashset_t		gmacros;
@@ -743,6 +783,8 @@ typedef struct
 	zbx_hashset_t		actions;
 	zbx_hashset_t		action_conditions;
 	zbx_hashset_t		trigger_tags;
+	zbx_hashset_t		host_tags;
+	zbx_hashset_t		host_tags_index;		/* host tag index by hostid */
 	zbx_hashset_t		correlations;
 	zbx_hashset_t		corr_conditions;
 	zbx_hashset_t		corr_operations;
@@ -760,7 +802,6 @@ typedef struct
 	zbx_binary_heap_t	queues[ZBX_POLLER_TYPE_COUNT];
 	zbx_binary_heap_t	pqueue;
 	zbx_binary_heap_t	timer_queue;
-	zbx_vector_uint64_t	locked_lld_ruleids;	/* for keeping track of lld rules being processed */
 	ZBX_DC_CONFIG_TABLE	*config;
 	ZBX_DC_STATUS		*status;
 	zbx_hashset_t		strpool;
