@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,20 +29,6 @@
 
 extern int		CONFIG_TIMER_FORKS;
 
-typedef struct
-{
-	zbx_uint64_t			hostid;
-	const zbx_dc_maintenance_t	*maintenance;
-}
-zbx_host_maintenance_t;
-
-typedef struct
-{
-	zbx_uint64_t		hostid;
-	zbx_vector_ptr_t	maintenances;
-}
-zbx_host_event_maintenance_t;
-
 /******************************************************************************
  *                                                                            *
  * Function: DCsync_maintenances                                              *
@@ -61,8 +47,6 @@ zbx_host_event_maintenance_t;
  ******************************************************************************/
 void	DCsync_maintenances(zbx_dbsync_t *sync)
 {
-	const char		*__function_name = "DCsync_maintenances";
-
 	char			**row;
 	zbx_uint64_t		rowid;
 	unsigned char		tag;
@@ -70,7 +54,7 @@ void	DCsync_maintenances(zbx_dbsync_t *sync)
 	zbx_dc_maintenance_t	*maintenance;
 	int			found, ret;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	while (SUCCEED == (ret = zbx_dbsync_next(sync, &rowid, &row, &tag)))
 	{
@@ -122,7 +106,7 @@ void	DCsync_maintenances(zbx_dbsync_t *sync)
 		zbx_hashset_remove_direct(&config->maintenances, maintenance);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -158,8 +142,6 @@ static int	dc_compare_maintenance_tags(const void *d1, const void *d2)
  ******************************************************************************/
 void	DCsync_maintenance_tags(zbx_dbsync_t *sync)
 {
-	const char			*__function_name = "DCsync_maintenance_tags";
-
 	char				**row;
 	zbx_uint64_t			rowid;
 	unsigned char			tag;
@@ -169,7 +151,7 @@ void	DCsync_maintenance_tags(zbx_dbsync_t *sync)
 	zbx_vector_ptr_t		maintenances;
 	int				found, ret, index, i;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	zbx_vector_ptr_create(&maintenances);
 
@@ -244,7 +226,7 @@ void	DCsync_maintenance_tags(zbx_dbsync_t *sync)
 
 	zbx_vector_ptr_destroy(&maintenances);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -270,8 +252,6 @@ void	DCsync_maintenance_tags(zbx_dbsync_t *sync)
  ******************************************************************************/
 void	DCsync_maintenance_periods(zbx_dbsync_t *sync)
 {
-	const char			*__function_name = "DCsync_maintenance_periods";
-
 	char				**row;
 	zbx_uint64_t			rowid;
 	unsigned char			tag;
@@ -280,7 +260,7 @@ void	DCsync_maintenance_periods(zbx_dbsync_t *sync)
 	zbx_dc_maintenance_t		*maintenance;
 	int				found, ret, index;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	while (SUCCEED == (ret = zbx_dbsync_next(sync, &rowid, &row, &tag)))
 	{
@@ -338,7 +318,7 @@ void	DCsync_maintenance_periods(zbx_dbsync_t *sync)
 		zbx_hashset_remove_direct(&config->maintenance_periods, period);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -356,8 +336,6 @@ void	DCsync_maintenance_periods(zbx_dbsync_t *sync)
  ******************************************************************************/
 void	DCsync_maintenance_groups(zbx_dbsync_t *sync)
 {
-	const char		*__function_name = "DCsync_maintenance_groups";
-
 	char			**row;
 	zbx_uint64_t		rowid;
 	unsigned char		tag;
@@ -365,7 +343,7 @@ void	DCsync_maintenance_groups(zbx_dbsync_t *sync)
 	int			index, ret;
 	zbx_uint64_t		last_maintenanceid = 0, maintenanceid, groupid;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	while (SUCCEED == (ret = zbx_dbsync_next(sync, &rowid, &row, &tag)))
 	{
@@ -413,7 +391,7 @@ void	DCsync_maintenance_groups(zbx_dbsync_t *sync)
 		zbx_vector_uint64_remove_noorder(&maintenance->groupids, index);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -431,8 +409,6 @@ void	DCsync_maintenance_groups(zbx_dbsync_t *sync)
  ******************************************************************************/
 void	DCsync_maintenance_hosts(zbx_dbsync_t *sync)
 {
-	const char		*__function_name = "DCsync_maintenance_hosts";
-
 	char			**row;
 	zbx_uint64_t		rowid;
 	unsigned char		tag;
@@ -441,7 +417,7 @@ void	DCsync_maintenance_hosts(zbx_dbsync_t *sync)
 	int			index, ret, i;
 	zbx_uint64_t		last_maintenanceid, maintenanceid, hostid;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	zbx_vector_ptr_create(&maintenances);
 
@@ -504,32 +480,7 @@ void	DCsync_maintenance_hosts(zbx_dbsync_t *sync)
 
 	zbx_vector_ptr_destroy(&maintenances);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: dc_substract_time                                                *
- *                                                                            *
- * Purpose: substract two local times with DST correction                     *
- *                                                                            *
- * Parameter: minuend       - [IN] the minuend time                           *
- *            subtrahend    - [IN] the subtrahend time (may be negative)      *
- *            tm            - [OUT] the struct tm                             *
- *                                                                            *
- * Return value: the resulting time difference in seconds                     *
- *                                                                            *
- ******************************************************************************/
-static time_t dc_substract_time(time_t minuend, int subtrahend, struct tm *tm)
-{
-	time_t	diff, offset_min, offset_diff;
-
-	offset_min = zbx_get_timezone_offset(minuend, tm);
-	diff = minuend - subtrahend;
-	offset_diff = zbx_get_timezone_offset(diff, tm);
-	diff -= offset_diff - offset_min;
-
-	return diff;
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -542,8 +493,8 @@ static time_t dc_substract_time(time_t minuend, int subtrahend, struct tm *tm)
  *            period        - [IN] the maintenance period                     *
  *            start_date    - [IN] the period starting timestamp based on     *
  *                                 current time                               *
- *            running_since - [OUT] the actual period starting timestamp      *
- *            running_until - [OUT] the actual period ending timestamp        *
+ *            running_since - [IN] the actual period starting timestamp       *
+ *            running_since - [IN] the actual period ending timestamp         *
  *                                                                            *
  * Return value: SUCCEED - a valid period was found                           *
  *               FAIL    - period started before maintenance activation time  *
@@ -554,7 +505,7 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 		time_t *running_until)
 {
 	int		day, wday, week;
-	struct tm	tm;
+	struct tm	*tm;
 	time_t		active_since = maintenance->active_since;
 
 	if (TIMEPERIOD_TYPE_ONETIME == period->type)
@@ -573,23 +524,23 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 			if (start_date < active_since)
 				return FAIL;
 
-			tm = *localtime(&active_since);
-			active_since = dc_substract_time(active_since,
-					tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec, &tm);
+			tm = localtime(&active_since);
+			active_since = active_since - (tm->tm_hour * SEC_PER_HOUR + tm->tm_min * SEC_PER_MIN +
+					tm->tm_sec);
 
 			day = (start_date - active_since) / SEC_PER_DAY;
-			start_date = dc_substract_time(start_date, SEC_PER_DAY * (day % period->every), &tm);
+			start_date -= SEC_PER_DAY * (day % period->every);
 			break;
 		case TIMEPERIOD_TYPE_WEEKLY:
 			if (start_date < active_since)
 				return FAIL;
 
-			tm = *localtime(&active_since);
-			wday = (0 == tm.tm_wday ? 7 : tm.tm_wday) - 1;
-			active_since = dc_substract_time(active_since, wday * SEC_PER_DAY +
-					tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec, &tm);
+			tm = localtime(&active_since);
+			wday = (0 == tm->tm_wday ? 7 : tm->tm_wday) - 1;
+			active_since = active_since - (wday * SEC_PER_DAY + tm->tm_hour * SEC_PER_HOUR +
+					tm->tm_min * SEC_PER_MIN + tm->tm_sec);
 
-			for (; start_date >= active_since; start_date = dc_substract_time(start_date, SEC_PER_DAY, &tm))
+			for (; start_date >= active_since; start_date -= SEC_PER_DAY)
 			{
 				/* check for every x week(s) */
 				week = (start_date - active_since) / SEC_PER_WEEK;
@@ -597,8 +548,8 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 					continue;
 
 				/* check for day of the week */
-				tm = *localtime(&start_date);
-				wday = (0 == tm.tm_wday ? 7 : tm.tm_wday) - 1;
+				tm = localtime(&start_date);
+				wday = (0 == tm->tm_wday ? 7 : tm->tm_wday) - 1;
 				if (0 == (period->dayofweek & (1 << wday)))
 					continue;
 
@@ -606,32 +557,32 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 			}
 			break;
 		case TIMEPERIOD_TYPE_MONTHLY:
-			for (; start_date >= active_since; start_date = dc_substract_time(start_date, SEC_PER_DAY, &tm))
+			for (; start_date >= active_since; start_date -= SEC_PER_DAY)
 			{
 				/* check for month */
-				tm = *localtime(&start_date);
-				if (0 == (period->month & (1 << tm.tm_mon)))
+				tm = localtime(&start_date);
+				if (0 == (period->month & (1 << tm->tm_mon)))
 					continue;
 
 				if (0 != period->day)
 				{
 					/* check for day of the month */
-					if (period->day != tm.tm_mday)
+					if (period->day != tm->tm_mday)
 						continue;
 				}
 				else
 				{
 					/* check for day of the week */
-					wday = (0 == tm.tm_wday ? 7 : tm.tm_wday) - 1;
+					wday = (0 == tm->tm_wday ? 7 : tm->tm_wday) - 1;
 					if (0 == (period->dayofweek & (1 << wday)))
 						continue;
 
 					/* check for number of day (first, second, third, fourth or last) */
-					day = (tm.tm_mday - 1) / 7 + 1;
+					day = (tm->tm_mday - 1) / 7 + 1;
 					if (5 == period->every && 4 == day)
 					{
-						if (tm.tm_mday + 7 <= zbx_day_in_month(1900 + tm.tm_year,
-								tm.tm_mon + 1))
+						if (tm->tm_mday + 7 <= zbx_day_in_month(1900 + tm->tm_year,
+								tm->tm_mon + 1))
 						{
 							continue;
 						}
@@ -658,58 +609,6 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 	return SUCCEED;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: dc_check_maintenance_period                                      *
- *                                                                            *
- * Purpose: calculates start time for the specified maintenance period and    *
- *          checks if we are inside the maintenance period                    *
- *                                                                            *
- * Parameter: maintenance   - [IN] the maintenance                            *
- *            period        - [IN] the maintenance period                     *
- *            now           - [IN] current time                               *
- *            running_since - [OUT] the actual period starting timestamp      *
- *            running_until - [OUT] the actual period ending timestamp        *
- *                                                                            *
- * Return value: SUCCEED - current time is inside valid maintenance period    *
- *               FAIL    - current time is outside valid maintenance period   *
- *                                                                            *
- ******************************************************************************/
-static int	dc_check_maintenance_period(const zbx_dc_maintenance_t *maintenance,
-		const zbx_dc_maintenance_period_t *period, time_t now, time_t *running_since, time_t *running_until)
-{
-	struct tm	tm;
-	int		seconds, rc, ret = FAIL;
-	time_t		period_start, period_end;
-
-	tm = *localtime(&now);
-	seconds = tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec;
-	period_start = dc_substract_time(now, seconds, &tm);
-	period_start = dc_substract_time(period_start, -period->start_time, &tm);
-
-	tm = *localtime(&period_start);
-
-	/* skip maintenance if the time does not exist due to DST */
-	if (period->start_time != (tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec))
-	{
-		goto out;
-	}
-
-	if (now < period_start)
-		period_start = dc_substract_time(period_start, SEC_PER_DAY, &tm);
-
-	rc = dc_calculate_maintenance_period(maintenance, period, period_start, &period_start, &period_end);
-
-	if (SUCCEED == rc && period_start <= now && now < period_end)
-	{
-		*running_since = period_start;
-		*running_until = period_end;
-		ret = SUCCEED;
-	}
-out:
-	return ret;
-}
-
 /******************************************************************************
  *                                                                            *
  * Function: zbx_dc_maintenance_set_update_flags                              *
@@ -839,18 +738,19 @@ out:
  ******************************************************************************/
 int	zbx_dc_update_maintenances(void)
 {
-	const char			*__function_name = "zbx_dc_update_maintenances";
-
 	zbx_dc_maintenance_t		*maintenance;
 	zbx_dc_maintenance_period_t	*period;
 	zbx_hashset_iter_t		iter;
-	int				i, running_num = 0, started_num = 0, stopped_num = 0, ret = FAIL;
+	int				i, running_num = 0, seconds, rc, started_num = 0, stopped_num = 0, ret = FAIL;
 	unsigned char			state;
+	struct tm			*tm;
 	time_t				now, period_start, period_end, running_since, running_until;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	now = time(NULL);
+	tm = localtime(&now);
+	seconds = tm->tm_hour * SEC_PER_HOUR + tm->tm_min * SEC_PER_MIN + tm->tm_sec;
 
 	WRLOCK_CACHE;
 
@@ -874,8 +774,14 @@ int	zbx_dc_update_maintenances(void)
 			{
 				period = (zbx_dc_maintenance_period_t *)maintenance->periods.values[i];
 
-				if (SUCCEED == dc_check_maintenance_period(maintenance, period, now, &period_start,
-						&period_end))
+				period_start = now - seconds + period->start_time;
+				if (seconds < period->start_time)
+					period_start -= SEC_PER_DAY;
+
+				rc = dc_calculate_maintenance_period(maintenance, period, period_start, &period_start,
+						&period_end);
+
+				if (SUCCEED == rc && period_start <= now && now < period_end)
 				{
 					state = ZBX_MAINTENANCE_RUNNING;
 					if (period_end > running_until)
@@ -933,7 +839,7 @@ int	zbx_dc_update_maintenances(void)
 
 	UNLOCK_CACHE;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() started:%d stopped:%d running:%d", __function_name,
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() started:%d stopped:%d running:%d", __func__,
 			started_num, stopped_num, running_num);
 
 	return ret;
@@ -941,132 +847,81 @@ int	zbx_dc_update_maintenances(void)
 
 /******************************************************************************
  *                                                                            *
- * Function: dc_assign_maintenance_to_host                                    *
+ * Function: dc_get_maintenances_by_ids                                       *
  *                                                                            *
- * Purpose: assign maintenance to a host, host can only be in one maintenance *
- *                                                                            *
- * Parameters: host_maintenances - [OUT] host with maintenance                *
- *             maintenance       - [IN] maintenance that host is in           *
- *             hostid            - [IN] ID of the host                        *
+ * Purpose: get maintenances by identifiers                                   *
  *                                                                            *
  ******************************************************************************/
-static void	dc_assign_maintenance_to_host(zbx_hashset_t *host_maintenances, zbx_dc_maintenance_t *maintenance,
-		zbx_uint64_t hostid)
-{
-	zbx_host_maintenance_t	*host_maintenance, host_maintenance_local;
-
-	if (NULL == (host_maintenance = (zbx_host_maintenance_t *)zbx_hashset_search(host_maintenances, &hostid)))
-	{
-		host_maintenance_local.hostid = hostid;
-		host_maintenance_local.maintenance = maintenance;
-
-		zbx_hashset_insert(host_maintenances, &host_maintenance_local, sizeof(host_maintenance_local));
-	}
-	else if (MAINTENANCE_TYPE_NORMAL == host_maintenance->maintenance->type &&
-			MAINTENANCE_TYPE_NODATA == maintenance->type)
-	{
-		host_maintenance->maintenance = maintenance;
-	}
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: dc_assign_event_maintenance_to_host                              *
- *                                                                            *
- * Purpose: assign maintenance to a host that event belongs to, events can be *
- *          in multiple maintenances at a time                                *
- *                                                                            *
- * Parameters: host_event_maintenances - [OUT] host with maintenances         *
- *             maintenance             - [IN] maintenance that host is in     *
- *             hostid                  - [IN] ID of the host                  *
- *                                                                            *
- ******************************************************************************/
-static void	dc_assign_event_maintenance_to_host(zbx_hashset_t *host_event_maintenances,
-		zbx_dc_maintenance_t *maintenance, zbx_uint64_t hostid)
-{
-	zbx_host_event_maintenance_t	*host_event_maintenance, host_event_maintenance_local;
-
-	if (NULL == (host_event_maintenance = (zbx_host_event_maintenance_t *)zbx_hashset_search(
-			host_event_maintenances, &hostid)))
-	{
-		host_event_maintenance_local.hostid = hostid;
-		zbx_vector_ptr_create(&host_event_maintenance_local.maintenances);
-		zbx_vector_ptr_append(&host_event_maintenance_local.maintenances, maintenance);
-
-		zbx_hashset_insert(host_event_maintenances, &host_event_maintenance_local,
-				sizeof(host_event_maintenance_local));
-		return;
-	}
-
-	zbx_vector_ptr_append(&host_event_maintenance->maintenances, maintenance);
-}
-
-typedef void	(*assign_maintenance_to_host_f)(zbx_hashset_t *host_maintenances,
-		zbx_dc_maintenance_t *maintenance, zbx_uint64_t hostid);
-
-/******************************************************************************
- *                                                                            *
- * Function: dc_get_host_maintenances_by_ids                                  *
- *                                                                            *
- * Purpose: get hosts and their maintenances                                  *
- *                                                                            *
- * Parameters: maintenanceids    - [IN] the maintenance ids                   *
- *             host_maintenances - [OUT] the maintenances running on hosts    *
- *             cb                - [IN] callback function                     *
- *                                                                            *
- ******************************************************************************/
-static void	dc_get_host_maintenances_by_ids(const zbx_vector_uint64_t *maintenanceids,
-		zbx_hashset_t *host_maintenances, assign_maintenance_to_host_f cb)
+static void	dc_get_maintenances_by_ids(const zbx_vector_uint64_t *maintenanceids, zbx_vector_ptr_t *maintenances)
 {
 	zbx_dc_maintenance_t	*maintenance;
-	int			i, j;
-	zbx_vector_uint64_t	groupids;
+	int			i;
 
-	zbx_vector_uint64_create(&groupids);
 
 	for (i = 0; i < maintenanceids->values_num; i++)
 	{
-		if (NULL == (maintenance = (zbx_dc_maintenance_t *)zbx_hashset_search(&config->maintenances,
+		if (NULL != (maintenance = (zbx_dc_maintenance_t *)zbx_hashset_search(&config->maintenances,
 				&maintenanceids->values[i])))
 		{
-			continue;
+			zbx_vector_ptr_append(maintenances, maintenance);
 		}
 
-		for (j = 0; j < maintenance->hostids.values_num; j++)
-			cb(host_maintenances, maintenance, maintenance->hostids.values[j]);
+	}
+}
 
-		if (0 != maintenance->groupids.values_num)	/* hosts groups */
+/******************************************************************************
+ *                                                                            *
+ * Function: dc_maintenance_match_host                                        *
+ *                                                                            *
+ * Purpose: check if the host must be processed by the specified maintenance  *
+ *                                                                            *
+ * Parameters: maintenance - [IN] the maintenance                             *
+ *             hostid      - [IN] identifier of the host to check             *
+ *                                                                            *
+ * Return value: SUCCEED - the host must be processed by the maintenance      *
+ *               FAIL    - otherwise                                          *
+ *                                                                            *
+ ******************************************************************************/
+static int	dc_maintenance_match_host(const zbx_dc_maintenance_t *maintenance, zbx_uint64_t hostid)
+{
+	int	ret = FAIL;
+
+	if (FAIL != zbx_vector_uint64_bsearch(&maintenance->hostids, hostid, ZBX_DEFAULT_UINT64_COMPARE_FUNC))
+		return SUCCEED;
+
+	if (0 != maintenance->groupids.values_num)
+	{
+		int			i;
+		zbx_dc_hostgroup_t	*group;
+		zbx_vector_uint64_t	groupids;
+
+		zbx_vector_uint64_create(&groupids);
+
+		for (i = 0; i < maintenance->groupids.values_num; i++)
+			dc_get_nested_hostgroupids(maintenance->groupids.values[i], &groupids);
+
+		zbx_vector_uint64_sort(&groupids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+		zbx_vector_uint64_uniq(&groupids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+
+		for (i = 0; i < groupids.values_num; i++)
 		{
-			zbx_dc_hostgroup_t	*group;
-
-			for (j = 0; j < maintenance->groupids.values_num; j++)
-				dc_get_nested_hostgroupids(maintenance->groupids.values[j], &groupids);
-
-			zbx_vector_uint64_sort(&groupids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
-			zbx_vector_uint64_uniq(&groupids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
-
-			for (j = 0; j < groupids.values_num; j++)
+			if (NULL == (group = (zbx_dc_hostgroup_t *)zbx_hashset_search(&config->hostgroups,
+					&groupids.values[i])))
 			{
-				zbx_hashset_iter_t	iter;
-				zbx_uint64_t		*phostid;
-
-				if (NULL == (group = (zbx_dc_hostgroup_t *)zbx_hashset_search(&config->hostgroups,
-						&groupids.values[j])))
-				{
-					continue;
-				}
-
-				zbx_hashset_iter_reset(&group->hostids, &iter);
-
-				while (NULL != (phostid = (zbx_uint64_t *)zbx_hashset_iter_next(&iter)))
-					cb(host_maintenances, maintenance, *phostid);
+				continue;
 			}
 
-			zbx_vector_uint64_clear(&groupids);
+			if (NULL != zbx_hashset_search(&group->hostids, &hostid))
+			{
+				ret = SUCCEED;
+				break;
+			}
 		}
+
+		zbx_vector_uint64_destroy(&groupids);
 	}
 
-	zbx_vector_uint64_destroy(&groupids);
+	return ret;
 }
 
 /******************************************************************************
@@ -1075,20 +930,20 @@ static void	dc_get_host_maintenances_by_ids(const zbx_vector_uint64_t *maintenan
  *                                                                            *
  * Purpose: gets maintenance updates for all hosts                            *
  *                                                                            *
- * Parameters: host_maintenances - [IN] the maintenances running on hosts     *
- *             updates           - [OUT] updates to be applied                *
+ * Parameters: maintenances - [IN] the running maintenances                   *
+ *             updates      - [OUT] updates to be applied                     *
  *                                                                            *
  ******************************************************************************/
-static void	dc_get_host_maintenance_updates(zbx_hashset_t *host_maintenances, zbx_vector_ptr_t *updates)
+static void	dc_get_host_maintenance_updates(const zbx_vector_ptr_t *maintenances, zbx_vector_ptr_t *updates)
 {
 	zbx_hashset_iter_t		iter;
 	ZBX_DC_HOST			*host;
-	int				maintenance_from;
+	const zbx_dc_maintenance_t	*maintenance;
+	int				i, maintenance_from;
 	unsigned char			maintenance_status, maintenance_type;
 	zbx_uint64_t			maintenanceid;
 	zbx_host_maintenance_diff_t	*diff;
 	unsigned int			flags;
-	const zbx_host_maintenance_t	*host_maintenance;
 
 	zbx_hashset_iter_reset(&config->hosts, &iter);
 	while (NULL != (host = (ZBX_DC_HOST *)zbx_hashset_iter_next(&iter)))
@@ -1096,23 +951,30 @@ static void	dc_get_host_maintenance_updates(zbx_hashset_t *host_maintenances, zb
 		if (HOST_STATUS_PROXY_ACTIVE == host->status || HOST_STATUS_PROXY_PASSIVE == host->status)
 			continue;
 
-		if (NULL != (host_maintenance = zbx_hashset_search(host_maintenances, &host->hostid)))
-		{
-			maintenance_status = HOST_MAINTENANCE_STATUS_ON;
-			maintenance_type = host_maintenance->maintenance->type;
-			maintenanceid = host_maintenance->maintenance->maintenanceid;
-			maintenance_from = host_maintenance->maintenance->running_since;
-		}
-		else
-		{
-			maintenance_status = HOST_MAINTENANCE_STATUS_OFF;
-			maintenance_type = MAINTENANCE_TYPE_NORMAL;
-			maintenanceid = 0;
-			maintenance_from = 0;
-		}
-
+		maintenance_status = HOST_MAINTENANCE_STATUS_OFF;
+		maintenance_type = MAINTENANCE_TYPE_NORMAL;
+		maintenanceid = 0;
+		maintenance_from = 0;
 		flags = 0;
 
+		for (i = 0; i < maintenances->values_num; i++)
+		{
+			maintenance = (const zbx_dc_maintenance_t *)maintenances->values[i];
+
+			if (SUCCEED == dc_maintenance_match_host(maintenance, host->hostid))
+			{
+				if (0 == maintenanceid ||
+						(MAINTENANCE_TYPE_NORMAL == maintenance_type &&
+						MAINTENANCE_TYPE_NODATA == maintenance->type))
+				{
+					maintenance_status = HOST_MAINTENANCE_STATUS_ON;
+					maintenance_type = maintenance->type;
+					maintenanceid = maintenance->maintenanceid;
+					maintenance_from = maintenance->running_since;
+				}
+			}
+		}
+
 		if (maintenanceid != host->maintenanceid)
 			flags |= ZBX_FLAG_HOST_MAINTENANCE_UPDATE_MAINTENANCEID;
 
@@ -1219,27 +1081,26 @@ void	zbx_dc_flush_host_maintenance_updates(const zbx_vector_ptr_t *updates)
  ******************************************************************************/
 void	zbx_dc_get_host_maintenance_updates(const zbx_vector_uint64_t *maintenanceids, zbx_vector_ptr_t *updates)
 {
-	const char	*__function_name = "zbx_dc_get_host_maintenance_updates";
-	zbx_hashset_t	host_maintenances;
+	zbx_vector_ptr_t	maintenances;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	zbx_hashset_create(&host_maintenances, maintenanceids->values_num, ZBX_DEFAULT_UINT64_HASH_FUNC,
-			ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+	zbx_vector_ptr_create(&maintenances);
+	zbx_vector_ptr_reserve(&maintenances, 100);
 
 	RDLOCK_CACHE;
 
-	dc_get_host_maintenances_by_ids(maintenanceids, &host_maintenances, dc_assign_maintenance_to_host);
+	dc_get_maintenances_by_ids(maintenanceids, &maintenances);
 
 	/* host maintenance update must be performed even without running maintenances */
 	/* to reset host maintenances status for stopped maintenances                  */
-	dc_get_host_maintenance_updates(&host_maintenances, updates);
+	dc_get_host_maintenance_updates(&maintenances, updates);
 
 	UNLOCK_CACHE;
 
-	zbx_hashset_destroy(&host_maintenances);
+	zbx_vector_ptr_destroy(&maintenances);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() updates:%d", __function_name, updates->values_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() updates:%d", __func__, updates->values_num);
 }
 
 /******************************************************************************
@@ -1466,11 +1327,6 @@ static int	dc_compare_tags(const void *d1, const void *d2)
 	return strcmp(tag1->tag, tag2->tag);
 }
 
-static void	host_event_maintenance_clean(zbx_host_event_maintenance_t *host_event_maintenance)
-{
-	zbx_vector_ptr_destroy(&host_event_maintenance->maintenances);
-}
-
 /******************************************************************************
  *                                                                            *
  * Function: zbx_dc_get_event_maintenances                                    *
@@ -1487,23 +1343,21 @@ static void	host_event_maintenance_clean(zbx_host_event_maintenance_t *host_even
  ******************************************************************************/
 int	zbx_dc_get_event_maintenances(zbx_vector_ptr_t *event_queries, const zbx_vector_uint64_t *maintenanceids)
 {
-	const char			*__function_name = "zbx_dc_get_event_maintenances";
-	zbx_hashset_t			host_event_maintenances;
+	zbx_vector_ptr_t		maintenances;
 	int				i, j, k, ret = FAIL;
+	zbx_dc_maintenance_t		*maintenance;
 	zbx_event_suppress_query_t	*query;
 	ZBX_DC_ITEM			*item;
 	ZBX_DC_FUNCTION			*function;
 	zbx_vector_uint64_t		hostids;
-	zbx_hashset_iter_t		iter;
-	zbx_host_event_maintenance_t	*host_event_maintenance;
+	zbx_uint64_pair_t		pair;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
+	zbx_vector_ptr_create(&maintenances);
+	zbx_vector_ptr_reserve(&maintenances, 100);
 	zbx_vector_uint64_create(&hostids);
 
-	zbx_hashset_create_ext(&host_event_maintenances, maintenanceids->values_num, ZBX_DEFAULT_UINT64_HASH_FUNC,
-			ZBX_DEFAULT_UINT64_COMPARE_FUNC, (zbx_clean_func_t)host_event_maintenance_clean,
-			ZBX_DEFAULT_MEM_MALLOC_FUNC, ZBX_DEFAULT_MEM_REALLOC_FUNC, ZBX_DEFAULT_MEM_FREE_FUNC);
 	/* event tags must be sorted by name to perform maintenance tag matching */
 
 	for (i = 0; i < event_queries->values_num; i++)
@@ -1515,19 +1369,11 @@ int	zbx_dc_get_event_maintenances(zbx_vector_ptr_t *event_queries, const zbx_vec
 
 	RDLOCK_CACHE;
 
-	dc_get_host_maintenances_by_ids(maintenanceids, &host_event_maintenances, dc_assign_event_maintenance_to_host);
+	dc_get_maintenances_by_ids(maintenanceids, &maintenances);
 
-	if (0 == host_event_maintenances.num_data)
+	if (0 == maintenances.values_num)
 		goto unlock;
 
-	zbx_hashset_iter_reset(&host_event_maintenances, &iter);
-
-	while (NULL != (host_event_maintenance = (zbx_host_event_maintenance_t *)zbx_hashset_iter_next(&iter)))
-	{
-		zbx_vector_ptr_sort(&host_event_maintenance->maintenances, ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC);
-		zbx_vector_ptr_uniq(&host_event_maintenance->maintenances, ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC);
-	}
-
 	for (i = 0; i < event_queries->values_num; i++)
 	{
 		query = (zbx_event_suppress_query_t *)event_queries->values[i];
@@ -1552,39 +1398,24 @@ int	zbx_dc_get_event_maintenances(zbx_vector_ptr_t *event_queries, const zbx_vec
 		zbx_vector_uint64_uniq(&hostids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
 
 		/* find matching maintenances */
-		for (j = 0; j < hostids.values_num; j++)
+		for (j = 0; j < maintenances.values_num; j++)
 		{
-			const zbx_dc_maintenance_t	*maintenance;
+			maintenance = (zbx_dc_maintenance_t *)maintenances.values[j];
 
-			if (NULL == (host_event_maintenance = zbx_hashset_search(&host_event_maintenances,
-					&hostids.values[j])))
-			{
+			if (ZBX_MAINTENANCE_RUNNING != maintenance->state)
 				continue;
-			}
 
-			for (k = 0; k < host_event_maintenance->maintenances.values_num; k++)
+			for (k = 0; k < hostids.values_num; k++)
 			{
-				zbx_uint64_pair_t	pair;
-
-				maintenance = (zbx_dc_maintenance_t *)host_event_maintenance->maintenances.values[k];
-
-				if (ZBX_MAINTENANCE_RUNNING != maintenance->state)
-					continue;
-
-				pair.first = maintenance->maintenanceid;
-
-				if (FAIL != zbx_vector_uint64_pair_search(&query->maintenances, pair,
-						ZBX_DEFAULT_UINT64_COMPARE_FUNC))
+				if (SUCCEED == dc_maintenance_match_host(maintenance, hostids.values[k]) &&
+						SUCCEED == dc_maintenance_match_tags(maintenance, &query->tags))
 				{
-					continue;
+					pair.first = maintenance->maintenanceid;
+					pair.second = maintenance->running_until;
+					zbx_vector_uint64_pair_append(&query->maintenances, pair);
+					ret = SUCCEED;
+					break;
 				}
-
-				if (SUCCEED != dc_maintenance_match_tags(maintenance, &query->tags))
-					continue;
-
-				pair.second = maintenance->running_until;
-				zbx_vector_uint64_pair_append(&query->maintenances, pair);
-				ret = SUCCEED;
 			}
 		}
 
@@ -1594,9 +1425,9 @@ unlock:
 	UNLOCK_CACHE;
 
 	zbx_vector_uint64_destroy(&hostids);
-	zbx_hashset_destroy(&host_event_maintenances);
+	zbx_vector_ptr_destroy(&maintenances);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return ret;
 }
