@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #define ZBX_FLAGS_TRIGGER_CREATE_EVENT										\
 		(ZBX_FLAGS_TRIGGER_CREATE_TRIGGER_EVENT | ZBX_FLAGS_TRIGGER_CREATE_INTERNAL_EVENT)
 
+
 /******************************************************************************
  *                                                                            *
  * Function: zbx_process_trigger                                              *
@@ -68,14 +69,12 @@
  ******************************************************************************/
 static int	zbx_process_trigger(struct _DC_TRIGGER *trigger, zbx_vector_ptr_t *diffs)
 {
-	const char	*__function_name = "zbx_process_trigger";
-
-	const char	*new_error;
-	int		new_state, new_value, ret = FAIL;
-	zbx_uint64_t	flags = ZBX_FLAGS_TRIGGER_DIFF_UNSET, event_flags = ZBX_FLAGS_TRIGGER_CREATE_NOTHING;
+	const char		*new_error;
+	int			new_state, new_value, ret = FAIL;
+	zbx_uint64_t		flags = ZBX_FLAGS_TRIGGER_DIFF_UNSET, event_flags = ZBX_FLAGS_TRIGGER_CREATE_NOTHING;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() triggerid:" ZBX_FS_UI64 " value:%d(%d) new_value:%d",
-			__function_name, trigger->triggerid, trigger->value, trigger->state, trigger->new_value);
+			__func__, trigger->triggerid, trigger->value, trigger->state, trigger->new_value);
 
 	if (TRIGGER_VALUE_UNKNOWN == trigger->new_value)
 	{
@@ -136,7 +135,7 @@ static int	zbx_process_trigger(struct _DC_TRIGGER *trigger, zbx_vector_ptr_t *di
 
 	ret = SUCCEED;
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s flags:" ZBX_FS_UI64, __function_name, zbx_result_string(ret),
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s flags:" ZBX_FS_UI64, __func__, zbx_result_string(ret),
 			flags);
 
 	return ret;
@@ -148,19 +147,17 @@ out:
  *                                                                            *
  * Purpose: save the trigger changes to database                              *
  *                                                                            *
- * Parameters: trigger_diff - [IN] the trigger changeset                      *
+ * Parameters:trigger_diff - [IN] the trigger changeset                       *
  *                                                                            *
  ******************************************************************************/
 void	zbx_db_save_trigger_changes(const zbx_vector_ptr_t *trigger_diff)
 {
-	const char			*__function_name = "zbx_db_save_trigger_changes";
-
 	int				i;
 	char				*sql = NULL;
 	size_t				sql_alloc = 0, sql_offset = 0;
 	const zbx_trigger_diff_t	*diff;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	DBbegin_multiple_update(&sql, &sql_alloc, &sql_offset);
 
@@ -214,7 +211,7 @@ void	zbx_db_save_trigger_changes(const zbx_vector_ptr_t *trigger_diff)
 
 	zbx_free(sql);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -262,11 +259,9 @@ static int	zbx_trigger_topoindex_compare(const void *d1, const void *d2)
  ******************************************************************************/
 void	zbx_process_triggers(zbx_vector_ptr_t *triggers, zbx_vector_ptr_t *trigger_diff)
 {
-	const char	*__function_name = "zbx_process_triggers";
+	int	i;
 
-	int		i;
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() values_num:%d", __function_name, triggers->values_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() values_num:%d", __func__, triggers->values_num);
 
 	if (0 == triggers->values_num)
 		goto out;
@@ -278,7 +273,7 @@ void	zbx_process_triggers(zbx_vector_ptr_t *triggers, zbx_vector_ptr_t *trigger_
 
 	zbx_vector_ptr_sort(trigger_diff, ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC);
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
