@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -138,10 +138,9 @@ static int	zbx_read_from_pipe(HANDLE hRead, char **buf, size_t *buf_size, size_t
  ******************************************************************************/
 static int	zbx_popen(pid_t *pid, const char *command)
 {
-	const char	*__function_name = "zbx_popen";
-	int		fd[2], stdout_orig, stderr_orig;
+	int	fd[2], stdout_orig, stderr_orig;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() command:'%s'", __function_name, command);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() command:'%s'", __func__, command);
 
 	if (-1 == pipe(fd))
 		return -1;
@@ -157,7 +156,7 @@ static int	zbx_popen(pid_t *pid, const char *command)
 	{
 		close(fd[1]);
 
-		zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __function_name, fd[0]);
+		zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __func__, fd[0]);
 
 		return fd[0];
 	}
@@ -169,27 +168,16 @@ static int	zbx_popen(pid_t *pid, const char *command)
 	/* set the child as the process group leader, otherwise orphans may be left after timeout */
 	if (-1 == setpgid(0, 0))
 	{
-		zabbix_log(LOG_LEVEL_ERR, "%s(): failed to create a process group: %s",
-				__function_name, zbx_strerror(errno));
+		zabbix_log(LOG_LEVEL_ERR, "%s(): failed to create a process group: %s", __func__, zbx_strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "%s(): executing script", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s(): executing script", __func__);
 
 	/* preserve stdout and stderr to restore them in case execl() fails */
 
-	if (-1 == (stdout_orig = dup(STDOUT_FILENO)))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "%s(): failed to duplicate stdout: %s",
-				__function_name, zbx_strerror(errno));
-		exit(EXIT_FAILURE);
-	}
-	if (-1 == (stderr_orig = dup(STDERR_FILENO)))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "%s(): failed to duplicate stderr: %s",
-				__function_name, zbx_strerror(errno));
-		exit(EXIT_FAILURE);
-	}
+	stdout_orig = dup(STDOUT_FILENO);
+	stderr_orig = dup(STDERR_FILENO);
 	fcntl(stdout_orig, F_SETFD, FD_CLOEXEC);
 	fcntl(stderr_orig, F_SETFD, FD_CLOEXEC);
 
@@ -232,10 +220,9 @@ static int	zbx_popen(pid_t *pid, const char *command)
  ******************************************************************************/
 static int	zbx_waitpid(pid_t pid, int *status)
 {
-	const char	*__function_name = "zbx_waitpid";
-	int		rc, result;
+	int	rc, result;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	do
 	{
@@ -253,19 +240,19 @@ retry:
 		if (-1 == (rc = waitpid(pid, &result, WUNTRACED)))
 		{
 #endif
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() waitpid failure: %s", __function_name, zbx_strerror(errno));
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() waitpid failure: %s", __func__, zbx_strerror(errno));
 			goto exit;
 		}
 
 		if (WIFEXITED(result))
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() exited, status:%d", __function_name, WEXITSTATUS(result));
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() exited, status:%d", __func__, WEXITSTATUS(result));
 		else if (WIFSIGNALED(result))
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() killed by signal %d", __function_name, WTERMSIG(result));
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() killed by signal %d", __func__, WTERMSIG(result));
 		else if (WIFSTOPPED(result))
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() stopped by signal %d", __function_name, WSTOPSIG(result));
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() stopped by signal %d", __func__, WSTOPSIG(result));
 #ifdef WIFCONTINUED
 		else if (WIFCONTINUED(result))
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() continued", __function_name);
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() continued", __func__);
 #endif
 	}
 	while (!WIFEXITED(result) && !WIFSIGNALED(result));
@@ -273,7 +260,7 @@ exit:
 	if (NULL != status)
 		*status = result;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __function_name, rc);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __func__, rc);
 
 	return rc;
 }
@@ -294,8 +281,7 @@ exit:
  *             flag          - [IN] indicates if exit code must be checked    *
  *                                                                            *
  * Return value: SUCCEED if processed successfully, TIMEOUT_ERROR if          *
- *               timeout occurred, SIG_ERROR if interrupted by signal or FAIL *
- *               otherwise                                                    *
+ *               timeout occurred or FAIL otherwise                           *
  *                                                                            *
  * Author: Alexander Vladishev                                                *
  *                                                                            *
@@ -468,16 +454,7 @@ close:
 		if (-1 == rc || -1 == zbx_waitpid(pid, &status))
 		{
 			if (EINTR == errno)
-			{
-				if (SUCCEED == zbx_alarm_timed_out())
-					ret = TIMEOUT_ERROR;
-				else
-				{
-					ret = SIG_ERROR;
-					zbx_strlcpy(error, "Signal received while executing a shell script.",
-							max_error_len);
-				}
-			}
+				ret = TIMEOUT_ERROR;
 			else
 				zbx_snprintf(error, max_error_len, "zbx_waitpid() failed: %s", zbx_strerror(errno));
 
@@ -505,7 +482,6 @@ close:
 				{
 					zbx_snprintf(error, max_error_len, "Process killed by signal: %d.",
 							WTERMSIG(status));
-					ret = SIG_ERROR;
 				}
 				else
 					zbx_strlcpy(error, "Process terminated unexpectedly.", max_error_len);
@@ -525,8 +501,7 @@ close:
 
 	if (TIMEOUT_ERROR == ret)
 		zbx_strlcpy(error, "Timeout while executing a shell script.", max_error_len);
-
-	if ('\0' != *error)
+	else if ('\0' != *error)
 		zabbix_log(LOG_LEVEL_WARNING, "Failed to execute command \"%s\": %s", command, error);
 
 	if (SUCCEED != ret || NULL == output)
@@ -553,8 +528,6 @@ close:
 int	zbx_execute_nowait(const char *command)
 {
 #ifdef _WINDOWS
-	const char	*__function_name = "zbx_execute_nowait";
-
 	char			*full_command;
 	STARTUPINFO		si;
 	PROCESS_INFORMATION	pi;
@@ -568,7 +541,7 @@ int	zbx_execute_nowait(const char *command)
 	si.cb = sizeof(si);
 	GetStartupInfo(&si);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "%s(): executing [%s]", __function_name, full_command);
+	zabbix_log(LOG_LEVEL_DEBUG, "%s(): executing [%s]", __func__, full_command);
 
 	if (0 == CreateProcess(
 		NULL,		/* no module name (use command line) */
