@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -144,17 +144,17 @@ static int	history_parse_value(struct zbx_json_parse *jp, unsigned char value_ty
 	size_t	value_alloc = 0;
 	int	ret = FAIL;
 
-	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "clock", &value, &value_alloc, NULL))
+	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "clock", &value, &value_alloc))
 		goto out;
 
 	hr->timestamp.sec = atoi(value);
 
-	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "ns", &value, &value_alloc, NULL))
+	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "ns", &value, &value_alloc))
 		goto out;
 
 	hr->timestamp.ns = atoi(value);
 
-	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "value", &value, &value_alloc, NULL))
+	if (SUCCEED != zbx_json_value_by_name_dyn(jp, "value", &value, &value_alloc))
 		goto out;
 
 	hr->value = history_str2value(value, value_type);
@@ -162,22 +162,22 @@ static int	history_parse_value(struct zbx_json_parse *jp, unsigned char value_ty
 	if (ITEM_VALUE_TYPE_LOG == value_type)
 	{
 
-		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "timestamp", &value, &value_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "timestamp", &value, &value_alloc))
 			goto out;
 
 		hr->value.log->timestamp = atoi(value);
 
-		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "logeventid", &value, &value_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "logeventid", &value, &value_alloc))
 			goto out;
 
 		hr->value.log->logeventid = atoi(value);
 
-		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "severity", &value, &value_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "severity", &value, &value_alloc))
 			goto out;
 
 		hr->value.log->severity = atoi(value);
 
-		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "source", &value, &value_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(jp, "source", &value, &value_alloc))
 			goto out;
 
 		hr->value.log->source = zbx_strdup(NULL, value);
@@ -195,10 +195,11 @@ static void	elastic_log_error(CURL *handle, CURLcode error, const char *errbuf)
 {
 	char		http_status[MAX_STRING_LEN];
 	long int	http_code;
+	CURLcode	curl_err;
 
 	if (CURLE_HTTP_RETURNED_ERROR == error)
 	{
-		if (CURLE_OK == curl_easy_getinfo(handle, CURLINFO_RESPONSE_CODE, &http_code))
+		if (CURLE_OK == (curl_err = curl_easy_getinfo(handle, CURLINFO_RESPONSE_CODE, &http_code)))
 			zbx_snprintf(http_status, sizeof(http_status), "HTTP status code: %ld", http_code);
 		else
 			zbx_strlcpy(http_status, "unknown HTTP status code", sizeof(http_status));
@@ -261,15 +262,13 @@ static void	elastic_close(zbx_history_iface_t *hist)
  ******************************************************************************/
 static int	elastic_is_error_present(zbx_httppage_t *page, char **err)
 {
-	const char		*__function_name = "elastic_is_error_present";
-
 	struct zbx_json_parse	jp, jp_values, jp_index, jp_error, jp_items, jp_item;
 	const char		*errors, *p = NULL;
 	char			*index = NULL, *status = NULL, *type = NULL, *reason = NULL;
 	size_t			index_alloc = 0, status_alloc = 0, type_alloc = 0, reason_alloc = 0;
 	int			rc_js = SUCCEED;
 
-	zabbix_log(LOG_LEVEL_TRACE, "%s() raw json: %s", __function_name, ZBX_NULL2EMPTY_STR(page->data));
+	zabbix_log(LOG_LEVEL_TRACE, "%s() raw json: %s", __func__, ZBX_NULL2EMPTY_STR(page->data));
 
 	if (SUCCEED != zbx_json_open(page->data, &jp) || SUCCEED != zbx_json_brackets_open(jp.start, &jp_values))
 		return FAIL;
@@ -285,17 +284,17 @@ static int	elastic_is_error_present(zbx_httppage_t *page, char **err)
 					SUCCEED == zbx_json_brackets_by_name(&jp_item, "index", &jp_index) &&
 					SUCCEED == zbx_json_brackets_by_name(&jp_index, "error", &jp_error))
 			{
-				if (SUCCEED != zbx_json_value_by_name_dyn(&jp_error, "type", &type, &type_alloc, NULL))
+				if (SUCCEED != zbx_json_value_by_name_dyn(&jp_error, "type", &type, &type_alloc))
 					rc_js = FAIL;
-				if (SUCCEED != zbx_json_value_by_name_dyn(&jp_error, "reason", &reason, &reason_alloc, NULL))
+				if (SUCCEED != zbx_json_value_by_name_dyn(&jp_error, "reason", &reason, &reason_alloc))
 					rc_js = FAIL;
 			}
 			else
 				continue;
 
-			if (SUCCEED != zbx_json_value_by_name_dyn(&jp_index, "status", &status, &status_alloc, NULL))
+			if (SUCCEED != zbx_json_value_by_name_dyn(&jp_index, "status", &status, &status_alloc))
 				rc_js = FAIL;
-			if (SUCCEED != zbx_json_value_by_name_dyn(&jp_index, "_index", &index, &index_alloc, NULL))
+			if (SUCCEED != zbx_json_value_by_name_dyn(&jp_index, "_index", &index, &index_alloc))
 				rc_js = FAIL;
 
 			break;
@@ -382,8 +381,6 @@ static void	elastic_writer_release(void)
 static void	elastic_writer_add_iface(zbx_history_iface_t *hist)
 {
 	zbx_elastic_data_t	*data = (zbx_elastic_data_t *)hist->data;
-	CURLoption		opt;
-	CURLcode		err;
 
 	elastic_writer_init();
 
@@ -392,42 +389,22 @@ static void	elastic_writer_add_iface(zbx_history_iface_t *hist)
 		zabbix_log(LOG_LEVEL_ERR, "cannot initialize cURL session");
 		return;
 	}
-
-	if (CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_URL, data->post_url)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_POST, 1L)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_POSTFIELDS, data->buf)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_WRITEFUNCTION,
-					curl_write_cb)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_WRITEDATA,
-					&page_w[hist->value_type].page)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_FAILONERROR, 1L)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_ERRORBUFFER,
-					page_w[hist->value_type].errbuf)))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)opt, curl_easy_strerror(err));
-		goto out;
-	}
-
+	curl_easy_setopt(data->handle, CURLOPT_URL, data->post_url);
+	curl_easy_setopt(data->handle, CURLOPT_POST, 1L);
+	curl_easy_setopt(data->handle, CURLOPT_POSTFIELDS, data->buf);
+	curl_easy_setopt(data->handle, CURLOPT_WRITEFUNCTION, curl_write_cb);
+	curl_easy_setopt(data->handle, CURLOPT_WRITEDATA, &page_w[hist->value_type].page);
+	curl_easy_setopt(data->handle, CURLOPT_FAILONERROR, 1L);
+	curl_easy_setopt(data->handle, CURLOPT_ERRORBUFFER, page_w[hist->value_type].errbuf);
 	*page_w[hist->value_type].errbuf = '\0';
-
-	if (CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_PRIVATE, &page_w[hist->value_type])))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)opt, curl_easy_strerror(err));
-		goto out;
-	}
-
+	curl_easy_setopt(data->handle, CURLOPT_PRIVATE, &page_w[hist->value_type]);
 	page_w[hist->value_type].page.offset = 0;
-
 	if (0 < page_w[hist->value_type].page.alloc)
 		*page_w[hist->value_type].page.data = '\0';
 
 	curl_multi_add_handle(writer.handle, data->handle);
 
 	zbx_vector_ptr_append(&writer.ifaces, hist);
-
-	return;
-out:
-	elastic_close(hist);
 }
 
 /************************************************************************************
@@ -439,21 +416,17 @@ out:
  ************************************************************************************/
 static int	elastic_writer_flush(void)
 {
-	const char		*__function_name = "elastic_writer_flush";
-
 	struct curl_slist	*curl_headers = NULL;
 	int			i, running, previous, msgnum;
 	CURLMsg			*msg;
 	zbx_vector_ptr_t	retries;
-	CURLcode		err;
-	int			ret = SUCCEED;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	/* The writer might be uninitialized only if the history */
 	/* was already flushed. In that case, return SUCCEED */
 	if (0 == writer.initialized)
-		goto end;
+		return SUCCEED;
 
 	zbx_vector_ptr_create(&retries);
 
@@ -464,13 +437,7 @@ static int	elastic_writer_flush(void)
 		zbx_history_iface_t	*hist = (zbx_history_iface_t *)writer.ifaces.values[i];
 		zbx_elastic_data_t	*data = (zbx_elastic_data_t *)hist->data;
 
-		if (CURLE_OK != (err = curl_easy_setopt(data->handle, CURLOPT_HTTPHEADER, curl_headers)))
-		{
-			zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)CURLOPT_HTTPHEADER,
-					curl_easy_strerror(err));
-			ret = FAIL;
-			goto clean;
-		}
+		(void)curl_easy_setopt(data->handle, CURLOPT_HTTPHEADER, curl_headers);
 
 		zabbix_log(LOG_LEVEL_DEBUG, "sending %s", data->buf);
 	}
@@ -515,13 +482,14 @@ try_again:
 				else
 				{
 					char		http_status[MAX_STRING_LEN];
-					long int	response_code;
+					long int	err;
+					CURLcode	curl_err;
 
-					if (CURLE_OK == curl_easy_getinfo(msg->easy_handle,
-							CURLINFO_RESPONSE_CODE, &response_code))
+					if (CURLE_OK == (curl_err = curl_easy_getinfo(msg->easy_handle,
+							CURLINFO_RESPONSE_CODE, &err)))
 					{
 						zbx_snprintf(http_status, sizeof(http_status), "HTTP status code: %ld",
-								response_code);
+								err);
 					}
 					else
 					{
@@ -556,7 +524,7 @@ try_again:
 					&& SUCCEED == elastic_is_error_present(&curl_page->page, &error))
 			{
 				zabbix_log(LOG_LEVEL_WARNING, "%s() cannot send data to elasticsearch: %s",
-						__function_name, error);
+						__func__, error);
 				zbx_free(error);
 
 				/* If the error is due to elastic internal problems (for example an index */
@@ -584,17 +552,16 @@ try_again:
 		sleep(ZBX_HISTORY_STORAGE_DOWN / 1000);
 		goto try_again;
 	}
-clean:
+
 	curl_slist_free_all(curl_headers);
 
 	zbx_vector_ptr_destroy(&retries);
 
 	elastic_writer_release();
 
-end:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
-	return ret;
+	return SUCCEED;
 }
 
 /******************************************************************************************************************
@@ -645,8 +612,6 @@ static void	elastic_destroy(zbx_history_iface_t *hist)
 static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, int start, int count, int end,
 		zbx_vector_history_record_t *values)
 {
-	const char		*__function_name = "elastic_get_values";
-
 	zbx_elastic_data_t	*data = (zbx_elastic_data_t *)hist->data;
 	size_t			url_alloc = 0, url_offset = 0, id_alloc = 0, scroll_alloc = 0, scroll_offset = 0;
 	int			total, empty, ret;
@@ -654,9 +619,8 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 	struct zbx_json		query;
 	struct curl_slist	*curl_headers = NULL;
 	char			*scroll_id = NULL, *scroll_query = NULL, errbuf[CURL_ERROR_SIZE];
-	CURLoption		opt;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	ret = FAIL;
 
@@ -715,18 +679,13 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 
 	curl_headers = curl_slist_append(curl_headers, "Content-Type: application/json");
 
-	if (CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_URL, data->post_url)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_POSTFIELDS, query.buffer)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_WRITEFUNCTION,
-					curl_write_cb)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_WRITEDATA, &page_r)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_HTTPHEADER, curl_headers)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_FAILONERROR, 1L)) ||
-			CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_ERRORBUFFER, errbuf)))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)opt, curl_easy_strerror(err));
-		goto out;
-	}
+	curl_easy_setopt(data->handle, CURLOPT_URL, data->post_url);
+	curl_easy_setopt(data->handle, CURLOPT_POSTFIELDS, query.buffer);
+	curl_easy_setopt(data->handle, CURLOPT_WRITEFUNCTION, curl_write_cb);
+	curl_easy_setopt(data->handle, CURLOPT_WRITEDATA, &page_r);
+	curl_easy_setopt(data->handle, CURLOPT_HTTPHEADER, curl_headers);
+	curl_easy_setopt(data->handle, CURLOPT_FAILONERROR, 1L);
+	curl_easy_setopt(data->handle, CURLOPT_ERRORBUFFER, errbuf);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "sending query to %s; post data: %s", data->post_url, query.buffer);
 
@@ -741,12 +700,7 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 	url_offset = 0;
 	zbx_snprintf_alloc(&data->post_url, &url_alloc, &url_offset, "%s/_search/scroll", data->base_url);
 
-	if (CURLE_OK != (err = curl_easy_setopt(data->handle, CURLOPT_URL, data->post_url)))
-	{
-		zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)CURLOPT_URL,
-				curl_easy_strerror(err));
-		goto out;
-	}
+	curl_easy_setopt(data->handle, CURLOPT_URL, data->post_url);
 
 	total = (0 == count ? -1 : count);
 
@@ -767,7 +721,7 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 		zbx_json_brackets_open(jp.start, &jp_values);
 
 		/* get the scroll id immediately, for being used in subsequent queries */
-		if (SUCCEED != zbx_json_value_by_name_dyn(&jp_values, "_scroll_id", &scroll_id, &id_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(&jp_values, "_scroll_id", &scroll_id, &id_alloc))
 		{
 			zabbix_log(LOG_LEVEL_WARNING, "elasticsearch version is not compatible with zabbix server. "
 					"_scroll_id tag is absent");
@@ -812,12 +766,7 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 		zbx_snprintf_alloc(&scroll_query, &scroll_alloc, &scroll_offset,
 				"{\"scroll\":\"10s\",\"scroll_id\":\"%s\"}\n", ZBX_NULL2EMPTY_STR(scroll_id));
 
-		if (CURLE_OK != (err = curl_easy_setopt(data->handle, CURLOPT_POSTFIELDS, scroll_query)))
-		{
-			zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)CURLOPT_POSTFIELDS,
-					curl_easy_strerror(err));
-			break;
-		}
+		curl_easy_setopt(data->handle, CURLOPT_POSTFIELDS, scroll_query);
 
 		page_r.offset = 0;
 		*errbuf = '\0';
@@ -836,16 +785,9 @@ static int	elastic_get_values(zbx_history_iface_t *hist, zbx_uint64_t itemid, in
 		zbx_snprintf_alloc(&data->post_url, &url_alloc, &url_offset, "%s/_search/scroll/%s", data->base_url,
 				scroll_id);
 
-		if (CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_URL, data->post_url)) ||
-				CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_POSTFIELDS, NULL)) ||
-				CURLE_OK != (err = curl_easy_setopt(data->handle, opt = CURLOPT_CUSTOMREQUEST, "DELETE")))
-		{
-			zabbix_log(LOG_LEVEL_ERR, "cannot set cURL option %d: [%s]", (int)opt,
-					curl_easy_strerror(err));
-			ret = FAIL;
-			goto out;
-		}
-
+		curl_easy_setopt(data->handle, CURLOPT_URL, data->post_url);
+		curl_easy_setopt(data->handle, CURLOPT_POSTFIELDS, NULL);
+		curl_easy_setopt(data->handle, CURLOPT_CUSTOMREQUEST, "DELETE");
 
 		zabbix_log(LOG_LEVEL_DEBUG, "elasticsearch closing scroll %s", data->post_url);
 
@@ -867,7 +809,7 @@ out:
 
 	zbx_vector_history_record_sort(values, (zbx_compare_func_t)zbx_history_record_compare_desc_func);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return ret;
 }
@@ -884,8 +826,6 @@ out:
  ************************************************************************************/
 static int	elastic_add_values(zbx_history_iface_t *hist, const zbx_vector_ptr_t *history)
 {
-	const char	*__function_name = "elastic_add_values";
-
 	zbx_elastic_data_t	*data = (zbx_elastic_data_t *)hist->data;
 	int			i, num = 0;
 	ZBX_DC_HISTORY		*h;
@@ -893,7 +833,7 @@ static int	elastic_add_values(zbx_history_iface_t *hist, const zbx_vector_ptr_t
 	size_t			buf_alloc = 0, buf_offset = 0;
 	char			pipeline[14]; /* index name length + suffix "-pipeline" */
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	zbx_json_init(&json_idx, ZBX_IDX_JSON_ALLOCATE);
 
@@ -956,7 +896,7 @@ static int	elastic_add_values(zbx_history_iface_t *hist, const zbx_vector_ptr_t
 
 	zbx_json_free(&json_idx);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return num;
 }
