@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -100,10 +100,11 @@ int	zabbix_decrease_log_level(void)
 }
 #endif
 
-int	zbx_redirect_stdio(const char *filename)
+void	zbx_redirect_stdio(const char *filename)
 {
+	int		fd;
 	const char	default_file[] = ZBX_DEV_NULL;
-	int		open_flags = O_WRONLY, fd;
+	int		open_flags = O_WRONLY;
 
 	if (NULL != filename && '\0' != *filename)
 		open_flags |= O_CREAT | O_APPEND;
@@ -113,7 +114,7 @@ int	zbx_redirect_stdio(const char *filename)
 	if (-1 == (fd = open(filename, open_flags, 0666)))
 	{
 		zbx_error("cannot open \"%s\": %s", filename, zbx_strerror(errno));
-		return FAIL;
+		exit(EXIT_FAILURE);
 	}
 
 	fflush(stdout);
@@ -129,44 +130,46 @@ int	zbx_redirect_stdio(const char *filename)
 	if (-1 == (fd = open(default_file, O_RDONLY)))
 	{
 		zbx_error("cannot open \"%s\": %s", default_file, zbx_strerror(errno));
-		return FAIL;
+		exit(EXIT_FAILURE);
 	}
 
 	if (-1 == dup2(fd, STDIN_FILENO))
 		zbx_error("cannot redirect stdin to \"%s\": %s", default_file, zbx_strerror(errno));
 
 	close(fd);
-
-	return SUCCEED;
 }
 
 static void	rotate_log(const char *filename)
 {
 	zbx_stat_t		buf;
 	zbx_uint64_t		new_size;
-	static zbx_uint64_t	old_size = ZBX_MAX_UINT64;	/* redirect stdout and stderr */
-#if !defined(_WINDOWS)
-	static zbx_uint64_t	st_ino, st_dev;
-#endif
+	static zbx_uint64_t	old_size = ZBX_MAX_UINT64;
 
-	if (0 != zbx_stat(filename, &buf))
+	if (0 == CONFIG_LOG_FILE_SIZE || NULL == filename || '\0' == *filename)
 	{
-		zbx_redirect_stdio(filename);
+		/* redirect only once if log file wasn't specified or there is no log file size limit */
+		if (ZBX_MAX_UINT64 == old_size)
+		{
+			old_size = 0;
+			zbx_redirect_stdio(filename);
+		}
+
 		return;
 	}
 
+	if (0 != zbx_stat(filename, &buf))
+		return;
+
 	new_size = buf.st_size;
 
-	if (0 != CONFIG_LOG_FILE_SIZE && (zbx_uint64_t)CONFIG_LOG_FILE_SIZE * ZBX_MEBIBYTE < new_size)
+	if ((zbx_uint64_t)CONFIG_LOG_FILE_SIZE * ZBX_MEBIBYTE < new_size)
 	{
 		char	filename_old[MAX_STRING_LEN];
 
 		strscpy(filename_old, filename);
 		zbx_strlcat(filename_old, ".old", MAX_STRING_LEN);
 		remove(filename_old);
-#ifdef _WINDOWS
-		zbx_redirect_stdio(NULL);
-#endif
+
 		if (0 != rename(filename, filename_old))
 		{
 			FILE	*log_file = NULL;
@@ -218,14 +221,6 @@ static void	rotate_log(const char *filename)
 
 	if (old_size > new_size)
 		zbx_redirect_stdio(filename);
-#if !defined(_WINDOWS)
-	else if (st_ino != buf.st_ino || st_dev != buf.st_dev)
-	{
-		st_ino = buf.st_ino;
-		st_dev = buf.st_dev;
-		zbx_redirect_stdio(filename);
-	}
-#endif
 
 	old_size = new_size;
 }
@@ -244,7 +239,7 @@ static void	lock_log(void)
 	sigaddset(&mask, SIGTERM);
 	sigaddset(&mask, SIGINT);
 	sigaddset(&mask, SIGQUIT);
-	sigaddset(&mask, SIGHUP);
+	sigaddset(&mask, SIGABRT);
 
 	if (0 > sigprocmask(SIG_BLOCK, &mask, &orig_mask))
 		zbx_error("cannot set sigprocmask to block the user signal");
@@ -328,7 +323,7 @@ int	zabbix_open_log(int type, int level, const char *filename, char **error)
 		strscpy(log_filename, filename);
 		zbx_fclose(log_file);
 	}
-	else if (LOG_TYPE_CONSOLE == type)
+	else if (LOG_TYPE_CONSOLE == type || LOG_TYPE_UNDEFINED == type)
 	{
 		if (SUCCEED != zbx_mutex_create(&log_access, ZBX_MUTEX_LOG, error))
 		{
@@ -340,7 +335,7 @@ int	zabbix_open_log(int type, int level, const char *filename, char **error)
 		if (-1 == dup2(STDOUT_FILENO, STDERR_FILENO))
 			zbx_error("cannot redirect stderr to stdout: %s", zbx_strerror(errno));
 	}
-	else if (LOG_TYPE_UNDEFINED != type)
+	else
 	{
 		*error = zbx_strdup(*error, "unknown log type");
 		return FAIL;
@@ -360,7 +355,7 @@ void	zabbix_close_log(void)
 		closelog();
 #endif
 	}
-	else if (LOG_TYPE_FILE == log_type || LOG_TYPE_CONSOLE == log_type)
+	else if (LOG_TYPE_FILE == log_type || LOG_TYPE_CONSOLE == log_type || LOG_TYPE_UNDEFINED == log_type)
 	{
 		zbx_mutex_destroy(&log_access);
 	}
@@ -385,8 +380,7 @@ void	__zbx_zabbix_log(int level, const char *fmt, ...)
 
 		LOCK_LOG;
 
-		if (0 != CONFIG_LOG_FILE_SIZE)
-			rotate_log(log_filename);
+		rotate_log(log_filename);
 
 		if (NULL != (log_file = fopen(log_filename, "a+")))
 		{
