@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -64,6 +64,7 @@ static int	get_if_names(char **if_list, size_t *if_list_alloc, size_t *if_list_o
 {
 	int			s, ifreq_size, numifs, i, family = AF_INET;
 	struct sockaddr		*from;
+	size_t			fromlen;
 	u_char			*buffer = NULL;
 	struct ifconf		ifc;
 	struct ifreq		*ifr;
@@ -144,11 +145,6 @@ next:
 end:
 	zbx_free(buffer);
 	close(s);
-#else
-	ZBX_UNUSED(numifs);
-	ZBX_UNUSED(i);
-	ZBX_UNUSED(lifc);
-	ZBX_UNUSED(lifr);
 #endif
 	return SUCCEED;
 }
@@ -173,9 +169,7 @@ int	NET_IF_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 		return SYSINFO_RET_FAIL;
 	}
 
-	zbx_json_init(&j, ZBX_JSON_STAT_BUF_LEN);
-
-	zbx_json_addarray(&j, ZBX_PROTO_TAG_DATA);
+	zbx_json_initarray(&j, ZBX_JSON_STAT_BUF_LEN);
 
 	if_name = if_list;
 
@@ -208,9 +202,7 @@ int	NET_IF_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 		return SYSINFO_RET_FAIL;
 	}
 
-	zbx_json_init(&j, ZBX_JSON_STAT_BUF_LEN);
-
-	zbx_json_addarray(&j, ZBX_PROTO_TAG_DATA);
+	zbx_json_initarray(&j, ZBX_JSON_STAT_BUF_LEN);
 
 	for (i = 0; 0 != ni[i].if_index; i++)
 	{
