@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -269,8 +269,7 @@ int	byte_value_from_proc_file(FILE *f, const char *label, const char *guard, zbx
 	if (NULL != guard)
 	{
 		guard_len = strlen(guard);
-		if (0 > (pos = ftell(f)))
-			return FAIL;
+		pos = ftell(f);
 	}
 
 	while (NULL != fgets(buf, (int)sizeof(buf), f))
@@ -279,16 +278,11 @@ int	byte_value_from_proc_file(FILE *f, const char *label, const char *guard, zbx
 		{
 			if (0 == strncmp(buf, guard, guard_len))
 			{
-				if (0 != fseek(f, pos, SEEK_SET))
-					ret = FAIL;
+				fseek(f, pos, SEEK_SET);
 				break;
 			}
 
-			if (0 > (pos = ftell(f)))
-			{
-				ret = FAIL;
-				break;
-			}
+			pos = ftell(f);
 		}
 
 		if (0 != strncmp(buf, label, label_len))
@@ -1066,7 +1060,7 @@ static int	proc_read_cpu_util(zbx_procstat_util_t *procutil)
 
 				break;
 			case 20:
-				if (FAIL == proc_read_value(ptr, &procutil->starttime))
+				if (FAIL == (offset = proc_read_value(ptr, &procutil->starttime)))
 				{
 					ret = -EINVAL;
 					goto out;
@@ -1152,15 +1146,14 @@ static int	proc_match_cmdline(const zbx_sysinfo_proc_t *proc, const char *cmdlin
  ******************************************************************************/
 void	zbx_proc_get_process_stats(zbx_procstat_util_t *procs, int procs_num)
 {
-	const char	*__function_name = "zbx_proc_get_process_stats";
 	int	i;
 
-	zabbix_log(LOG_LEVEL_TRACE, "In %s() procs_num:%d", __function_name, procs_num);
+	zabbix_log(LOG_LEVEL_TRACE, "In %s() procs_num:%d", __func__, procs_num);
 
 	for (i = 0; i < procs_num; i++)
 		procs[i].error = proc_read_cpu_util(&procs[i]);
 
-	zabbix_log(LOG_LEVEL_TRACE, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_TRACE, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -1179,7 +1172,7 @@ void	zbx_proc_get_process_stats(zbx_procstat_util_t *procs, int procs_num)
 static zbx_sysinfo_proc_t	*proc_create(int pid, unsigned int flags)
 {
 	char			*procname = NULL, *cmdline = NULL, *name_arg0 = NULL;
-	uid_t			uid = (uid_t)-1;
+	uid_t			uid = -1;
 	zbx_sysinfo_proc_t	*proc = NULL;
 	int			ret = FAIL;
 	size_t			cmdline_nbytes;
@@ -1253,14 +1246,12 @@ out:
  ******************************************************************************/
 int	zbx_proc_get_processes(zbx_vector_ptr_t *processes, unsigned int flags)
 {
-	const char		*__function_name = "zbx_proc_get_processes";
-
 	DIR			*dir;
 	struct dirent		*entries;
 	int			ret = FAIL, pid;
 	zbx_sysinfo_proc_t	*proc;
 
-	zabbix_log(LOG_LEVEL_TRACE, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_TRACE, "In %s()", __func__);
 
 	if (NULL == (dir = opendir("/proc")))
 		goto out;
@@ -1281,7 +1272,7 @@ int	zbx_proc_get_processes(zbx_vector_ptr_t *processes, unsigned int flags)
 
 	ret = SUCCEED;
 out:
-	zabbix_log(LOG_LEVEL_TRACE, "End of %s(): %s, processes:%d", __function_name, zbx_result_string(ret),
+	zabbix_log(LOG_LEVEL_TRACE, "End of %s(): %s, processes:%d", __func__, zbx_result_string(ret),
 			processes->values_num);
 
 	return ret;
@@ -1321,12 +1312,11 @@ void	zbx_proc_free_processes(zbx_vector_ptr_t *processes)
 void	zbx_proc_get_matching_pids(const zbx_vector_ptr_t *processes, const char *procname, const char *username,
 		const char *cmdline, zbx_uint64_t flags, zbx_vector_uint64_t *pids)
 {
-	const char		*__function_name = "zbx_proc_get_matching_pids";
 	struct passwd		*usrinfo;
 	int			i;
 	zbx_sysinfo_proc_t	*proc;
 
-	zabbix_log(LOG_LEVEL_TRACE, "In %s() procname:%s username:%s cmdline:%s flags:" ZBX_FS_UI64, __function_name,
+	zabbix_log(LOG_LEVEL_TRACE, "In %s() procname:%s username:%s cmdline:%s flags:" ZBX_FS_UI64, __func__,
 			ZBX_NULL2EMPTY_STR(procname), ZBX_NULL2EMPTY_STR(username), ZBX_NULL2EMPTY_STR(cmdline), flags);
 
 	if (NULL != username)
@@ -1354,7 +1344,7 @@ void	zbx_proc_get_matching_pids(const zbx_vector_ptr_t *processes, const char *p
 		zbx_vector_uint64_append(pids, (zbx_uint64_t)proc->pid);
 	}
 out:
-	zabbix_log(LOG_LEVEL_TRACE, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_TRACE, "End of %s()", __func__);
 }
 
 int	PROC_CPU_UTIL(AGENT_REQUEST *request, AGENT_RESULT *result)
