@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,17 +36,17 @@
 #endif
 
 ZBX_METRIC	parameters_simple[] =
-/*      KEY                     FLAG		FUNCTION        	TEST PARAMETERS */
+/*	KEY			FLAG		FUNCTION		TEST PARAMETERS */
 {
-	{"net.tcp.service",	CF_HAVEPARAMS,	CHECK_SERVICE, 		"ssh,127.0.0.1,22"},
-	{"net.tcp.service.perf",CF_HAVEPARAMS,	CHECK_SERVICE_PERF, 	"ssh,127.0.0.1,22"},
-	{"net.udp.service",	CF_HAVEPARAMS,	CHECK_SERVICE, 		"ntp,127.0.0.1,123"},
-	{"net.udp.service.perf",CF_HAVEPARAMS,	CHECK_SERVICE_PERF, 	"ntp,127.0.0.1,123"},
+	{"net.tcp.service",	CF_HAVEPARAMS,	CHECK_SERVICE,		"ssh,127.0.0.1,22"},
+	{"net.tcp.service.perf",CF_HAVEPARAMS,	CHECK_SERVICE_PERF,	"ssh,127.0.0.1,22"},
+	{"net.udp.service",	CF_HAVEPARAMS,	CHECK_SERVICE,		"ntp,127.0.0.1,123"},
+	{"net.udp.service.perf",CF_HAVEPARAMS,	CHECK_SERVICE_PERF,	"ntp,127.0.0.1,123"},
 	{NULL}
 };
 
 #ifdef HAVE_LDAP
-static int    check_ldap(const char *host, unsigned short port, int timeout, int *value_int)
+static int	check_ldap(const char *host, unsigned short port, int timeout, int *value_int)
 {
 	LDAP		*ldap	= NULL;
 	LDAPMessage	*res	= NULL;
@@ -68,18 +68,6 @@ static int    check_ldap(const char *host, unsigned short port, int timeout, int
 		goto lbl_ret;
 	}
 
-	#if defined(LDAP_OPT_SOCKET_BIND_ADDRESSES) && defined(HAVE_LDAP_SOURCEIP)
-	if (NULL != CONFIG_SOURCE_IP)
-	{
-		if (LDAP_SUCCESS != (ldapErr = ldap_set_option(ldap, LDAP_OPT_SOCKET_BIND_ADDRESSES, CONFIG_SOURCE_IP)))
-		{
-			zabbix_log(LOG_LEVEL_DEBUG, "LDAP - failed to set source ip address [%s]",
-					ldap_err2string(ldapErr));
-			goto lbl_ret;
-		}
-	}
-	#endif
-
 	if (LDAP_SUCCESS != (ldapErr = ldap_search_s(ldap, "", LDAP_SCOPE_BASE, "(objectClass=*)", attrs, 0, &res)))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "LDAP - searching failed [%s] [%s]", host, ldap_err2string(ldapErr));
@@ -158,8 +146,7 @@ static int	check_ssh(const char *host, unsigned short port, int timeout, int *va
 #ifdef HAVE_LIBCURL
 static int	check_https(const char *host, unsigned short port, int timeout, int *value_int)
 {
-	const char	*__function_name = "check_https";
-	CURL            *easyhandle;
+	CURL		*easyhandle;
 	CURLoption	opt;
 	CURLcode	err;
 	char		https_host[MAX_STRING_LEN];
@@ -168,7 +155,7 @@ static int	check_https(const char *host, unsigned short port, int timeout, int *
 
 	if (NULL == (easyhandle = curl_easy_init()))
 	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s: could not init cURL library", __function_name);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s: could not init cURL library", __func__);
 		goto clean;
 	}
 
@@ -186,7 +173,7 @@ static int	check_https(const char *host, unsigned short port, int timeout, int *
 		CURLE_OK != (err = curl_easy_setopt(easyhandle, opt = CURLOPT_TIMEOUT, (long)timeout)))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "%s: could not set cURL option [%d]: %s",
-				__function_name, (int)opt, curl_easy_strerror(err));
+				__func__, (int)opt, curl_easy_strerror(err));
 		goto clean;
 	}
 
@@ -195,7 +182,7 @@ static int	check_https(const char *host, unsigned short port, int timeout, int *
 		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, opt = CURLOPT_INTERFACE, CONFIG_SOURCE_IP)))
 		{
 			zabbix_log(LOG_LEVEL_DEBUG, "%s: could not set source interface option [%d]: %s",
-					__function_name, (int)opt, curl_easy_strerror(err));
+					__func__, (int)opt, curl_easy_strerror(err));
 			goto clean;
 		}
 	}
@@ -204,7 +191,7 @@ static int	check_https(const char *host, unsigned short port, int timeout, int *
 		*value_int = 1;
 	else
 		zabbix_log(LOG_LEVEL_DEBUG, "%s: curl_easy_perform failed for [%s:%hu]: %s",
-				__function_name, host, port, curl_easy_strerror(err));
+				__func__, host, port, curl_easy_strerror(err));
 clean:
 	curl_easy_cleanup(easyhandle);
 
@@ -214,7 +201,6 @@ clean:
 
 static int	check_telnet(const char *host, unsigned short port, int timeout, int *value_int)
 {
-	const char	*__function_name = "check_telnet";
 	zbx_socket_t	s;
 #ifdef _WINDOWS
 	u_long		argp = 1;
@@ -241,7 +227,7 @@ static int	check_telnet(const char *host, unsigned short port, int timeout, int
 		zbx_tcp_close(&s);
 	}
 	else
-		zabbix_log(LOG_LEVEL_DEBUG, "%s error: %s", __function_name, zbx_socket_strerror());
+		zabbix_log(LOG_LEVEL_DEBUG, "%s error: %s", __func__, zbx_socket_strerror());
 
 	return SYSINFO_RET_OK;
 }
