@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,12 +24,12 @@
 
 /* __stdcall calling convention is used for GetIfEntry2(). In order to declare a */
 /* pointer to GetIfEntry2() we have to expand NETIOPAPI_API macro manually since */
-/* part of it must be together with the pointer name in the parentheses.         */
+/* part of it must be toghether with the pointer name in the parentheses.        */
 typedef NETIO_STATUS (NETIOAPI_API_ *pGetIfEntry2_t)(PMIB_IF_ROW2 Row);
 
 /* GetIfEntry2() is available since Windows Vista and Windows Server 2008. In    */
 /* earlier Windows releases this pointer remains set to NULL and GetIfEntry() is */
-/* used directly instead.                                                        */
+/* used dirrectly instead.                                                       */
 static pGetIfEntry2_t	pGetIfEntry2 = NULL;
 
 /* GetIfEntry2() and GetIfEntry() work with different MIB interface structures.  */
@@ -294,7 +294,6 @@ static char	*zbx_ifrow_get_utf8_description(const zbx_ifrow_t *pIfRow)
 			else
 				mb_to_unicode = zbx_acp_to_unicode;
 		}
-
 		wdescr = mb_to_unicode(pIfRow->ifRow->bDescr);
 		utf8_descr = zbx_unicode_to_utf8(wdescr);
 		zbx_free(wdescr);
@@ -578,9 +577,7 @@ int	NET_IF_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 		goto clean;
 	}
 
-	zbx_json_init(&j, ZBX_JSON_STAT_BUF_LEN);
-
-	zbx_json_addarray(&j, ZBX_PROTO_TAG_DATA);
+	zbx_json_initarray(&j, ZBX_JSON_STAT_BUF_LEN);
 
 	zbx_ifrow_init(&ifrow);
 
