@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,12 +25,11 @@
 
 int	USER_PERF_COUNTER(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	const char		*__function_name = "USER_PERF_COUNTER";
-	int			ret = SYSINFO_RET_FAIL;
-	char			*counter, *error = NULL;
-	double			value;
+	int	ret = SYSINFO_RET_FAIL;
+	char	*counter, *error = NULL;
+	double	value;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	if (1 != request->nparam)
 	{
@@ -54,19 +53,18 @@ int	USER_PERF_COUNTER(AGENT_REQUEST *request, AGENT_RESULT *result)
 	SET_DBL_RESULT(result, value);
 	ret = SYSINFO_RET_OK;
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
-static int perf_counter_ex(const char *function, AGENT_REQUEST *request, AGENT_RESULT *result,
-		zbx_perf_counter_lang_t lang)
+int	PERF_COUNTER(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	counterpath[PDH_MAX_COUNTER_PATH], *tmp, *error = NULL;
 	int	interval, ret = SYSINFO_RET_FAIL;
 	double	value;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", function);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	if (2 < request->nparam)
 	{
@@ -100,13 +98,13 @@ static int perf_counter_ex(const char *function, AGENT_REQUEST *request, AGENT_R
 		goto out;
 	}
 
-	if (FAIL == check_counter_path(counterpath, PERF_COUNTER_LANG_DEFAULT == lang))
+	if (FAIL == check_counter_path(counterpath))
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid performance counter path."));
 		goto out;
 	}
 
-	if (SUCCEED != get_perf_counter_value_by_path(counterpath, interval, lang, &value, &error))
+	if (SUCCEED != get_perf_counter_value_by_path(counterpath, interval, &value, &error))
 	{
 		SET_MSG_RESULT(result, error != NULL ? error :
 				zbx_strdup(NULL, "Cannot obtain performance information from collector."));
@@ -116,21 +114,7 @@ static int perf_counter_ex(const char *function, AGENT_REQUEST *request, AGENT_R
 	ret = SYSINFO_RET_OK;
 	SET_DBL_RESULT(result, value);
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", function, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
-
-int	PERF_COUNTER(AGENT_REQUEST *request, AGENT_RESULT *result)
-{
-	const char	*__function_name = "PERF_COUNTER";
-
-	return perf_counter_ex(__function_name, request, result, PERF_COUNTER_LANG_DEFAULT);
-}
-
-int	PERF_COUNTER_EN(AGENT_REQUEST *request, AGENT_RESULT *result)
-{
-	const char	*__function_name = "PERF_COUNTER_EN";
-
-	return perf_counter_ex(__function_name, request, result, PERF_COUNTER_LANG_EN);
-}
