@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -77,6 +77,11 @@ abstract class ItemChecker
 		return values;
 	}
 
+	String getFirstKey()
+	{
+		return 0 == keys.size() ? null : keys.get(0);
+	}
+
 	protected final JSONObject getJSONValue(String key)
 	{
 		JSONObject value = new JSONObject();
@@ -93,12 +98,13 @@ abstract class ItemChecker
 			try
 			{
 				logger.debug("caught exception for item '{}'", key, e1);
-				value.put(JSON_TAG_ERROR, e1.getMessage());
+				value.put(JSON_TAG_ERROR, ZabbixException.getRootCauseMessage(e1));
 			}
 			catch (JSONException e2)
 			{
-				Object[] logInfo = {JSON_TAG_ERROR, e1.getMessage(), e2};
-				logger.warn("cannot add JSON attribute '{}' with message '{}'", logInfo);
+				Object[] logInfo = {JSON_TAG_ERROR, e1.getMessage(), ZabbixException.getRootCauseMessage(e2)};
+				logger.warn("cannot add JSON attribute '{}' with message '{}': {}", logInfo);
+				logger.debug("error caused by", e2);
 			}
 		}
 
