@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -52,12 +52,9 @@ typedef struct
 }
 zbx_httppage_t;
 
-#define ZBX_RETRIEVE_MODE_CONTENT	0
-#define ZBX_RETRIEVE_MODE_HEADERS	1
-
 static zbx_httppage_t	page;
 
-static size_t	WRITEFUNCTION2(void *ptr, size_t size, size_t nmemb, void *userdata)
+static size_t	curl_write_cb(void *ptr, size_t size, size_t nmemb, void *userdata)
 {
 	size_t	r_size = size * nmemb;
 
@@ -76,7 +73,7 @@ static size_t	WRITEFUNCTION2(void *ptr, size_t size, size_t nmemb, void *userdat
 	return r_size;
 }
 
-static size_t	HEADERFUNCTION2(void *ptr, size_t size, size_t nmemb, void *userdata)
+static size_t	curl_ignore_cb(void *ptr, size_t size, size_t nmemb, void *userdata)
 {
 	ZBX_UNUSED(ptr);
 	ZBX_UNUSED(userdata);
@@ -115,8 +112,6 @@ static void	httptest_remove_macros(zbx_httptest_t *httptest)
 static void	process_test_data(zbx_uint64_t httptestid, int lastfailedstep, double speed_download,
 		const char *err_str, zbx_timespec_t *ts)
 {
-	const char	*__function_name = "process_test_data";
-
 	DB_RESULT	result;
 	DB_ROW		row;
 	unsigned char	types[3];
@@ -126,7 +121,7 @@ static void	process_test_data(zbx_uint64_t httptestid, int lastfailedstep, doubl
 	size_t		i, num = 0;
 	AGENT_RESULT	value;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	result = DBselect("select type,itemid from httptestitem where httptestid=" ZBX_FS_UI64, httptestid);
 
@@ -203,7 +198,7 @@ static void	process_test_data(zbx_uint64_t httptestid, int lastfailedstep, doubl
 		DCconfig_clean_items(items, errcodes, num);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -266,8 +261,6 @@ static void	httppairs_free(zbx_vector_ptr_pair_t *pairs)
 #ifdef HAVE_LIBCURL
 static void	process_step_data(zbx_uint64_t httpstepid, zbx_httpstat_t *stat, zbx_timespec_t *ts)
 {
-	const char	*__function_name = "process_step_data";
-
 	DB_RESULT	result;
 	DB_ROW		row;
 	unsigned char	types[3];
@@ -278,7 +271,7 @@ static void	process_step_data(zbx_uint64_t httpstepid, zbx_httpstat_t *stat, zbx
 	AGENT_RESULT	value;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() rspcode:%ld time:" ZBX_FS_DBL " speed:" ZBX_FS_DBL,
-			__function_name, stat->rspcode, stat->total_time, stat->speed_download);
+			__func__, stat->rspcode, stat->total_time, stat->speed_download);
 
 	result = DBselect("select type,itemid from httpstepitem where httpstepid=" ZBX_FS_UI64, httpstepid);
 
@@ -348,7 +341,7 @@ static void	process_step_data(zbx_uint64_t httpstepid, zbx_httpstat_t *stat, zbx
 		DCconfig_clean_items(items, errcodes, num);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -643,8 +636,6 @@ out:
  ******************************************************************************/
 static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 {
-	const char	*__function_name = "process_httptest";
-
 	DB_RESULT	result;
 	DB_HTTPSTEP	db_httpstep;
 	char		*err_str = NULL, *buffer = NULL;
@@ -663,7 +654,7 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 #endif
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() httptestid:" ZBX_FS_UI64 " name:'%s'",
-			__function_name, httptest->httptest.httptestid, httptest->httptest.name);
+			__func__, httptest->httptest.httptestid, httptest->httptest.name);
 
 	result = DBselect(
 			"select httpstepid,no,name,url,timeout,posts,required,status_codes,post_type,follow_redirects,"
@@ -677,11 +668,6 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, &buffer,
 			MACRO_TYPE_COMMON, NULL, 0);
 
-	/* Avoid the potential usage of uninitialized values when: */
-	/* 1) compile without libCURL support */
-	/* 2) update interval is invalid */
-	db_httpstep.name = NULL;
-
 	if (SUCCEED != is_time_suffix(buffer, &delay, ZBX_LENGTH_UNLIMITED))
 	{
 		err_str = zbx_dsprintf(err_str, "update interval \"%s\" is invalid", buffer);
@@ -689,6 +675,10 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 		goto httptest_error;
 	}
 
+	/* Explicitly initialize the name. If we compile without libCURL support, */
+	/* we avoid the potential usage of uninitialized values. */
+	db_httpstep.name = NULL;
+
 #ifdef HAVE_LIBCURL
 	if (NULL == (easyhandle = curl_easy_init()))
 	{
@@ -699,8 +689,6 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_PROXY, httptest->httptest.http_proxy)) ||
 			CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_COOKIEFILE, "")) ||
 			CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_USERAGENT, httptest->httptest.agent)) ||
-			CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, WRITEFUNCTION2)) ||
-			CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_HEADERFUNCTION, HEADERFUNCTION2)) ||
 			CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_ERRORBUFFER, errbuf)))
 	{
 		err_str = zbx_strdup(err_str, curl_easy_strerror(err));
@@ -721,6 +709,8 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 	{
 		struct curl_slist	*headers_slist = NULL;
 		char			*header_cookie = NULL;
+		size_t			(*curl_header_cb)(void *ptr, size_t size, size_t nmemb, void *userdata);
+		size_t			(*curl_body_cb)(void *ptr, size_t size, size_t nmemb, void *userdata);
 
 		/* NOTE: do not break or return from this block! */
 		/*       process_step_data() call is required! */
@@ -735,14 +725,6 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 				&db_httpstep.url, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 		http_substitute_variables(httptest, &db_httpstep.url);
 
-		db_httpstep.required = zbx_strdup(NULL, row[6]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL,
-				&db_httpstep.required, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
-
-		db_httpstep.status_codes = zbx_strdup(NULL, row[7]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL,
-				&db_httpstep.status_codes, MACRO_TYPE_COMMON, NULL, 0);
-
 		db_httpstep.post_type = atoi(row[8]);
 
 		if (ZBX_POSTTYPE_RAW == db_httpstep.post_type)
@@ -770,19 +752,27 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 			err_str = zbx_dsprintf(err_str, "timeout \"%s\" is invalid", buffer);
 			goto httpstep_error;
 		}
-		else if (db_httpstep.timeout < 1 || SEC_PER_HOUR < db_httpstep.timeout)
+		else if (SEC_PER_HOUR < db_httpstep.timeout)
 		{
-			err_str = zbx_dsprintf(err_str, "timeout \"%s\" is out of 1-3600 seconds bounds", buffer);
+			err_str = zbx_dsprintf(err_str, "timeout \"%s\" exceeds 1 hour limit", buffer);
 			goto httpstep_error;
 		}
 
+		db_httpstep.required = zbx_strdup(NULL, row[6]);
+		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL,
+				&db_httpstep.required, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
+
+		db_httpstep.status_codes = zbx_strdup(NULL, row[7]);
+		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL,
+				&db_httpstep.status_codes, MACRO_TYPE_COMMON, NULL, 0);
+
 		db_httpstep.follow_redirects = atoi(row[9]);
 		db_httpstep.retrieve_mode = atoi(row[10]);
 
 		memset(&stat, 0, sizeof(stat));
 
-		zabbix_log(LOG_LEVEL_DEBUG, "%s() use step \"%s\"", __function_name, db_httpstep.name);
-		zabbix_log(LOG_LEVEL_DEBUG, "%s() use post \"%s\"", __function_name, ZBX_NULL2EMPTY_STR(httpstep.posts));
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() use step \"%s\"", __func__, db_httpstep.name);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() use post \"%s\"", __func__, ZBX_NULL2EMPTY_STR(httpstep.posts));
 
 		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_POSTFIELDS, httpstep.posts)))
 		{
@@ -834,6 +824,32 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 			goto httpstep_error;
 		}
 
+		switch (db_httpstep.retrieve_mode)
+		{
+			case ZBX_RETRIEVE_MODE_CONTENT:
+				curl_header_cb = curl_ignore_cb;
+				curl_body_cb = curl_write_cb;
+				break;
+			case ZBX_RETRIEVE_MODE_BOTH:
+				curl_header_cb = curl_body_cb = curl_write_cb;
+				break;
+			case ZBX_RETRIEVE_MODE_HEADERS:
+				curl_header_cb = curl_write_cb;
+				curl_body_cb = curl_ignore_cb;
+				break;
+			default:
+				THIS_SHOULD_NEVER_HAPPEN;
+				err_str = zbx_strdup(err_str, "invalid retrieve mode");
+				goto httpstep_error;
+		}
+
+		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, curl_body_cb)) ||
+				CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_HEADERFUNCTION, curl_header_cb)))
+		{
+			err_str = zbx_strdup(err_str, curl_easy_strerror(err));
+			goto httpstep_error;
+		}
+
 		/* enable/disable fetching the body */
 		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_NOBODY,
 				ZBX_RETRIEVE_MODE_HEADERS == db_httpstep.retrieve_mode ? 1L : 0L)))
@@ -848,7 +864,7 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 			goto httpstep_error;
 		}
 
-		zabbix_log(LOG_LEVEL_DEBUG, "%s() go to URL \"%s\"", __function_name, httpstep.url);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() go to URL \"%s\"", __func__, httpstep.url);
 
 		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_TIMEOUT, (long)db_httpstep.timeout)) ||
 				CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_URL, httpstep.url)))
@@ -861,7 +877,6 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 		do
 		{
 			memset(&page, 0, sizeof(page));
-			errbuf[0] = '\0';
 
 			if (CURLE_OK == (err = curl_easy_perform(easyhandle)))
 				break;
@@ -874,8 +889,9 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 
 		if (CURLE_OK == err)
 		{
-			zabbix_log(LOG_LEVEL_TRACE, "%s() page.data from %s:'%s'", __function_name, httpstep.url,
-					page.data);
+			char	*var_err_str = NULL;
+
+			zabbix_log(LOG_LEVEL_TRACE, "%s() page.data from %s:'%s'", __func__, httpstep.url, page.data);
 
 			/* first get the data that is needed even if step fails */
 			if (CURLE_OK != (err = curl_easy_getinfo(easyhandle, CURLINFO_RESPONSE_CODE, &stat.rspcode)))
@@ -907,53 +923,46 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 				speed_download_num++;
 			}
 
-			if (ZBX_RETRIEVE_MODE_CONTENT == db_httpstep.retrieve_mode)
+			/* required pattern */
+			if (NULL == err_str && '\0' != *db_httpstep.required &&
+					NULL == zbx_regexp_match(page.data, db_httpstep.required, NULL))
 			{
-				char	*var_err_str = NULL;
-
-				/* required pattern */
-				if (NULL == err_str && '\0' != *db_httpstep.required &&
-						NULL == zbx_regexp_match(page.data, db_httpstep.required, NULL))
-				{
-					err_str = zbx_dsprintf(err_str, "required pattern \"%s\" was not found on %s",
-							db_httpstep.required, httpstep.url);
-				}
-
-				/* variables defined in scenario */
-				if (NULL == err_str && FAIL == http_process_variables(httptest,
-						&httptest->variables, page.data, &var_err_str))
-				{
-					char	*variables = NULL;
-					size_t	alloc_len = 0, offset;
-
-					httpstep_pairs_join(&variables, &alloc_len, &offset, "=", " ",
-							&httptest->variables);
-
-					err_str = zbx_dsprintf(err_str, "error in scenario variables \"%s\": %s",
-							variables, var_err_str);
-
-					zbx_free(variables);
-				}
-
-				/* variables defined in a step */
-				if (NULL == err_str && FAIL == http_process_variables(httptest, &httpstep.variables,
-						page.data, &var_err_str))
-				{
-					char	*variables = NULL;
-					size_t	alloc_len = 0, offset;
-
-					httpstep_pairs_join(&variables, &alloc_len, &offset, "=", " ",
-							&httpstep.variables);
-
-					err_str = zbx_dsprintf(err_str, "error in step variables \"%s\": %s",
-							variables, var_err_str);
-
-					zbx_free(variables);
-				}
-
-				zbx_free(var_err_str);
+				err_str = zbx_dsprintf(err_str, "required pattern \"%s\" was not found on %s",
+						db_httpstep.required, httpstep.url);
 			}
 
+			/* variables defined in scenario */
+			if (NULL == err_str && FAIL == http_process_variables(httptest, &httptest->variables, page.data,
+					&var_err_str))
+			{
+				char	*variables = NULL;
+				size_t	alloc_len = 0, offset;
+
+				httpstep_pairs_join(&variables, &alloc_len, &offset, "=", " ", &httptest->variables);
+
+				err_str = zbx_dsprintf(err_str, "error in scenario variables \"%s\": %s", variables,
+						var_err_str);
+
+				zbx_free(variables);
+			}
+
+			/* variables defined in a step */
+			if (NULL == err_str && FAIL == http_process_variables(httptest, &httpstep.variables, page.data,
+					&var_err_str))
+			{
+				char	*variables = NULL;
+				size_t	alloc_len = 0, offset;
+
+				httpstep_pairs_join(&variables, &alloc_len, &offset, "=", " ", &httpstep.variables);
+
+				err_str = zbx_dsprintf(err_str, "error in step variables \"%s\": %s", variables,
+						var_err_str);
+
+				zbx_free(variables);
+			}
+
+			zbx_free(var_err_str);
+
 			zbx_timespec(&ts);
 			process_step_data(db_httpstep.httpstepid, &stat, &ts);
 
@@ -1041,7 +1050,7 @@ httptest_error:
 	zbx_free(err_str);
 	zbx_preprocessor_flush();
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -1061,15 +1070,13 @@ httptest_error:
  ******************************************************************************/
 int	process_httptests(int httppoller_num, int now)
 {
-	const char	*__function_name = "process_httptests";
-
 	DB_RESULT	result;
 	DB_ROW		row;
 	zbx_httptest_t	httptest;
 	DC_HOST		host;
 	int		httptests_count = 0;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	/* create macro cache to use in http tests */
 	zbx_vector_ptr_pair_create(&httptest.macros);
@@ -1181,7 +1188,7 @@ int	process_httptests(int httppoller_num, int now)
 
 	DBfree_result(result);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return httptests_count;
 }
