@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,13 +50,12 @@ extern unsigned char	program_type;
  ******************************************************************************/
 int	get_value_agent(DC_ITEM *item, AGENT_RESULT *result)
 {
-	const char	*__function_name = "get_value_agent";
 	zbx_socket_t	s;
 	char		*tls_arg1, *tls_arg2;
 	int		ret = SUCCEED;
 	ssize_t		received_len;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() host:'%s' addr:'%s' key:'%s' conn:'%s'", __function_name, item->host.host,
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() host:'%s' addr:'%s' key:'%s' conn:'%s'", __func__, item->host.host,
 			item->interface.addr, item->key, zbx_tcp_connection_type_name(item->host.tls_connect));
 
 	switch (item->host.tls_connect)
@@ -90,8 +89,8 @@ int	get_value_agent(DC_ITEM *item, AGENT_RESULT *result)
 			goto out;
 	}
 
-	if (SUCCEED == zbx_tcp_connect(&s, CONFIG_SOURCE_IP, item->interface.addr, item->interface.port, 0,
-			item->host.tls_connect, tls_arg1, tls_arg2))
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, item->interface.addr, item->interface.port, 0,
+			item->host.tls_connect, tls_arg1, tls_arg2)))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", item->key);
 
@@ -109,9 +108,6 @@ int	get_value_agent(DC_ITEM *item, AGENT_RESULT *result)
 
 	if (SUCCEED == ret)
 	{
-		zbx_rtrim(s.buffer, " \r\n");
-		zbx_ltrim(s.buffer, " ");
-
 		zabbix_log(LOG_LEVEL_DEBUG, "get value from agent result: '%s'", s.buffer);
 
 		if (0 == strcmp(s.buffer, ZBX_NOTSUPPORTED))
@@ -144,7 +140,7 @@ int	get_value_agent(DC_ITEM *item, AGENT_RESULT *result)
 
 	zbx_tcp_close(&s);
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
