@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ static int	parse_response(AGENT_RESULT *results, int *errcodes, int num, char *r
 
 	if (SUCCEED == zbx_json_open(response, &jp))
 	{
-		if (SUCCEED != zbx_json_value_by_name_dyn(&jp, ZBX_PROTO_TAG_RESPONSE, &value, &value_alloc, NULL))
+		if (SUCCEED != zbx_json_value_by_name_dyn(&jp, ZBX_PROTO_TAG_RESPONSE, &value, &value_alloc))
 		{
 			zbx_snprintf(error, max_error_len, "No '%s' tag in received JSON", ZBX_PROTO_TAG_RESPONSE);
 			goto exit;
@@ -69,14 +69,12 @@ static int	parse_response(AGENT_RESULT *results, int *errcodes, int num, char *r
 					goto exit;
 				}
 
-				if (SUCCEED == zbx_json_value_by_name_dyn(&jp_row, ZBX_PROTO_TAG_VALUE, &value,
-						&value_alloc, NULL))
+				if (SUCCEED == zbx_json_value_by_name_dyn(&jp_row, ZBX_PROTO_TAG_VALUE, &value, &value_alloc))
 				{
 					set_result_type(&results[i], ITEM_VALUE_TYPE_TEXT, value);
 					errcodes[i] = SUCCEED;
 				}
-				else if (SUCCEED == zbx_json_value_by_name_dyn(&jp_row, ZBX_PROTO_TAG_ERROR, &value,
-						&value_alloc, NULL))
+				else if (SUCCEED == zbx_json_value_by_name_dyn(&jp_row, ZBX_PROTO_TAG_ERROR, &value, &value_alloc))
 				{
 					SET_MSG_RESULT(&results[i], zbx_strdup(NULL, value));
 					errcodes[i] = NOTSUPPORTED;
@@ -92,7 +90,7 @@ static int	parse_response(AGENT_RESULT *results, int *errcodes, int num, char *r
 		}
 		else if (0 == strcmp(value, ZBX_PROTO_VALUE_FAILED))
 		{
-			if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_ERROR, error, max_error_len, NULL))
+			if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_ERROR, error, max_error_len))
 				ret = NETWORK_ERROR;
 			else
 				zbx_strlcpy(error, "Cannot get error message describing reasons for failure", max_error_len);
@@ -128,14 +126,12 @@ int	get_value_java(unsigned char request, const DC_ITEM *item, AGENT_RESULT *res
 
 void	get_values_java(unsigned char request, const DC_ITEM *items, AGENT_RESULT *results, int *errcodes, int num)
 {
-	const char	*__function_name = "get_values_java";
-
 	zbx_socket_t	s;
 	struct zbx_json	json;
 	char		error[MAX_STRING_LEN];
 	int		i, j, err = SUCCEED;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() jmx_endpoint:'%s' num:%d", __function_name, items[0].jmx_endpoint, num);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() jmx_endpoint:'%s' num:%d", __func__, items[0].jmx_endpoint, num);
 
 	for (j = 0; j < num; j++)	/* locate first supported item to use as a reference */
 	{
@@ -246,5 +242,5 @@ exit:
 		}
 	}
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
