@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -102,7 +102,6 @@ typedef struct
 zbx_snmpidx_mapping_t;
 
 static zbx_hashset_t	snmpidx;		/* Dynamic Index Cache */
-static char		zbx_snmp_init_done;
 
 static zbx_hash_t	__snmpidx_main_key_hash(const void *data)
 {
@@ -218,14 +217,12 @@ static char	*get_item_security_name(const DC_ITEM *item)
  ******************************************************************************/
 static int	cache_get_snmp_index(const DC_ITEM *item, const char *snmp_oid, const char *value, char **idx, size_t *idx_alloc)
 {
-	const char		*__function_name = "cache_get_snmp_index";
-
 	int			ret = FAIL;
 	zbx_snmpidx_main_key_t	*main_key, main_key_local;
 	zbx_snmpidx_mapping_t	*mapping;
 	size_t			idx_offset = 0;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s' value:'%s'", __function_name, snmp_oid, value);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s' value:'%s'", __func__, snmp_oid, value);
 
 	if (NULL == snmpidx.slots)
 		goto end;
@@ -246,7 +243,7 @@ static int	cache_get_snmp_index(const DC_ITEM *item, const char *snmp_oid, const
 	zbx_strcpy_alloc(idx, idx_alloc, &idx_offset, mapping->index);
 	ret = SUCCEED;
 end:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s idx:'%s'", __function_name, zbx_result_string(ret),
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s idx:'%s'", __func__, zbx_result_string(ret),
 			SUCCEED == ret ? *idx : "");
 
 	return ret;
@@ -268,12 +265,10 @@ end:
  ******************************************************************************/
 static void	cache_put_snmp_index(const DC_ITEM *item, const char *snmp_oid, const char *index, const char *value)
 {
-	const char		*__function_name = "cache_put_snmp_index";
-
 	zbx_snmpidx_main_key_t	*main_key, main_key_local;
 	zbx_snmpidx_mapping_t	*mapping, mapping_local;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s' index:'%s' value:'%s'", __function_name, snmp_oid, index, value);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s' index:'%s' value:'%s'", __func__, snmp_oid, index, value);
 
 	if (NULL == snmpidx.slots)
 	{
@@ -318,7 +313,7 @@ static void	cache_put_snmp_index(const DC_ITEM *item, const char *snmp_oid, cons
 		mapping->index = zbx_strdup(NULL, index);
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -338,11 +333,9 @@ static void	cache_put_snmp_index(const DC_ITEM *item, const char *snmp_oid, cons
  ******************************************************************************/
 static void	cache_del_snmp_index_subtree(const DC_ITEM *item, const char *snmp_oid)
 {
-	const char		*__function_name = "cache_del_snmp_index_subtree";
-
 	zbx_snmpidx_main_key_t	*main_key, main_key_local;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s'", __function_name, snmp_oid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s'", __func__, snmp_oid);
 
 	if (NULL == snmpidx.slots)
 		goto end;
@@ -359,7 +352,7 @@ static void	cache_del_snmp_index_subtree(const DC_ITEM *item, const char *snmp_o
 
 	zbx_hashset_clear(main_key->mappings);
 end:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 static char	*zbx_get_snmp_type_error(u_char type)
@@ -421,14 +414,13 @@ static int	zbx_get_snmp_response_error(const struct snmp_session *ss, const DC_I
 
 static struct snmp_session	*zbx_snmp_open_session(const DC_ITEM *item, char *error, size_t max_error_len)
 {
-	const char		*__function_name = "zbx_snmp_open_session";
 	struct snmp_session	session, *ss = NULL;
 	char			addr[128];
 #ifdef HAVE_IPV6
 	int			family;
 #endif
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	snmp_sess_init(&session);
 
@@ -632,34 +624,29 @@ static struct snmp_session	*zbx_snmp_open_session(const DC_ITEM *item, char *err
 		zbx_strlcpy(error, "Cannot open SNMP session", max_error_len);
 	}
 end:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return ss;
 }
 
 static void	zbx_snmp_close_session(struct snmp_session *session)
 {
-	const char	*__function_name = "zbx_snmp_close_session";
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	snmp_close(session);
 	SOCK_CLEANUP;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
-static char	*zbx_snmp_get_octet_string(const struct variable_list *var, unsigned char *string_type)
+static char	*zbx_snmp_get_octet_string(const struct variable_list *var)
 {
-	const char	*__function_name = "zbx_snmp_get_octet_string";
-
 	const char	*hint;
-	char		buffer[MAX_BUFFER_LEN];
+	char		buffer[MAX_STRING_LEN];
 	char		*strval_dyn = NULL;
-	struct tree	*subtree;
-	unsigned char	type;
+	struct tree     *subtree;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	/* find the subtree to get display hint */
 	subtree = get_tree(var->name, var->name_length, get_tree_head());
@@ -669,27 +656,23 @@ static char	*zbx_snmp_get_octet_string(const struct variable_list *var, unsigned
 	if (-1 == snprint_value(buffer, sizeof(buffer), var->name, var->name_length, var))
 		goto end;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "%s() full value:'%s' hint:'%s'", __function_name, buffer, ZBX_NULL2STR(hint));
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() full value:'%s' hint:'%s'", __func__, buffer, ZBX_NULL2STR(hint));
 
 	if (0 == strncmp(buffer, "Hex-STRING: ", 12))
 	{
 		strval_dyn = zbx_strdup(strval_dyn, buffer + 12);
-		type = ZBX_SNMP_STR_HEX;
 	}
 	else if (NULL != hint && 0 == strncmp(buffer, "STRING: ", 8))
 	{
 		strval_dyn = zbx_strdup(strval_dyn, buffer + 8);
-		type = ZBX_SNMP_STR_STRING;
 	}
 	else if (0 == strncmp(buffer, "OID: ", 5))
 	{
 		strval_dyn = zbx_strdup(strval_dyn, buffer + 5);
-		type = ZBX_SNMP_STR_OID;
 	}
 	else if (0 == strncmp(buffer, "BITS: ", 6))
 	{
 		strval_dyn = zbx_strdup(strval_dyn, buffer + 6);
-		type = ZBX_SNMP_STR_BITS;
 	}
 	else
 	{
@@ -699,30 +682,24 @@ static char	*zbx_snmp_get_octet_string(const struct variable_list *var, unsigned
 		strval_dyn = (char *)zbx_malloc(strval_dyn, var->val_len + 1);
 		memcpy(strval_dyn, var->val.string, var->val_len);
 		strval_dyn[var->val_len] = '\0';
-		type = ZBX_SNMP_STR_ASCII;
 	}
 
-	if (NULL != string_type)
-		*string_type = type;
 end:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():'%s'", __function_name, ZBX_NULL2STR(strval_dyn));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():'%s'", __func__, ZBX_NULL2STR(strval_dyn));
 
 	return strval_dyn;
 }
 
-static int	zbx_snmp_set_result(const struct variable_list *var, AGENT_RESULT *result, unsigned char *string_type)
+static int	zbx_snmp_set_result(const struct variable_list *var, AGENT_RESULT *result)
 {
-	const char	*__function_name = "zbx_snmp_set_result";
 	char		*strval_dyn;
 	int		ret = SUCCEED;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%d", __function_name, (int)var->type);
-
-	*string_type = ZBX_SNMP_STR_UNDEFINED;
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%d", __func__, (int)var->type);
 
 	if (ASN_OCTET_STR == var->type || ASN_OBJECT_ID == var->type)
 	{
-		if (NULL == (strval_dyn = zbx_snmp_get_octet_string(var, string_type)))
+		if (NULL == (strval_dyn = zbx_snmp_get_octet_string(var)))
 		{
 			SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot receive string value: out of memory."));
 			ret = NOTSUPPORTED;
@@ -782,17 +759,13 @@ static int	zbx_snmp_set_result(const struct variable_list *var, AGENT_RESULT *re
 				(unsigned int)var->val.string[2],
 				(unsigned int)var->val.string[3]));
 	}
-	else if (ASN_NULL == var->type)
-	{
-		SET_STR_RESULT(result, zbx_strdup(NULL, "NULL"));
-	}
 	else
 	{
 		SET_MSG_RESULT(result, zbx_get_snmp_type_error(var->type));
 		ret = NOTSUPPORTED;
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -825,12 +798,9 @@ static int	zbx_snmp_print_oid(char *buffer, size_t buffer_len, const oid *objid,
 static int	zbx_snmp_choose_index(char *buffer, size_t buffer_len, const oid *objid, size_t objid_len,
 		size_t root_string_len, size_t root_numeric_len)
 {
-	const char	*__function_name = "zbx_snmp_choose_index";
-
 	oid	parsed_oid[MAX_OID_LEN];
 	size_t	parsed_oid_len = MAX_OID_LEN;
 	char	printed_oid[MAX_STRING_LEN];
-	char	*printed_oid_escaped;
 
 	/**************************************************************************************************************/
 	/*                                                                                                            */
@@ -890,7 +860,7 @@ static int	zbx_snmp_choose_index(char *buffer, size_t buffer_len, const oid *obj
 
 	if (-1 == zbx_snmp_print_oid(printed_oid, sizeof(printed_oid), objid, objid_len, ZBX_OID_INDEX_STRING))
 	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot print OID with string indices", __function_name);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot print OID with string indices", __func__);
 		goto numeric;
 	}
 
@@ -900,15 +870,11 @@ static int	zbx_snmp_choose_index(char *buffer, size_t buffer_len, const oid *obj
 		return SUCCEED;
 	}
 
-	printed_oid_escaped = zbx_dyn_escape_string(printed_oid, "\\");
-
-	if (NULL == snmp_parse_oid(printed_oid_escaped, parsed_oid, &parsed_oid_len))
+	if (NULL == snmp_parse_oid(printed_oid, parsed_oid, &parsed_oid_len))
 	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot parse OID '%s'", __function_name, printed_oid_escaped);
-		zbx_free(printed_oid_escaped);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot parse OID '%s'", __func__, printed_oid);
 		goto numeric;
 	}
-	zbx_free(printed_oid_escaped);
 
 	if (parsed_oid_len == objid_len && 0 == memcmp(parsed_oid, objid, parsed_oid_len * sizeof(oid)))
 	{
@@ -918,7 +884,7 @@ static int	zbx_snmp_choose_index(char *buffer, size_t buffer_len, const oid *obj
 numeric:
 	if (-1 == zbx_snmp_print_oid(printed_oid, sizeof(printed_oid), objid, objid_len, ZBX_OID_INDEX_NUMERIC))
 	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot print OID with numeric indices", __function_name);
+		zabbix_log(LOG_LEVEL_DEBUG, "%s(): cannot print OID with numeric indices", __func__);
 		return FAIL;
 	}
 
@@ -1036,8 +1002,6 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 		size_t max_error_len, int *max_succeed, int *min_fail, int max_vars, int bulk,
 		zbx_snmp_walk_cb_func walk_cb_func, void *walk_cb_arg)
 {
-	const char		*__function_name = "zbx_snmp_walk";
-
 	struct snmp_pdu		*pdu, *response;
 	oid			anOID[MAX_OID_LEN], rootOID[MAX_OID_LEN];
 	size_t			anOID_len = MAX_OID_LEN, rootOID_len = MAX_OID_LEN, root_string_len, root_numeric_len;
@@ -1047,7 +1011,7 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 	AGENT_RESULT		snmp_result;
 	zbx_hashset_t		oids_seen;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%d OID:'%s' bulk:%d", __function_name, (int)item->type, snmp_oid, bulk);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%d OID:'%s' bulk:%d", __func__, (int)item->type, snmp_oid, bulk);
 
 	if (ITEM_TYPE_SNMPv1 == item->type)	/* GetBulkRequest-PDU available since SNMPv2 */
 		bulk = SNMP_BULK_DISABLED;
@@ -1118,7 +1082,7 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 		status = snmp_synch_response(ss, pdu, &response);
 
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() snmp_synch_response() status:%d s_snmp_errno:%d errstat:%ld"
-				" max_vars:%d", __function_name, status, ss->s_snmp_errno,
+				" max_vars:%d", __func__, status, ss->s_snmp_errno,
 				NULL == response ? (long)-1 : response->errstat, max_vars);
 
 		if (1 < max_vars &&
@@ -1153,9 +1117,6 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 		/* process response */
 		for (num_vars = 0, var = response->variables; NULL != var; num_vars++, var = var->next_variable)
 		{
-			char		**str_res;
-			unsigned char	val_type;
-
 			/* verify if we are in the same subtree */
 			if (SNMP_ENDOFMIBVIEW == var->type || var->name_length < rootOID_len ||
 					0 != memcmp(rootOID, var->name, rootOID_len * sizeof(oid)))
@@ -1216,18 +1177,14 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 					break;
 				}
 
-				str_res = NULL;
 				init_result(&snmp_result);
 
-				if (SUCCEED == zbx_snmp_set_result(var, &snmp_result, &val_type))
+				if (SUCCEED == zbx_snmp_set_result(var, &snmp_result) &&
+						NULL != GET_STR_RESULT(&snmp_result))
 				{
-					if (ISSET_TEXT(&snmp_result) && ZBX_SNMP_STR_HEX == val_type)
-						zbx_remove_chars(snmp_result.text, "\r\n");
-
-					str_res = GET_STR_RESULT(&snmp_result);
+					walk_cb_func(walk_cb_arg, snmp_oid, oid_index, snmp_result.str);
 				}
-
-				if (NULL == str_res)
+				else
 				{
 					char	**msg;
 
@@ -1236,8 +1193,6 @@ static int	zbx_snmp_walk(struct snmp_session *ss, const DC_ITEM *item, const cha
 					zabbix_log(LOG_LEVEL_DEBUG, "cannot get index '%s' string value: %s",
 							oid_index, NULL != msg && NULL != *msg ? *msg : "(null)");
 				}
-				else
-					walk_cb_func(walk_cb_arg, snmp_oid, oid_index, snmp_result.str);
 
 				free_result(&snmp_result);
 
@@ -1269,26 +1224,23 @@ next:
 	if (0 == check_oid_increase)
 		zbx_hashset_destroy(&oids_seen);
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
 static int	zbx_snmp_get_values(struct snmp_session *ss, const DC_ITEM *items, char oids[][ITEM_SNMP_OID_LEN_MAX],
 		AGENT_RESULT *results, int *errcodes, unsigned char *query_and_ignore_type, int num, int level,
-		char *error, size_t max_error_len, int *max_succeed, int *min_fail, unsigned char poller_type)
+		char *error, size_t max_error_len, int *max_succeed, int *min_fail)
 {
-	const char		*__function_name = "zbx_snmp_get_values";
-
 	int			i, j, status, ret = SUCCEED;
 	int			mapping[MAX_SNMP_ITEMS], mapping_num = 0;
 	oid			parsed_oids[MAX_SNMP_ITEMS][MAX_OID_LEN];
 	size_t			parsed_oid_lens[MAX_SNMP_ITEMS];
 	struct snmp_pdu		*pdu, *response;
 	struct variable_list	*var;
-	unsigned char		val_type;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() num:%d level:%d", __function_name, num, level);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() num:%d level:%d", __func__, num, level);
 
 	if (NULL == (pdu = snmp_pdu_create(SNMP_MSG_GET)))
 	{
@@ -1331,12 +1283,12 @@ static int	zbx_snmp_get_values(struct snmp_session *ss, const DC_ITEM *items, ch
 		goto out;
 	}
 
-	ss->retries = (1 == mapping_num && 0 == level && ZBX_POLLER_TYPE_UNREACHABLE != poller_type ? 1 : 0);
+	ss->retries = (1 == mapping_num && 0 == level ? 1 : 0);
 retry:
 	status = snmp_synch_response(ss, pdu, &response);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "%s() snmp_synch_response() status:%d s_snmp_errno:%d errstat:%ld mapping_num:%d",
-			__function_name, status, ss->s_snmp_errno, NULL == response ? (long)-1 : response->errstat,
+			__func__, status, ss->s_snmp_errno, NULL == response ? (long)-1 : response->errstat,
 			mapping_num);
 
 	if (STAT_SUCCESS == status && SNMP_ERR_NOERROR == response->errstat)
@@ -1409,12 +1361,13 @@ retry:
 			/* process received data */
 
 			if (NULL != query_and_ignore_type && 1 == query_and_ignore_type[j])
-				(void)zbx_snmp_set_result(var, &results[j], &val_type);
+			{
+				(void)zbx_snmp_set_result(var, &results[j]);
+			}
 			else
-				errcodes[j] = zbx_snmp_set_result(var, &results[j], &val_type);
-
-			if (ISSET_TEXT(&results[j]) && ZBX_SNMP_STR_HEX == val_type)
-				zbx_remove_chars(results[j].text, "\r\n");
+			{
+				errcodes[j] = zbx_snmp_set_result(var, &results[j]);
+			}
 		}
 
 		if (SUCCEED == ret)
@@ -1422,7 +1375,11 @@ retry:
 			if (*max_succeed < mapping_num)
 				*max_succeed = mapping_num;
 		}
-		/* min_fail value is updated when bulk request is halved in the case of failure */
+		else if (1 < mapping_num)
+		{
+			if (*min_fail > mapping_num)
+				*min_fail = mapping_num;
+		}
 	}
 	else if (STAT_SUCCESS == status && SNMP_ERR_NOSUCHNAME == response->errstat && 0 != response->errindex)
 	{
@@ -1448,7 +1405,7 @@ retry:
 
 		j = mapping[i];
 
-		zabbix_log(LOG_LEVEL_DEBUG, "%s() snmp_synch_response() errindex:%ld OID:'%s'", __function_name,
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() snmp_synch_response() errindex:%ld OID:'%s'", __func__,
 				response->errindex, oids[j]);
 
 		if (NULL == query_and_ignore_type || 0 == query_and_ignore_type[j])
@@ -1505,7 +1462,7 @@ halve:
 			int	base;
 
 			ret = zbx_snmp_get_values(ss, items, oids, results, errcodes, query_and_ignore_type, num / 2,
-					level + 1, error, max_error_len, max_succeed, min_fail, poller_type);
+					level + 1, error, max_error_len, max_succeed, min_fail);
 
 			if (SUCCEED != ret)
 				goto exit;
@@ -1514,7 +1471,7 @@ halve:
 
 			ret = zbx_snmp_get_values(ss, items + base, oids + base, results + base, errcodes + base,
 					NULL == query_and_ignore_type ? NULL : query_and_ignore_type + base, num - base,
-					level + 1, error, max_error_len, max_succeed, min_fail, poller_type);
+					level + 1, error, max_error_len, max_succeed, min_fail);
 		}
 		else if (1 == level)
 		{
@@ -1527,7 +1484,7 @@ halve:
 
 				ret = zbx_snmp_get_values(ss, items + i, oids + i, results + i, errcodes + i,
 						NULL == query_and_ignore_type ? NULL : query_and_ignore_type + i, 1,
-						level + 1, error, max_error_len, max_succeed, min_fail, poller_type);
+						level + 1, error, max_error_len, max_succeed, min_fail);
 
 				if (SUCCEED != ret)
 					goto exit;
@@ -1540,7 +1497,7 @@ exit:
 	if (NULL != response)
 		snmp_free_pdu(response);
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -1556,8 +1513,6 @@ out:
  ******************************************************************************/
 static void	zbx_snmp_translate(char *oid_translated, const char *snmp_oid, size_t max_oid_len)
 {
-	const char	*__function_name = "zbx_snmp_translate";
-
 	typedef struct
 	{
 		const size_t	sz;
@@ -1596,7 +1551,7 @@ static void	zbx_snmp_translate(char *oid_translated, const char *snmp_oid, size_
 
 	int	found = 0, i;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s'", __function_name, snmp_oid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() OID:'%s'", __func__, snmp_oid);
 
 	for (i = 0; 0 != mibs[i].sz; i++)
 	{
@@ -1611,7 +1566,7 @@ static void	zbx_snmp_translate(char *oid_translated, const char *snmp_oid, size_
 	if (0 == found)
 		zbx_strlcpy(oid_translated, snmp_oid, max_oid_len);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() oid_translated:'%s'", __function_name, oid_translated);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() oid_translated:'%s'", __func__, oid_translated);
 }
 
 /* discovered SNMP object, identified by its index */
@@ -1788,15 +1743,13 @@ static int	zbx_snmp_process_discovery(struct snmp_session *ss, const DC_ITEM *it
 		int *errcode, char *error, size_t max_error_len, int *max_succeed, int *min_fail, int max_vars,
 		int bulk)
 {
-	const char	*__function_name = "zbx_snmp_process_discovery";
-
 	int			i, j, ret;
 	char			oid_translated[ITEM_SNMP_OID_LEN_MAX];
 	struct zbx_json		js;
 	zbx_snmp_ddata_t	data;
 	zbx_snmp_dobject_t	*obj;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	if (SUCCEED != (ret = zbx_snmp_ddata_init(&data, item->snmp_oid, error, max_error_len)))
 		goto out;
@@ -1812,8 +1765,7 @@ static int	zbx_snmp_process_discovery(struct snmp_session *ss, const DC_ITEM *it
 		}
 	}
 
-	zbx_json_init(&js, ZBX_JSON_STAT_BUF_LEN);
-	zbx_json_addarray(&js, ZBX_PROTO_TAG_DATA);
+	zbx_json_initarray(&js, ZBX_JSON_STAT_BUF_LEN);
 
 	for (i = 0; i < data.index.values_num; i++)
 	{
@@ -1843,7 +1795,7 @@ out:
 	if (SUCCEED != (*errcode = ret))
 		SET_MSG_RESULT(result, zbx_strdup(NULL, error));
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -1854,11 +1806,8 @@ static void	zbx_snmp_walk_cache_cb(void *arg, const char *snmp_oid, const char *
 }
 
 static int	zbx_snmp_process_dynamic(struct snmp_session *ss, const DC_ITEM *items, AGENT_RESULT *results,
-		int *errcodes, int num, char *error, size_t max_error_len, int *max_succeed, int *min_fail, int bulk,
-		unsigned char poller_type)
+		int *errcodes, int num, char *error, size_t max_error_len, int *max_succeed, int *min_fail, int bulk)
 {
-	const char	*__function_name = "zbx_snmp_process_dynamic";
-
 	int		i, j, k, ret;
 	int		to_walk[MAX_SNMP_ITEMS], to_walk_num = 0;
 	int		to_verify[MAX_SNMP_ITEMS], to_verify_num = 0;
@@ -1870,7 +1819,7 @@ static int	zbx_snmp_process_dynamic(struct snmp_session *ss, const DC_ITEM *item
 	char		*idx = NULL, *pl;
 	size_t		idx_alloc = 32;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	idx = (char *)zbx_malloc(idx, idx_alloc);
 
@@ -1924,7 +1873,7 @@ static int	zbx_snmp_process_dynamic(struct snmp_session *ss, const DC_ITEM *item
 	if (0 != to_verify_num)
 	{
 		ret = zbx_snmp_get_values(ss, items, to_verify_oids, results, errcodes, query_and_ignore_type, num, 0,
-				error, max_error_len, max_succeed, min_fail, poller_type);
+				error, max_error_len, max_succeed, min_fail);
 
 		if (SUCCEED != ret && NOTSUPPORTED != ret)
 			goto exit;
@@ -2048,25 +1997,22 @@ static int	zbx_snmp_process_dynamic(struct snmp_session *ss, const DC_ITEM *item
 	/* query values based on the indices verified and/or determined above */
 
 	ret = zbx_snmp_get_values(ss, items, oids_translated, results, errcodes, NULL, num, 0, error, max_error_len,
-			max_succeed, min_fail, poller_type);
+			max_succeed, min_fail);
 exit:
 	zbx_free(idx);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
 static int	zbx_snmp_process_standard(struct snmp_session *ss, const DC_ITEM *items, AGENT_RESULT *results,
-		int *errcodes, int num, char *error, size_t max_error_len, int *max_succeed, int *min_fail,
-		unsigned char poller_type)
+		int *errcodes, int num, char *error, size_t max_error_len, int *max_succeed, int *min_fail)
 {
-	const char	*__function_name = "zbx_snmp_process_standard";
+	int	i, ret;
+	char	oids_translated[MAX_SNMP_ITEMS][ITEM_SNMP_OID_LEN_MAX];
 
-	int		i, ret;
-	char		oids_translated[MAX_SNMP_ITEMS][ITEM_SNMP_OID_LEN_MAX];
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	for (i = 0; i < num; i++)
 	{
@@ -2085,55 +2031,31 @@ static int	zbx_snmp_process_standard(struct snmp_session *ss, const DC_ITEM *ite
 	}
 
 	ret = zbx_snmp_get_values(ss, items, oids_translated, results, errcodes, NULL, num, 0, error, max_error_len,
-			max_succeed, min_fail, poller_type);
+			max_succeed, min_fail);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
-int	get_value_snmp(const DC_ITEM *item, AGENT_RESULT *result, unsigned char poller_type)
+int	get_value_snmp(const DC_ITEM *item, AGENT_RESULT *result)
 {
 	int	errcode = SUCCEED;
 
-	get_values_snmp(item, result, &errcode, 1, poller_type);
+	get_values_snmp(item, result, &errcode, 1);
 
 	return errcode;
 }
 
-static void	zbx_init_snmp(void)
+void	get_values_snmp(const DC_ITEM *items, AGENT_RESULT *results, int *errcodes, int num)
 {
-	sigset_t	mask, orig_mask;
-
-	if (1 == zbx_snmp_init_done)
-		return;
-
-	sigemptyset(&mask);
-	sigaddset(&mask, SIGTERM);
-	sigaddset(&mask, SIGUSR2);
-	sigaddset(&mask, SIGHUP);
-	sigaddset(&mask, SIGQUIT);
-	sigprocmask(SIG_BLOCK, &mask, &orig_mask);
-
-	init_snmp(progname);
-	zbx_snmp_init_done = 1;
-
-	sigprocmask(SIG_SETMASK, &orig_mask, NULL);
-}
-
-void	get_values_snmp(const DC_ITEM *items, AGENT_RESULT *results, int *errcodes, int num, unsigned char poller_type)
-{
-	const char		*__function_name = "get_values_snmp";
-
 	struct snmp_session	*ss;
 	char			error[MAX_STRING_LEN];
 	int			i, j, err = SUCCEED, max_succeed = 0, min_fail = MAX_SNMP_ITEMS + 1,
 				bulk = SNMP_BULK_ENABLED;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() host:'%s' addr:'%s' num:%d",
-			__function_name, items[0].host.host, items[0].interface.addr, num);
-
-	zbx_init_snmp();	/* avoid high CPU usage by only initializing SNMP once used */
+			__func__, items[0].host.host, items[0].interface.addr, num);
 
 	for (j = 0; j < num; j++)	/* locate first supported item to use as a reference */
 	{
@@ -2164,12 +2086,12 @@ void	get_values_snmp(const DC_ITEM *items, AGENT_RESULT *results, int *errcodes,
 		(void)DCconfig_get_suggested_snmp_vars(items[j].interface.interfaceid, &bulk);
 
 		err = zbx_snmp_process_dynamic(ss, items + j, results + j, errcodes + j, num - j, error, sizeof(error),
-				&max_succeed, &min_fail, bulk, poller_type);
+				&max_succeed, &min_fail, bulk);
 	}
 	else
 	{
 		err = zbx_snmp_process_standard(ss, items + j, results + j, errcodes + j, num - j, error, sizeof(error),
-				&max_succeed, &min_fail, poller_type);
+				&max_succeed, &min_fail);
 	}
 
 	zbx_snmp_close_session(ss);
@@ -2192,7 +2114,23 @@ exit:
 		DCconfig_update_interface_snmp_stats(items[j].interface.interfaceid, max_succeed, min_fail);
 	}
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
+}
+
+void	zbx_init_snmp(void)
+{
+	sigset_t	mask, orig_mask;
+
+	sigemptyset(&mask);
+	sigaddset(&mask, SIGTERM);
+	sigaddset(&mask, SIGUSR2);
+	sigaddset(&mask, SIGABRT);
+	sigaddset(&mask, SIGQUIT);
+	sigprocmask(SIG_BLOCK, &mask, &orig_mask);
+
+	init_snmp(progname);
+
+	sigprocmask(SIG_SETMASK, &orig_mask, NULL);
 }
 
 #endif	/* HAVE_NETSNMP */
