@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -30,19 +30,16 @@
 #include "scripts.h"
 
 extern int	CONFIG_TRAPPER_TIMEOUT;
-extern int	CONFIG_IPMIPOLLER_FORKS;
 
 static int	zbx_execute_script_on_agent(const DC_HOST *host, const char *command, char **result,
 		char *error, size_t max_error_len)
 {
-	const char	*__function_name = "zbx_execute_script_on_agent";
-
 	int		ret;
 	AGENT_RESULT	agent_result;
 	char		*param = NULL, *port = NULL;
 	DC_ITEM		item;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	*error = '\0';
 	memset(&item, 0, sizeof(item));
@@ -96,7 +93,7 @@ fail:
 	zbx_free(port);
 	zbx_free(param);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -104,20 +101,18 @@ fail:
 static int	zbx_execute_script_on_terminal(const DC_HOST *host, const zbx_script_t *script, char **result,
 		char *error, size_t max_error_len)
 {
-	const char	*__function_name = "zbx_execute_script_on_terminal";
-
 	int		ret = FAIL, i;
 	AGENT_RESULT	agent_result;
 	DC_ITEM		item;
 	int             (*function)(DC_ITEM *, AGENT_RESULT *);
 
-#if defined(HAVE_SSH2) || defined(HAVE_SSH)
+#ifdef HAVE_SSH2
 	assert(ZBX_SCRIPT_TYPE_SSH == script->type || ZBX_SCRIPT_TYPE_TELNET == script->type);
 #else
 	assert(ZBX_SCRIPT_TYPE_TELNET == script->type);
 #endif
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	*error = '\0';
 	memset(&item, 0, sizeof(item));
@@ -151,7 +146,7 @@ static int	zbx_execute_script_on_terminal(const DC_HOST *host, const zbx_script_
 			break;
 	}
 
-#if defined(HAVE_SSH2) || defined(HAVE_SSH)
+#ifdef HAVE_SSH2
 	if (ZBX_SCRIPT_TYPE_SSH == script->type)
 	{
 		item.key = zbx_dsprintf(item.key, "ssh.run[,,%s]", script->port);
@@ -162,7 +157,7 @@ static int	zbx_execute_script_on_terminal(const DC_HOST *host, const zbx_script_
 #endif
 		item.key = zbx_dsprintf(item.key, "telnet.run[,,%s]", script->port);
 		function = get_value_telnet;
-#if defined(HAVE_SSH2) || defined(HAVE_SSH)
+#ifdef HAVE_SSH2
 	}
 #endif
 	item.value_type = ITEM_VALUE_TYPE_TEXT;
@@ -188,20 +183,18 @@ static int	zbx_execute_script_on_terminal(const DC_HOST *host, const zbx_script_
 	zbx_free(item.params);
 	zbx_free(item.key);
 fail:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
 static int	DBget_script_by_scriptid(zbx_uint64_t scriptid, zbx_script_t *script, zbx_uint64_t *groupid)
 {
-	const char	*__function_name = "DBget_script_by_scriptid";
-
 	DB_RESULT	result;
 	DB_ROW		row;
 	int		ret = FAIL;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	result = DBselect(
 			"select type,execute_on,command,groupid,host_access"
@@ -220,23 +213,20 @@ static int	DBget_script_by_scriptid(zbx_uint64_t scriptid, zbx_script_t *script,
 	}
 	DBfree_result(result);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
 static int	check_script_permissions(zbx_uint64_t groupid, zbx_uint64_t hostid)
 {
-	const char		*__function_name = "check_script_permissions";
-
 	DB_RESULT		result;
 	int			ret = SUCCEED;
 	zbx_vector_uint64_t	groupids;
 	char			*sql = NULL;
 	size_t			sql_alloc = 0, sql_offset = 0;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() groupid:" ZBX_FS_UI64 " hostid:" ZBX_FS_UI64,
-			__function_name, groupid, hostid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() groupid:" ZBX_FS_UI64 " hostid:" ZBX_FS_UI64, __func__, groupid, hostid);
 
 	if (0 == groupid)
 		goto exit;
@@ -264,20 +254,19 @@ static int	check_script_permissions(zbx_uint64_t groupid, zbx_uint64_t hostid)
 
 	DBfree_result(result);
 exit:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
 
 static int	check_user_permissions(zbx_uint64_t userid, const DC_HOST *host, zbx_script_t *script)
 {
-	const char	*__function_name = "check_user_permissions";
-
 	int		ret = SUCCEED;
 	DB_RESULT	result;
+	DB_ROW		row;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() userid:" ZBX_FS_UI64 " hostid:" ZBX_FS_UI64 " scriptid:" ZBX_FS_UI64,
-			__function_name, userid, host->hostid, script->scriptid);
+			__func__, userid, host->hostid, script->scriptid);
 
 	result = DBselect(
 		"select null"
@@ -294,12 +283,12 @@ static int	check_user_permissions(zbx_uint64_t userid, const DC_HOST *host, zbx_
 		PERM_DENY,
 		script->host_access);
 
-	if (NULL == DBfetch(result))
+	if (NULL == (row = DBfetch(result)))
 		ret = FAIL;
 
 	DBfree_result(result);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -343,12 +332,10 @@ void	zbx_script_clean(zbx_script_t *script)
 int	zbx_script_prepare(zbx_script_t *script, const DC_HOST *host, const zbx_user_t *user, char *error,
 		size_t max_error_len)
 {
-	const char	*__function_name = "zbx_script_prepare";
-
 	int		ret = FAIL;
 	zbx_uint64_t	groupid;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	switch (script->type)
 	{
@@ -423,7 +410,7 @@ int	zbx_script_prepare(zbx_script_t *script, const DC_HOST *host, const zbx_user
 
 	ret = SUCCEED;
 out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 	return ret;
 }
 
@@ -441,11 +428,9 @@ out:
 int	zbx_script_execute(const zbx_script_t *script, const DC_HOST *host, char **result, char *error,
 		size_t max_error_len)
 {
-	const char	*__function_name = "zbx_script_execute";
+	int	ret = FAIL;
 
-	int		ret = FAIL;
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	*error = '\0';
 
@@ -460,11 +445,8 @@ int	zbx_script_execute(const zbx_script_t *script, const DC_HOST *host, char **r
 					break;
 				case ZBX_SCRIPT_EXECUTE_ON_SERVER:
 				case ZBX_SCRIPT_EXECUTE_ON_PROXY:
-					if (SUCCEED != (ret = zbx_execute(script->command, result, error, max_error_len,
-							CONFIG_TRAPPER_TIMEOUT, ZBX_EXIT_CODE_CHECKS_ENABLED)))
-					{
-						ret = FAIL;
-					}
+					ret = zbx_execute(script->command, result, error, max_error_len,
+							CONFIG_TRAPPER_TIMEOUT, ZBX_EXIT_CODE_CHECKS_ENABLED);
 					break;
 				default:
 					zbx_snprintf(error, max_error_len, "Invalid 'Execute on' option \"%d\".",
@@ -473,13 +455,6 @@ int	zbx_script_execute(const zbx_script_t *script, const DC_HOST *host, char **r
 			break;
 		case ZBX_SCRIPT_TYPE_IPMI:
 #ifdef HAVE_OPENIPMI
-			if (0 == CONFIG_IPMIPOLLER_FORKS)
-			{
-				zbx_strlcpy(error, "Cannot perform IPMI request: configuration parameter"
-						" \"StartIPMIPollers\" is 0.", max_error_len);
-				break;
-			}
-
 			if (SUCCEED == (ret = zbx_ipmi_execute_command(host, script->command, error, max_error_len)))
 			{
 				if (NULL != result)
@@ -490,7 +465,7 @@ int	zbx_script_execute(const zbx_script_t *script, const DC_HOST *host, char **r
 #endif
 			break;
 		case ZBX_SCRIPT_TYPE_SSH:
-#if !defined(HAVE_SSH2) && !defined(HAVE_SSH)
+#ifndef HAVE_SSH2
 			zbx_strlcpy(error, "Support for SSH script was not compiled in.", max_error_len);
 			break;
 #endif
@@ -504,7 +479,7 @@ int	zbx_script_execute(const zbx_script_t *script, const DC_HOST *host, char **r
 	if (SUCCEED != ret && NULL != result)
 		*result = zbx_strdup(*result, "");
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -530,8 +505,6 @@ zbx_uint64_t	zbx_script_create_task(const zbx_script_t *script, const DC_HOST *h
 	else
 		port = 0;
 
-	DBbegin();
-
 	taskid = DBget_maxid("task");
 
 	task = zbx_tm_task_create(taskid, ZBX_TM_TASK_REMOTE_COMMAND, ZBX_TM_STATUS_NEW, now,
@@ -541,6 +514,8 @@ zbx_uint64_t	zbx_script_create_task(const zbx_script_t *script, const DC_HOST *h
 			script->authtype, script->username, script->password, script->publickey, script->privatekey,
 			taskid, host->hostid, alertid);
 
+	DBbegin();
+
 	if (FAIL == zbx_tm_save_task(task))
 		taskid = 0;
 
