@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,11 +51,9 @@ extern int		server_num, process_num;
 static void	tm_execute_task_close_problem(zbx_uint64_t taskid, zbx_uint64_t triggerid, zbx_uint64_t eventid,
 		zbx_uint64_t userid)
 {
-	const char		*__function_name = "tm_execute_task_close_problem";
-
 	DB_RESULT	result;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() eventid:" ZBX_FS_UI64, __function_name, eventid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() eventid:" ZBX_FS_UI64, __func__, eventid);
 
 	result = DBselect("select null from problem where eventid=" ZBX_FS_UI64 " and r_eventid is null", eventid);
 
@@ -67,7 +65,7 @@ static void	tm_execute_task_close_problem(zbx_uint64_t taskid, zbx_uint64_t trig
 
 	DBexecute("update task set status=%d where taskid=" ZBX_FS_UI64, ZBX_TM_STATUS_DONE, taskid);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -84,70 +82,49 @@ static void	tm_execute_task_close_problem(zbx_uint64_t taskid, zbx_uint64_t trig
  ******************************************************************************/
 static int	tm_try_task_close_problem(zbx_uint64_t taskid)
 {
-	const char		*__function_name = "tm_try_task_close_problem";
-
 	DB_ROW			row;
 	DB_RESULT		result;
 	int			ret = FAIL;
 	zbx_uint64_t		userid, triggerid, eventid;
 	zbx_vector_uint64_t	triggerids, locked_triggerids;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __function_name, taskid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __func__, taskid);
 
 	zbx_vector_uint64_create(&triggerids);
 	zbx_vector_uint64_create(&locked_triggerids);
 
 	result = DBselect("select a.userid,a.eventid,e.objectid"
-				" from task_close_problem tcp"
-				" left join acknowledges a"
-					" on tcp.acknowledgeid=a.acknowledgeid"
+				" from task_close_problem tcp,acknowledges a"
 				" left join events e"
 					" on a.eventid=e.eventid"
-				" where tcp.taskid=" ZBX_FS_UI64,
+				" where tcp.taskid=" ZBX_FS_UI64
+					" and tcp.acknowledgeid=a.acknowledgeid",
 			taskid);
 
 	if (NULL != (row = DBfetch(result)))
 	{
-		if (SUCCEED == DBis_null(row[0]))
+		ZBX_STR2UINT64(triggerid, row[2]);
+		zbx_vector_uint64_append(&triggerids, triggerid);
+		DCconfig_lock_triggers_by_triggerids(&triggerids, &locked_triggerids);
+
+		/* only close the problem if source trigger was successfully locked */
+		if (0 != locked_triggerids.values_num)
 		{
-			zabbix_log(LOG_LEVEL_DEBUG, "cannot process close problem task because related event"
-					" was removed");
-			DBexecute("update task set status=%d where taskid=" ZBX_FS_UI64, ZBX_TM_STATUS_DONE, taskid);
+			ZBX_STR2UINT64(userid, row[0]);
+			ZBX_STR2UINT64(eventid, row[1]);
+			tm_execute_task_close_problem(taskid, triggerid, eventid, userid);
+
+			DCconfig_unlock_triggers(&locked_triggerids);
 
 			ret = SUCCEED;
 		}
-		else
-		{
-			ZBX_STR2UINT64(triggerid, row[2]);
-			zbx_vector_uint64_append(&triggerids, triggerid);
-			DCconfig_lock_triggers_by_triggerids(&triggerids, &locked_triggerids);
-
-			/* close the problem if source trigger was successfully locked or */
-			/* if the trigger doesn't exist, but event still exists */
-			if (0 != locked_triggerids.values_num)
-			{
-				ZBX_STR2UINT64(userid, row[0]);
-				ZBX_STR2UINT64(eventid, row[1]);
-				tm_execute_task_close_problem(taskid, triggerid, eventid, userid);
-
-				DCconfig_unlock_triggers(&locked_triggerids);
-
-				ret = SUCCEED;
-			}
-			else if (FAIL == DCconfig_trigger_exists(triggerid))
-			{
-				DBexecute("update task set status=%d where taskid=" ZBX_FS_UI64, ZBX_TM_STATUS_DONE,
-						taskid);
-				ret = SUCCEED;
-			}
-		}
 	}
 	DBfree_result(result);
 
 	zbx_vector_uint64_destroy(&locked_triggerids);
 	zbx_vector_uint64_destroy(&triggerids);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -161,14 +138,12 @@ static int	tm_try_task_close_problem(zbx_uint64_t taskid)
  ******************************************************************************/
 static void	tm_expire_remote_command(zbx_uint64_t taskid)
 {
-	const char	*__function_name = "tm_expire_remote_command";
-
 	DB_ROW		row;
 	DB_RESULT	result;
 	zbx_uint64_t	alertid;
 	char		*error;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __function_name, taskid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __func__, taskid);
 
 	DBbegin();
 
@@ -193,7 +168,7 @@ static void	tm_expire_remote_command(zbx_uint64_t taskid)
 
 	DBcommit();
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
 /******************************************************************************
@@ -208,8 +183,6 @@ static void	tm_expire_remote_command(zbx_uint64_t taskid)
  ******************************************************************************/
 static int	tm_process_remote_command_result(zbx_uint64_t taskid)
 {
-	const char	*__function_name = "tm_process_remote_command_result";
-
 	DB_ROW		row;
 	DB_RESULT	result;
 	zbx_uint64_t	alertid, parent_taskid = 0;
@@ -217,7 +190,7 @@ static int	tm_process_remote_command_result(zbx_uint64_t taskid)
 	char		*error, *sql = NULL;
 	size_t		sql_alloc = 0, sql_offset = 0;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __function_name, taskid);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() taskid:" ZBX_FS_UI64, __func__, taskid);
 
 	DBbegin();
 
@@ -267,7 +240,7 @@ static int	tm_process_remote_command_result(zbx_uint64_t taskid)
 
 	DBcommit();
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
@@ -283,8 +256,6 @@ static int	tm_process_remote_command_result(zbx_uint64_t taskid)
  ******************************************************************************/
 static int	tm_process_acknowledgements(zbx_vector_uint64_t *ack_taskids)
 {
-	const char		*__function_name = "tm_process_acknowledgements";
-
 	DB_ROW			row;
 	DB_RESULT		result;
 	int			processed_num = 0;
@@ -293,7 +264,7 @@ static int	tm_process_acknowledgements(zbx_vector_uint64_t *ack_taskids)
 	zbx_vector_ptr_t	ack_tasks;
 	zbx_ack_task_t		*ack_task;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() tasks_num:%d", __function_name, ack_taskids->values_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() tasks_num:%d", __func__, ack_taskids->values_num);
 
 	zbx_vector_uint64_sort(ack_taskids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
 
@@ -347,7 +318,7 @@ static int	tm_process_acknowledgements(zbx_vector_uint64_t *ack_taskids)
 	zbx_vector_ptr_clear_ext(&ack_tasks, zbx_ptr_free);
 	zbx_vector_ptr_destroy(&ack_tasks);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() processed:%d", __function_name, processed_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() processed:%d", __func__, processed_num);
 
 	return processed_num;
 }
@@ -363,8 +334,6 @@ static int	tm_process_acknowledgements(zbx_vector_uint64_t *ack_taskids)
  ******************************************************************************/
 static int	tm_process_check_now(zbx_vector_uint64_t *taskids)
 {
-	const char		*__function_name = "tm_process_check_now";
-
 	DB_ROW			row;
 	DB_RESULT		result;
 	int			i, processed_num = 0;
@@ -376,7 +345,7 @@ static int	tm_process_check_now(zbx_vector_uint64_t *taskids)
 	zbx_tm_task_t		*task;
 	zbx_tm_check_now_t	*data;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() tasks_num:%d", __function_name, taskids->values_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() tasks_num:%d", __func__, taskids->values_num);
 
 	zbx_vector_ptr_create(&tasks);
 	zbx_vector_uint64_create(&done_taskids);
@@ -495,7 +464,7 @@ static int	tm_process_check_now(zbx_vector_uint64_t *taskids)
 	zbx_vector_uint64_destroy(&done_taskids);
 	zbx_vector_ptr_destroy(&tasks);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() processed:%d", __function_name, processed_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() processed:%d", __func__, processed_num);
 
 	return processed_num;
 }
@@ -636,8 +605,6 @@ ZBX_THREAD_ENTRY(taskmanager_thread, args)
 	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(program_type),
 			server_num, get_process_type_string(process_type), process_num);
 
-	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
-
 	zbx_setproctitle("%s [connecting to the database]", get_process_type_string(process_type));
 	DBconnect(ZBX_DB_CONNECT_NORMAL);
 
