@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,8 +50,7 @@ typedef struct
 }
 zbx_str_uint64_pair_t;
 
-ZBX_PTR_VECTOR_DECL(str_uint64_pair, zbx_str_uint64_pair_t)
-int	zbx_str_uint64_pair_name_compare(const void *p1, const void *p2);
+ZBX_VECTOR_DECL(str_uint64_pair, zbx_str_uint64_pair_t)
 
 /* performance counter data */
 typedef struct
@@ -95,50 +94,20 @@ typedef struct
 }
 zbx_vmware_perf_entity_t;
 
-#define ZBX_VMWARE_DS_NONE		0
-#define ZBX_VMWARE_DS_MOUNTED		1
-#define ZBX_VMWARE_DS_ACCESSIBLE	2
-#define ZBX_VMWARE_DS_READ		4
-#define ZBX_VMWARE_DS_WRITE		8
-#define ZBX_VMWARE_DS_READWRITE		(ZBX_VMWARE_DS_READ | ZBX_VMWARE_DS_WRITE)
-#define ZBX_VMWARE_DS_READ_FILTER	(ZBX_VMWARE_DS_MOUNTED | ZBX_VMWARE_DS_ACCESSIBLE | ZBX_VMWARE_DS_READ)
-#define ZBX_VMWARE_DS_WRITE_FILTER	(ZBX_VMWARE_DS_MOUNTED | ZBX_VMWARE_DS_ACCESSIBLE | ZBX_VMWARE_DS_READWRITE)
-
-typedef struct
-{
-	char				*uuid;
-	char				*name;
-	char				*id;
-	zbx_uint64_t			capacity;
-	zbx_uint64_t			free_space;
-	zbx_uint64_t			uncommitted;
-	zbx_vector_str_uint64_pair_t	hv_uuids_access;
-}
-zbx_vmware_datastore_t;
-
-int	vmware_ds_uuid_compare(const void *d1, const void *d2);
-int	vmware_ds_name_compare(const void *d1, const void *d2);
-ZBX_PTR_VECTOR_DECL(vmware_datastore, zbx_vmware_datastore_t *)
-
-typedef struct
-{
-	char	*name;
-	char	*uuid;
-}
-zbx_vmware_ds_name_uuid_t;
-
-int	vmware_hvds_name_compare(const void *d1, const void *d2);
-ZBX_PTR_VECTOR_DECL(ds_name_uuid, zbx_vmware_ds_name_uuid_t)
-
 typedef struct
 {
 	char			*name;
+	char			*uuid;
 	char			*id;
+	zbx_uint64_t		capacity;
+	zbx_uint64_t		free_space;
+	zbx_uint64_t		uncommitted;
+	zbx_vector_str_t	hv_uuids;
 }
-zbx_vmware_datacenter_t;
+zbx_vmware_datastore_t;
 
-int	vmware_dc_name_compare(const void *d1, const void *d2);
-ZBX_PTR_VECTOR_DECL(vmware_datacenter, zbx_vmware_datacenter_t *)
+int	vmware_ds_name_compare(const void *d1, const void *d2);
+ZBX_PTR_VECTOR_DECL(vmware_datastore, zbx_vmware_datastore_t *)
 
 #define ZBX_VMWARE_DEV_TYPE_NIC		1
 #define ZBX_VMWARE_DEV_TYPE_DISK	2
@@ -173,15 +142,15 @@ zbx_vmware_vm_t;
 /* the vmware hypervisor data */
 typedef struct
 {
-	char				*uuid;
-	char				*id;
-	char				*clusterid;
-	char				*datacenter_name;
-	char				*parent_name;
-	char				*parent_type;
-	char				**props;
-	zbx_vector_ds_name_uuid_t	ds_names;
-	zbx_vector_ptr_t		vms;
+	char			*uuid;
+	char			*id;
+	char			*clusterid;
+	char			*datacenter_name;
+	char			*parent_name;
+	char			*parent_type;
+	char			**props;
+	zbx_vector_str_t	ds_names;
+	zbx_vector_ptr_t	vms;
 }
 zbx_vmware_hv_t;
 
@@ -207,8 +176,7 @@ typedef struct
 {
 	zbx_uint64_t	last_key;	/* lastlogsize when vmware.eventlog[] item was polled last time */
 	unsigned char	skip_old;	/* skip old event log records */
-	unsigned char	oom;		/* no enough memory to store new events */
-	zbx_uint64_t	req_sz;		/* memory size required to store events */
+
 }
 zbx_vmware_eventlog_state_t;
 
@@ -232,7 +200,6 @@ typedef struct
 	zbx_vector_ptr_t		events;			/* vector of pointers to zbx_vmware_event_t structures */
 	int				max_query_metrics;	/* max count of Datastore perfCounters in one request */
 	zbx_vector_vmware_datastore_t	datastores;
-	zbx_vector_vmware_datacenter_t	datacenters;
 }
 zbx_vmware_data_t;
 
@@ -258,10 +225,6 @@ typedef struct
 	/* the vmware service instance version */
 	char				*version;
 
-	/* the vmware service instance version numeric */
-	unsigned short			major_version;
-	unsigned short			minor_version;
-
 	/* the vmware service instance fullname */
 	char				*fullname;
 
@@ -287,7 +250,6 @@ typedef struct
 {
 	zbx_vector_ptr_t	services;
 	zbx_hashset_t		strpool;
-	zbx_uint64_t		strpool_sz;
 }
 zbx_vmware_t;
 
